@@ -24,17 +24,16 @@
 #include "autosettlers.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiferry.h"
 #include "aihand.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
 #include "daidiplomacy.h"
 #include "daidomestic.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 #include "daisettler.h"
 
 #include "classicai.h"
@@ -579,6 +578,16 @@ static void cai_consider_wonder_city(struct city *pcity, bool *result)
   dai_consider_wonder_city(deftype, pcity, result);
 }
 
+/**********************************************************************//**
+  Call default ai with classic ai type as parameter.
+**************************************************************************/
+static void cai_revolution_start(struct player *pplayer)
+{
+  struct ai_type *deftype = classic_ai_get_self();
+
+  dai_revolution_start(deftype, pplayer);
+}
+
 /**********************************************************************//**
   Setup player ai_funcs function pointers.
 **************************************************************************/
@@ -691,5 +700,7 @@ bool fc_ai_classic_setup(struct ai_type *ai)
   /* ai->funcs.city_info = NULL; */
   /* ai->funcs.unit_info = NULL; */
 
+  ai->funcs.revolution_start = cai_revolution_start;
+
   return TRUE;
 }
