@@ -46,12 +46,10 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
-#include "ailog.h"
-#include "aiplayer.h"
-#include "aiunit.h"
 #include "aitools.h"
 #include "daicity.h"
+#include "daidata.h"
+#include "daiplayer.h"
 
 #include "aiparatrooper.h"
 
@@ -169,10 +167,11 @@ static struct tile *find_best_tile_to_paradrop_to(struct ai_type *ait,
           }
         } unit_list_iterate_end;
       } else {
-        val += get_defender(nmap, punit, target)->hp * 100;
+        val += get_defender(nmap, punit, target, NULL)->hp * 100;
       }
       val *= unit_win_chance(nmap, punit,
-                             get_defender(nmap, punit, target));
+                             get_defender(nmap, punit, target, NULL),
+                             NULL);
       val += pterrain->defense_bonus / 10;
       val -= punit->hp * 100;
       
@@ -379,18 +378,13 @@ static int calculate_want_for_paratrooper(struct unit *punit,
 /*************************************************************************//**
   Chooses to build a paratroopers if necessary
 *****************************************************************************/
-void dai_choose_paratrooper(struct ai_type *ait,
+void dai_choose_paratrooper(struct ai_type *ait, const struct civ_map *nmap,
                             struct player *pplayer, struct city *pcity,
                             struct adv_choice *choice, bool allow_gold_upkeep)
 {
-  const struct research *presearch;
+  const struct research *presearch = research_get(pplayer);
   int profit;
-  Tech_type_id tech_req;
-  Tech_type_id requirements[A_LAST];
-  int num_requirements = 0;
-  int i;
   struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
-  const struct civ_map *nmap = &(wld.map);
 
   /* military_advisor_choose_build() does something idiotic,
    * this function should not be called if there is danger... */
@@ -405,9 +399,6 @@ void dai_choose_paratrooper(struct ai_type *ait,
         && !utype_can_do_action(u_type, ACTION_PARADROP_CONQUER)) {
       continue;
     }
-    if (A_NEVER == u_type->require_advance) {
-      continue;
-    }
 
     if (!allow_gold_upkeep && utype_upkeep_cost(u_type, pplayer, O_GOLD) > 0) {
       continue;
@@ -420,17 +411,28 @@ void dai_choose_paratrooper(struct ai_type *ait,
     }
 
     /* Assign tech for paratroopers */
-    tech_req = advance_index(u_type->require_advance);
-    if (tech_req != A_NONE && tech_req != A_UNSET) {
-      for (i = 0; i < num_requirements; i++) {
-        if (requirements[i] == tech_req) {
-          break;
-        }
+    unit_tech_reqs_iterate(u_type, padv) {
+      /* We raise want if the required tech is not known */
+      Tech_type_id tech_req = advance_index(padv);
+
+      if (research_invention_state(presearch, tech_req) != TECH_KNOWN) {
+        plr_data->tech_want[tech_req] += 2;
+        log_base(LOGLEVEL_PARATROOPER, "Raising tech want in city %s for %s "
+                 "stimulating %s with %d (" ADV_WANT_PRINTF ") and req",
+                 city_name_get(pcity),
+                 player_name(pplayer),
+                 advance_rule_name(padv),
+                 2,
+                 plr_data->tech_want[tech_req]);
+
+        /* Now, we raise want for prerequisites */
+        advance_index_iterate(A_FIRST, k) {
+          if (research_goal_tech_req(presearch, tech_req, k)) {
+            plr_data->tech_want[k] += 1;
+          }
+        } advance_index_iterate_end;
       }
-      if (i == num_requirements) {
-        requirements[num_requirements++] = tech_req;
-      }
-    }
+    } unit_tech_reqs_iterate_end;
 
     /* we only update choice struct if we can build it! */
     if (!can_city_build_unit_now(nmap, pcity, u_type)) {
@@ -457,25 +459,5 @@ void dai_choose_paratrooper(struct ai_type *ait,
     }
   } unit_type_iterate_end;
 
-  /* we raise want if the required tech is not known */
-  presearch = research_get(pplayer);
-  for (i = 0; i < num_requirements; i++) {
-    tech_req = requirements[i];
-    plr_data->tech_want[tech_req] += 2;
-    log_base(LOGLEVEL_PARATROOPER, "Raising tech want in city %s for %s "
-             "stimulating %s with %d (" ADV_WANT_PRINTF ") and req",
-             city_name_get(pcity),
-             player_name(pplayer),
-             advance_rule_name(advance_by_number(tech_req)),
-             2,
-             plr_data->tech_want[tech_req]);
-
-    /* now, we raise want for prerequisites */
-    advance_index_iterate(A_FIRST, k) {
-      if (research_goal_tech_req(presearch, tech_req, k)) {
-        plr_data->tech_want[k] += 1;
-      }
-    } advance_index_iterate_end;
-  }
   return;
 }
