@@ -55,19 +55,18 @@
 
 /* ai/default */
 #include "aiair.h"
-#include "aidata.h"
 #include "aidiplomat.h"
 #include "aiferry.h"
 #include "aihand.h"
 #include "aihunt.h"
-#include "ailog.h"
 #include "aiparatrooper.h"
-#include "aiplayer.h"
 #include "aitech.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
 #include "daieffects.h"
+#include "dailog.h"
+#include "daiplayer.h"
 
 #include "daimilitary.h"
 
@@ -109,7 +108,7 @@ struct unit_type *dai_choose_defender_versus(struct city *pcity,
 
       defender = unit_virtual_create(pplayer, pcity, punittype, veteran);
       defense = get_total_defense_power(attacker, defender);
-      attack = get_total_attack_power(attacker, defender);
+      attack = get_total_attack_power(attacker, defender, NULL);
       get_modified_firepower(nmap, attacker, defender, &fpatt, &fpdef);
 
       /* Greg's algorithm. loss is the average number of health lost by
@@ -120,8 +119,8 @@ struct unit_type *dai_choose_defender_versus(struct city *pcity,
 
 #ifdef NEVER
       CITY_LOG(LOG_DEBUG, pcity, "desire for %s against %s(%d,%d) is %.2f",
-               unit_name_orig(punittype),
-               unit_name_orig(unit_type_get(attacker)), 
+               utype_rule_name(punittype),
+               unit_rule_name(attacker),
                TILE_XY(attacker->tile), want);
 #endif /* NEVER */
 
@@ -144,6 +143,7 @@ struct unit_type *dai_choose_defender_versus(struct city *pcity,
   very wrong. FIXME, use amortize on time to build.
 **************************************************************************/
 static struct unit_type *dai_choose_attacker(struct ai_type *ait,
+                                             const struct civ_map *nmap,
                                              struct city *pcity,
                                              enum terrain_class tc,
                                              bool allow_gold_upkeep)
@@ -152,7 +152,6 @@ static struct unit_type *dai_choose_attacker(struct ai_type *ait,
   adv_want best = -1;
   adv_want cur;
   struct player *pplayer = city_owner(pcity);
-  const struct civ_map *nmap = &(wld.map);
 
   simple_ai_unit_type_iterate(putype) {
     if (!allow_gold_upkeep && utype_upkeep_cost(putype, pplayer, O_GOLD) > 0) {
@@ -241,7 +240,7 @@ static int base_assess_defense_unit(struct city *pcity, struct unit *punit,
   int defense;
   int fp;
 
-  if (!is_military_unit(punit)) {
+  if (is_special_unit(punit)) {
     return 0;
   }
 
@@ -371,6 +370,7 @@ tactical_req_cb(const struct req_context *context,
 {
   switch (req->source.kind) {
   case VUT_IMPROVEMENT:
+  case VUT_SITE:
     {
       const struct impr_type *b = req->source.value.building;
 
@@ -388,6 +388,7 @@ tactical_req_cb(const struct req_context *context,
   case VUT_MAXTILEUNITS:
   case VUT_MINHP:
   case VUT_MINMOVES:
+  case VUT_COUNTER:
     /* Can be changed back or forth quickly */
     return TRI_MAYBE;
   case VUT_MINVETERAN:
@@ -413,25 +414,34 @@ tactical_req_cb(const struct req_context *context,
     /* If the attack happens, there is a diplrel that allows it */
     return TRI_YES;
   case VUT_AGE:
+  case VUT_FORM_AGE:
   case VUT_MINCALFRAG:
   case VUT_MINYEAR:
     /* If it is not near, won't change */
     return tri_req_active_turns(n_data, 5 /* WAG */,
                                 context, other_player, req);
+  case VUT_CITYSTATUS:
+    if (CITYS_OWNED_BY_ORIGINAL != req->source.value.citystatus
+        && CITYS_TRANSFERRED != req->source.value.citystatus) {
+      return TRI_MAYBE;
+    }
+    fc__fallthrough;
   case VUT_UTYPE:
   case VUT_UTFLAG:
   case VUT_UCLASS:
   case VUT_UCFLAG:
     /* FIXME: support converting siege machines (needs hard reqs checked) */
-  case VUT_CITYSTATUS:
   case VUT_ACTION:
   case VUT_OTYPE:
   case VUT_SPECIALIST:
   case VUT_EXTRAFLAG:
+  case VUT_MINLATITUDE:
+  case VUT_MAXLATITUDE:
   case VUT_AI_LEVEL:
   case VUT_CITYTILE:
   case VUT_STYLE:
   case VUT_TOPO:
+  case VUT_WRAP:
   case VUT_SERVERSETTING:
   case VUT_NATION:
   case VUT_NATIONGROUP:
@@ -440,8 +450,12 @@ tactical_req_cb(const struct req_context *context,
   case VUT_GOVERNMENT:
   case VUT_ACHIEVEMENT:
   case VUT_IMPR_GENUS:
+  case VUT_IMPR_FLAG:
+  case VUT_PLAYER_FLAG:
+  case VUT_PLAYER_STATE:
   case VUT_MINCULTURE:
   case VUT_MINTECHS:
+  case VUT_ORIGINAL_OWNER:
   case VUT_ROADFLAG:
   case VUT_TERRAIN:
   case VUT_EXTRA:
@@ -566,8 +580,9 @@ static unsigned int assess_danger_unit(const struct civ_map *nmap,
   /* Find the worst attack action to expect */
   action_by_result_iterate(paction, ACTRES_ATTACK) {
     /* Is it possible that punit will do action id to the city? */
+    /* FIXME: some unit parameters (notably, veterancy) may meddle in */
 
-    if (action_may_happen_unit_on_city(paction->id, punit, pcity, *move_time)) {
+    if (action_may_happen_unit_on_city(action_id(paction), punit, pcity, *move_time)) {
       int b;
 
       attack_danger = TRUE;
@@ -583,7 +598,10 @@ static unsigned int assess_danger_unit(const struct civ_map *nmap,
    * approaching bombarders. Some better logic is needed, see OSDN#41778 */
   if (!attack_danger) {
     action_by_result_iterate(paction, ACTRES_BOMBARD) {
-      if (action_may_happen_unit_on_city(paction->id, punit, pcity, *move_time)) {
+      /* FIXME: some unit parameters (notably, veterancy) may meddle in */
+
+      if (action_may_happen_unit_on_city(action_id(paction), punit, pcity,
+                                         *move_time)) {
         int b;
 
         attack_danger = TRUE;
@@ -1121,9 +1139,14 @@ bool dai_process_defender_want(struct ai_type *ait, const struct civ_map *nmap,
         /* Cost (shield equivalent) of gaining these techs. */
         /* FIXME? Katvrr advises that this should be weighted more heavily in
          * big danger. */
-        int tech_cost = research_goal_bulbs_required(presearch,
-                            advance_number(punittype->require_advance)) / 4
-                            / city_list_size(pplayer->cities);
+        int tech_cost = 0;
+
+        unit_tech_reqs_iterate(punittype, padv) {
+          tech_cost = research_goal_bulbs_required(presearch,
+                                                   advance_number(padv));
+        } unit_tech_reqs_iterate_end;
+
+        tech_cost = tech_cost / 4 / city_list_size(pplayer->cities);
 
         /* Contrary to the above, we don't care if walls are actually built
          * - we're looking into the future now. */
@@ -1167,13 +1190,15 @@ bool dai_process_defender_want(struct ai_type *ait, const struct civ_map *nmap,
        * it is written this way, and the results seem strange to me. - Per */
       adv_want desire = tech_desire[utype_index(punittype)] * best_unit_cost / best;
 
-      plr_data->tech_want[advance_index(punittype->require_advance)]
-        += desire;
-      TECH_LOG(ait, LOG_DEBUG, pplayer, punittype->require_advance,
-               "+ " ADV_WANT_PRINTF " for %s to defend %s",
-               desire,
-               utype_rule_name(punittype),
-               city_name_get(pcity));
+      unit_tech_reqs_iterate(punittype, padv) {
+        plr_data->tech_want[advance_index(padv)]
+          += desire;
+        TECH_LOG(ait, LOG_DEBUG, pplayer, padv,
+                 "+ " ADV_WANT_PRINTF " for %s to defend %s",
+                 desire,
+                 utype_rule_name(punittype),
+                 city_name_get(pcity));
+      } unit_tech_reqs_iterate_end;
     }
   } simple_ai_unit_type_iterate_end;
 
@@ -1256,9 +1281,6 @@ static void process_attacker_want(struct ai_type *ait,
   }
 
   simple_ai_unit_type_iterate(punittype) {
-    Tech_type_id tech_req = advance_number(punittype->require_advance);
-    int tech_dist = research_goal_unknown_techs(presearch, tech_req);
-
     if (dai_can_unit_type_follow_unit_type(punittype, orig_utype, ait)
         && is_native_near_tile(&(wld.map), utype_class(punittype), ptile)
         && (U_NOT_OBSOLETED == punittype->obsoleted_by
@@ -1282,14 +1304,25 @@ static void process_attacker_want(struct ai_type *ait,
       /* Cost (shield equivalent) of gaining these techs. */
       /* FIXME? Katvrr advises that this should be weighted more heavily in big
        * danger. */
-      int tech_cost = research_goal_bulbs_required(presearch, tech_req) / 4
-                      / city_list_size(pplayer->cities);
+      int tech_cost = 0;
       int bcost_balanced = build_cost_balanced(punittype);
       /* See description of kill_desire() for info about this variables. */
       int bcost = utype_build_shield_cost(pcity, NULL, punittype);
       int attack = adv_unittype_att_rating(punittype, veteran_level,
                                            SINGLE_MOVE,
                                            punittype->hp);
+      int tech_dist = 0;
+
+      unit_tech_reqs_iterate(punittype, padv) {
+        Tech_type_id tech_req = advance_number(padv);
+
+        tech_cost += research_goal_bulbs_required(presearch, tech_req);
+        if (tech_dist == 0) {
+          tech_dist = research_goal_unknown_techs(presearch, tech_req);
+        }
+      } unit_tech_reqs_iterate_end;
+
+      tech_cost = tech_cost / 4 / city_list_size(pplayer->cities);
 
       /* Take into account reinforcements strength */
       if (acity) {
@@ -1385,7 +1418,7 @@ static void process_attacker_want(struct ai_type *ait,
           adv_want kd;
           int city_attack = acity_data->attack * acity_data->attack;
 
-          /* See aiunit.c:find_something_to_kill() for comments. */
+          /* See daiunit.c:find_something_to_kill() for comments. */
           kd = kill_desire(value, attack,
                            (bcost + acity_data->bcost), vuln,
                            victim_count);
@@ -1413,14 +1446,16 @@ static void process_attacker_want(struct ai_type *ait,
       if (want > 0) {
         if (tech_dist > 0) {
           /* This is a future unit, tell the scientist how much we need it */
-          plr_data->tech_want[advance_index(punittype->require_advance)]
-            += want;
-          TECH_LOG(ait, LOG_DEBUG, pplayer, punittype->require_advance,
-                   "+ " ADV_WANT_PRINTF " for %s vs %s(%d,%d)",
-                   want,
-                   utype_rule_name(punittype),
-                   (acity ? city_name_get(acity) : utype_rule_name(victim_unit_type)),
-                   TILE_XY(ptile));
+          unit_tech_reqs_iterate(punittype, padv) {
+            plr_data->tech_want[advance_index(padv)]
+              += want;
+            TECH_LOG(ait, LOG_DEBUG, pplayer, padv,
+                     "+ " ADV_WANT_PRINTF " for %s vs %s(%d,%d)",
+                     want,
+                     utype_rule_name(punittype),
+                     (acity ? city_name_get(acity) : utype_rule_name(victim_unit_type)),
+                     TILE_XY(ptile));
+          } unit_tech_reqs_iterate_end;
         } else if (want > best_choice->want) {
           const struct impr_type *impr_req;
 
@@ -1478,6 +1513,7 @@ static void process_attacker_want(struct ai_type *ait,
   to carry a land attack unit, instead of the land attack unit itself.
 **************************************************************************/
 static struct adv_choice *kill_something_with(struct ai_type *ait,
+                                              const struct civ_map *nmap,
                                               struct player *pplayer,
                                               struct city *pcity, struct unit *myunit,
                                               struct adv_choice *choice)
@@ -1504,14 +1540,14 @@ static struct adv_choice *kill_something_with(struct ai_type *ait,
   struct adv_choice *best_choice;
   struct ai_city *city_data = def_ai_city_data(pcity, ait);
   struct ai_city *acity_data;
-  struct civ_map *nmap = &(wld.map);
 
   best_choice = adv_new_choice();
   best_choice->value.utype = unit_type_get(myunit);
   best_choice->type = CT_ATTACKER;
   adv_choice_set_use(best_choice, "attacker");
 
-  fc_assert_ret_val(is_military_unit(myunit) && !utype_fuel(unit_type_get(myunit)), choice);
+  fc_assert_ret_val(!is_special_unit(myunit)
+                    && !utype_fuel(unit_type_get(myunit)), choice);
 
   if (city_data->danger != 0 && assess_defense(ait, pcity) == 0) {
     /* Defense comes first! */
@@ -1564,7 +1600,7 @@ static struct adv_choice *kill_something_with(struct ai_type *ait,
       def_vet = 0;
     }
 
-    pdef = get_defender(nmap, myunit, ptile);
+    pdef = get_defender(nmap, myunit, ptile, NULL);
     if (pdef) {
       int m = unittype_def_rating_squared(unit_type_get(myunit), unit_type_get(pdef),
                                           city_owner(acity), ptile, FALSE,
@@ -1595,7 +1631,7 @@ static struct adv_choice *kill_something_with(struct ai_type *ait,
       ferry_map = NULL;
     }
 
-    pdef = get_defender(nmap, myunit, ptile);
+    pdef = get_defender(nmap, myunit, ptile, NULL);
     if (!pdef) {
       /* Nobody to attack! */
       goto cleanup;
@@ -1928,7 +1964,7 @@ struct adv_choice *military_advisor_choose_build(struct ai_type *ait,
         CITY_LOG(LOG_DEBUG, pcity, "m_a_c_d does not want defenders");
       }
     }
-  } /* ok, don't need to defend */
+  } /* Ok, don't need to defend */
 
   if (pcity->surplus[O_SHIELD] <= 0 
       || pcity->feel[CITIZEN_UNHAPPY][FEELING_FINAL] > pcity->feel[CITIZEN_UNHAPPY][FEELING_EFFECT]
@@ -1965,7 +2001,7 @@ struct adv_choice *military_advisor_choose_build(struct ai_type *ait,
   }
 
   /* Consider making an offensive diplomat */
-  dai_choose_diplomat_offensive(ait, pplayer, pcity, choice);
+  dai_choose_diplomat_offensive(ait, nmap, pplayer, pcity, choice);
 
   /* Consider making a sea bodyguard */
   punittype = dai_choose_bodyguard(ait, nmap, pcity, TC_OCEAN, L_DEFEND_GOOD,
@@ -1975,29 +2011,30 @@ struct adv_choice *military_advisor_choose_build(struct ai_type *ait,
   }
 
   /* Consider making an airplane */
-  (void) dai_choose_attacker_air(ait, pplayer, pcity, choice, allow_gold_upkeep);
+  (void) dai_choose_attacker_air(ait, nmap, pplayer, pcity, choice,
+                                 allow_gold_upkeep);
 
   /* Consider making a paratrooper */
-  dai_choose_paratrooper(ait, pplayer, pcity, choice, allow_gold_upkeep);
+  dai_choose_paratrooper(ait, nmap, pplayer, pcity, choice, allow_gold_upkeep);
 
   /* Check if we want a sailing attacker. Have to put sailing first
      before we mung the seamap */
-  punittype = dai_choose_attacker(ait, pcity, TC_OCEAN, allow_gold_upkeep);
+  punittype = dai_choose_attacker(ait, nmap, pcity, TC_OCEAN, allow_gold_upkeep);
   if (punittype) {
     virtualunit = unit_virtual_create(
       pplayer, pcity, punittype,
       city_production_unit_veteran_level(pcity, punittype));
-    choice = kill_something_with(ait, pplayer, pcity, virtualunit, choice);
+    choice = kill_something_with(ait, nmap, pplayer, pcity, virtualunit, choice);
     unit_virtual_destroy(virtualunit);
   }
 
   /* Consider a land attacker or a ferried land attacker
    * (in which case, we might want a ferry before an attacker)
    */
-  punittype = dai_choose_attacker(ait, pcity, TC_LAND, allow_gold_upkeep);
+  punittype = dai_choose_attacker(ait, nmap, pcity, TC_LAND, allow_gold_upkeep);
   if (punittype) {
     virtualunit = unit_virtual_create(pplayer, pcity, punittype, 1);
-    choice = kill_something_with(ait, pplayer, pcity, virtualunit, choice);
+    choice = kill_something_with(ait, nmap, pplayer, pcity, virtualunit, choice);
     unit_virtual_destroy(virtualunit);
   }
 
