@@ -55,13 +55,12 @@
 #include "handicaps.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiferry.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
-#include "aiunit.h"
 #include "daicity.h"
+#include "daidata.h"
+#include "dailog.h"
+#include "daiplayer.h"
 
 #include "daisettler.h"
 
@@ -572,7 +571,7 @@ static bool food_starvation(const struct cityresult *result)
   /* Avoid starvation: We must have enough food to grow.
    *   Note: this does not handle the case of a newly founded city breaking
    * even but being immediately able to build an improvement increasing its
-   * yield (such as supermarkets and harbours in the classic ruleset).
+   * yield (such as supermarkets and harbors in the classic ruleset).
    * /MSS */
   return (result->city_center.tdc->food
           + (result->best_other.tdc ? result->best_other.tdc->food
@@ -807,7 +806,7 @@ static struct cityresult *settler_map_iterate(struct ai_type *ait,
 
     if (boat_cost == 0 && pclass->adv.sea_move == MOVE_NONE
         && tile_continent(ptile) != curcont) {
-      /* We have an accidential land bridge. Ignore it. It will in all
+      /* We have an accidental land bridge. Ignore it. It will in all
        * likelihood go away next turn, or even in a few nanoseconds. */
       continue;
     }
@@ -941,18 +940,20 @@ static struct cityresult *find_best_city_placement(struct ai_type *ait,
         /* Sea travel not possible yet. Bump tech want for ferries. */
         boattype = get_role_unit(L_FERRYBOAT, 0);
 
-        if (NULL != boattype
-            && A_NEVER != boattype->require_advance) {
+        if (NULL != boattype) {
           struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
 
-          plr_data->tech_want[advance_index(boattype->require_advance)]
-            += FERRY_TECH_WANT;
-          TECH_LOG(ait, LOG_DEBUG, pplayer, boattype->require_advance,
-                   "+ %d for %s to ferry settler",
-                   FERRY_TECH_WANT,
-                   utype_rule_name(boattype));
+          unit_tech_reqs_iterate(boattype, padv) {
+            plr_data->tech_want[advance_index(padv)]
+              += FERRY_TECH_WANT;
+            TECH_LOG(ait, LOG_DEBUG, pplayer, padv,
+                     "+ %d for %s to ferry settler",
+                     FERRY_TECH_WANT,
+                     utype_rule_name(boattype));
+          } unit_tech_reqs_iterate_end;
         }
-        /* return the result from the search on our current continent */
+
+        /* Return the result from the search on our current continent */
         return cr1;
       }
       ferry = unit_virtual_create(pplayer, NULL, boattype, 0);
