@@ -17,18 +17,18 @@
 
 /* common */
 #include "ai.h"
+#include "world_object.h"
 
 /* ai/default */
-#include "aidata.h"
 #include "aiferry.h"
 #include "aihand.h"
-#include "ailog.h"
-#include "aiplayer.h"
 #include "aitools.h"
 #include "daicity.h"
 #include "daidiplomacy.h"
 #include "daidomestic.h"
+#include "dailog.h"
 #include "daimilitary.h"
+#include "daiplayer.h"
 #include "daisettler.h"
 
 /* tex ai */
@@ -565,6 +565,15 @@ static void texwai_refresh(struct player *pplayer)
   TEXAI_TFUNC(texai_refresh, pplayer);
 }
 
+/**********************************************************************//**
+  Call default ai with tex ai type as parameter.
+**************************************************************************/
+static void texwai_revolution_start(struct player *pplayer)
+{
+  TEXAI_AIT;
+  TEXAI_TFUNC(dai_revolution_start, pplayer);
+}
+
 /**********************************************************************//**
   Return module capability string
 **************************************************************************/
@@ -675,5 +684,7 @@ bool fc_ai_tex_setup(struct ai_type *ai)
   ai->funcs.city_info = texai_city_changed;
   ai->funcs.unit_info = texai_unit_changed;
 
+  ai->funcs.revolution_start = texwai_revolution_start;
+
   return TRUE;
 }
