@@ -36,6 +36,7 @@
 #include "events.h"
 #include "game.h"
 #include "government.h"
+#include "nation.h"
 #include "packets.h"
 #include "specialist.h"
 
@@ -210,8 +211,7 @@ static bool apply_result_on_server(struct city *pcity,
 
       last_request_id =
         dsend_packet_city_make_specialist(&client.conn,
-                                          pcity->id, pcity->id,
-                                          ptile->index);
+                                          pcity->id, ptile->index);
       if (first_request_id == 0) {
         first_request_id = last_request_id;
       }
@@ -251,7 +251,7 @@ static bool apply_result_on_server(struct city *pcity,
 
       last_request_id =
         dsend_packet_city_make_worker(&client.conn,
-                                      pcity->id, pcity->id, ptile->index);
+                                      pcity->id, ptile->index);
       if (first_request_id == 0) {
         first_request_id = last_request_id;
       }
@@ -287,8 +287,8 @@ static bool apply_result_on_server(struct city *pcity,
        * allocation of citizen than the server. We just send a
        * PACKET_CITY_REFRESH to bring them in sync.
        */
-    first_request_id = last_request_id
-      = dsend_packet_city_refresh(&client.conn, pcity->id, pcity->id);
+    first_request_id = last_request_id =
+      dsend_packet_city_refresh(&client.conn, pcity->id);
     stats.refresh_forced++;
   }
 
@@ -488,10 +488,11 @@ void cma_init(void)
   /* reset cache counters */
   memset(&stats, 0, sizeof(stats));
 
-  /* We used to just use timer_new here, but apparently cma_init can be
+  /* We used to just use timer_new() here, but apparently cma_init() can be
    * called multiple times per client invocation so that lead to memory
    * leaks. */
-  stats.wall_timer = timer_renew(timer, TIMER_USER, TIMER_ACTIVE);
+  stats.wall_timer = timer_renew(timer, TIMER_USER, TIMER_ACTIVE,
+                                 timer != NULL ? NULL : "agent: stats");
 
   memset(&self, 0, sizeof(self));
   strcpy(self.name, "CMA");
