@@ -94,6 +94,7 @@
 #include "options.h"
 #include "overview_common.h"
 #include "packhand.h"
+#include "svgflag.h"
 #include "tilespec.h"
 #include "themes_common.h"
 #include "update_queue.h"
@@ -330,7 +331,13 @@ int default_tileset_select(void)
       return EXIT_FAILURE;
     }
   } else {
-    tilespec_try_read(gui_options.default_tileset_name, FALSE, -1, TRUE);
+    if (gui_options.default_tileset_name[0] == '\0') {
+      /* Use topology by default */
+      tilespec_try_read(tileset_name_for_topology(index_ts_topology(gui_options.default_topology)),
+                        FALSE, -1, TRUE);
+    } else {
+      tilespec_try_read(gui_options.default_tileset_name, FALSE, -1, TRUE);
+    }
   }
 
   editor_init();
@@ -436,7 +443,7 @@ int client_main(int argc, char *argv[], bool postpone_tileset)
                   _("Print a summary of the options"));
 #ifdef FREECIV_DEBUG
       cmdhelp_add(help, "H", "Hackless",
-                  _("Do not request hack access to local, but not spawned, server"));
+                  _("Do not request hack access to local server"));
 #endif /* FREECIV_DEBUG */
       cmdhelp_add(help, "l",
                   /* TRANS: "log" is exactly what user must type, do not translate. */
@@ -659,17 +666,6 @@ int client_main(int argc, char *argv[], bool postpone_tileset)
     sz_strlcpy(user_name, gui_options.default_user_name); 
   }
   if (metaserver[0] == '\0') {
-    /* FIXME: Find a cleaner way to achieve this. */
-    /* www.cazfi.net/freeciv/metaserver/ was default metaserver
-     * over one release when meta.freeciv.org was unavailable. */
-    const char *oldaddr = "http://www.cazfi.net/freeciv/metaserver/";
-
-    if (0 == strcmp(gui_options.default_metaserver, oldaddr)) {
-      log_normal(_("Updating old metaserver address \"%s\"."), oldaddr);
-      sz_strlcpy(gui_options.default_metaserver, DEFAULT_METASERVER_OPTION);
-      log_normal(_("Default metaserver has been set to value \"%s\"."),
-                 DEFAULT_METASERVER_OPTION);
-    }
     if (0 == strcmp(gui_options.default_metaserver, DEFAULT_METASERVER_OPTION)) {
       sz_strlcpy(metaserver, FREECIV_META_URL);
     } else {
@@ -725,7 +721,7 @@ static void log_option_save_msg(enum log_level lvl, const char *msg, ...)
   Main client execution stop function. This calls ui_exit() and not the
   other way around.
 **************************************************************************/
-void client_exit(int return_value)
+void fc__noreturn client_exit(int return_value)
 {
   if (client_state() >= C_S_PREPARING) {
     attribute_flush();
@@ -761,6 +757,7 @@ void client_exit(int return_value)
   conn_list_destroy(game.all_connections);
   conn_list_destroy(game.est_connections);
 
+  free_svg_flag_API();
   registry_module_close();
   libfreeciv_free();
 
@@ -788,10 +785,10 @@ void client_packet_input(void *packet, int type)
       && PACKET_SERVER_INFO != type) {
     log_error("Received packet %s (%d) before establishing connection!",
               packet_name(type), type);
-    disconnect_from_server();
+    disconnect_from_server(FALSE);
   } else if (!client_handle_packet(type, packet)) {
     log_error("Received unknown packet (type %d) from server!", type);
-    disconnect_from_server();
+    disconnect_from_server(FALSE);
   }
 }
 
@@ -925,7 +922,7 @@ void set_client_state(enum client_states newstate)
       client_game_init();
     } else {
       /* From an upper state means that we didn't quit the server,
-       * so a lot of informations are still in effect. */
+       * so a lot of information is still in effect. */
       client_game_reset();
       options_dialogs_update();
     }
@@ -941,7 +938,7 @@ void set_client_state(enum client_states newstate)
   case C_S_RUNNING:
     if (oldstate == C_S_PREPARING) {
       popdown_races_dialog();
-      stop_menu_music();     /* stop intro sound loop. */
+      stop_menu_music();     /* Stop intro sound loop. */
     }
 
     init_city_report_game_data();
@@ -951,7 +948,7 @@ void set_client_state(enum client_states newstate)
       research_update(research_get(pplayer));
     }
     role_unit_precalcs();
-    boot_help_texts();   /* reboot with player */
+    boot_help_texts();   /* Reboot with player */
     global_worklists_build();
     can_slide = FALSE;
     unit_focus_update();
@@ -965,7 +962,7 @@ void set_client_state(enum client_states newstate)
 
     refresh_overview_canvas();
 
-    update_info_label();        /* get initial population right */
+    update_info_label();        /* Get initial population right */
     unit_focus_update();
     update_unit_info_label(get_units_in_focus());
 
@@ -973,6 +970,7 @@ void set_client_state(enum client_states newstate)
       center_on_something();
     }
     start_style_music();
+    audio_play_sound("e_enter_game", NULL, NULL);
     break;
 
   case C_S_OVER:
@@ -1114,7 +1112,8 @@ void set_seconds_to_turndone(double seconds)
 {
   if (current_turn_timeout() > 0) {
     seconds_to_turndone = seconds;
-    turndone_timer = timer_renew(turndone_timer, TIMER_USER, TIMER_ACTIVE);
+    turndone_timer = timer_renew(turndone_timer, TIMER_USER, TIMER_ACTIVE,
+                                 turndone_timer != NULL ? NULL : "turndone");
     timer_start(turndone_timer);
 
     /* Maybe we should do an update_timeout_label here, but it doesn't
@@ -1137,7 +1136,8 @@ bool is_waiting_turn_change(void)
 void start_turn_change_wait(void)
 {
   seconds_shown_to_new_turn = ceil(game.tinfo.last_turn_change_time + 0.1);
-  between_turns = timer_renew(between_turns, TIMER_USER, TIMER_ACTIVE);
+  between_turns = timer_renew(between_turns, TIMER_USER, TIMER_ACTIVE,
+                              between_turns != NULL ? NULL : "between turns");
   timer_start(between_turns);
 
   waiting_turn_change = TRUE;
