@@ -97,7 +97,7 @@ void client_remove_unit(struct unit *punit)
   game_remove_unit(&wld, punit);
   punit = NULL;
   if (old > 0 && get_num_units_in_focus() == 0) {
-    unit_focus_advance();
+    unit_focus_advance(TRUE);
   } else if (update) {
     update_unit_pix_label(get_units_in_focus());
     update_unit_info_label(get_units_in_focus());
@@ -180,7 +180,7 @@ void client_change_all(struct universal *from, struct universal *to)
   connection_do_buffer(&client.conn);
   city_list_iterate (client.conn.playing->cities, pcity) {
     if (are_universals_equal(&pcity->production, from)
-        && can_city_build_now(pcity, to)) {
+        && can_city_build_now(&(wld.map), pcity, to)) {
       city_change_production(pcity, to);
     }
   } city_list_iterate_end;
@@ -248,7 +248,7 @@ void client_diplomacy_clause_string(char *buf, int bufsiz,
     fc_snprintf(buf, bufsiz, _("The %s give %s"),
                 nation_plural_for_player(pclause->from),
                 advance_name_translation(advance_by_number(pclause->value)));
-    break;
+    return;
   case CLAUSE_CITY:
     pcity = game_city_by_number(pclause->value);
     if (pcity) {
@@ -259,44 +259,50 @@ void client_diplomacy_clause_string(char *buf, int bufsiz,
       fc_snprintf(buf, bufsiz,_("The %s give an unknown city"),
                   nation_plural_for_player(pclause->from));
     }
-    break;
+    return;
   case CLAUSE_GOLD:
     fc_snprintf(buf, bufsiz, PL_("The %s give %d gold",
                                  "The %s give %d gold", pclause->value),
                 nation_plural_for_player(pclause->from),
                 pclause->value);
-    break;
+    return;
   case CLAUSE_MAP:
     fc_snprintf(buf, bufsiz, _("The %s give their worldmap"),
                 nation_plural_for_player(pclause->from));
-    break;
+    return;
   case CLAUSE_SEAMAP:
     fc_snprintf(buf, bufsiz, _("The %s give their seamap"),
                 nation_plural_for_player(pclause->from));
-    break;
+    return;
   case CLAUSE_CEASEFIRE:
     fc_snprintf(buf, bufsiz, _("The parties agree on a cease-fire"));
-    break;
+    return;
   case CLAUSE_PEACE:
     fc_snprintf(buf, bufsiz, _("The parties agree on a peace"));
-    break;
+    return;
   case CLAUSE_ALLIANCE:
     fc_snprintf(buf, bufsiz, _("The parties create an alliance"));
-    break;
+    return;
   case CLAUSE_VISION:
     fc_snprintf(buf, bufsiz, _("The %s give shared vision"),
                 nation_plural_for_player(pclause->from));
-    break;
+    return;
   case CLAUSE_EMBASSY:
     fc_snprintf(buf, bufsiz, _("The %s give an embassy"),
                 nation_plural_for_player(pclause->from));
-    break;
-  default:
+    return;
+  case CLAUSE_SHARED_TILES:
+    fc_snprintf(buf, bufsiz, _("The %s share tiles"),
+                nation_plural_for_player(pclause->from));
+    return;
+  case CLAUSE_COUNT:
     fc_assert(FALSE);
-    if (bufsiz > 0) {
-      *buf = '\0';
-    }
-    break;
+    return;
+  }
+
+  fc_assert(FALSE);
+  if (bufsiz > 0) {
+    *buf = '\0';
   }
 }
 
@@ -425,6 +431,7 @@ void center_on_something(void)
 {
   struct city *pcity;
   struct unit *punit;
+  const struct civ_map *nmap = &(wld.map);
 
   if (!can_client_change_view()) {
     return;
@@ -450,14 +457,14 @@ void center_on_something(void)
     fc_assert_ret(punit != NULL);
     center_tile_mapcanvas(unit_tile(punit));
   } else {
-    struct tile *ctile = native_pos_to_tile(&(wld.map), wld.map.xsize / 2, wld.map.ysize / 2);
+    struct tile *ctile = native_pos_to_tile(nmap, wld.map.xsize / 2, wld.map.ysize / 2);
 
     /* Just any known tile will do; search near the middle first. */
     /* Iterate outward from the center tile.  We have to give a radius that
      * is guaranteed to be larger than the map will be.  Although this is
      * a misuse of map.xsize and map.ysize (which are native dimensions),
      * it should give a sufficiently large radius. */
-    iterate_outward(&(wld.map), ctile, wld.map.xsize + wld.map.ysize, ptile) {
+    iterate_outward(nmap, ctile, wld.map.xsize + wld.map.ysize, ptile) {
       if (client_tile_get_known(ptile) != TILE_UNKNOWN) {
         ctile = ptile;
         break;
@@ -579,6 +586,15 @@ bool city_building_present(const struct city *pcity,
     && city_has_building(pcity, target->value.building);
 }
 
+/**********************************************************************//**
+  A TestCityFunc wrapper for can_city_build_now()
+**************************************************************************/
+bool can_city_build_now_client(const struct city *pcity,
+                               const struct universal *target)
+{
+  return can_city_build_now(&(wld.map), pcity, target);
+}
+
 /**********************************************************************//**
   Return the numerical "section" of an item.  This is used for sorting.
 **************************************************************************/
@@ -591,7 +607,7 @@ static int target_get_section(struct universal target)
       return 3;
     }
   } else {
-    if (improvement_has_flag(target.value.building, IF_GOLD)) {
+    if (is_convert_improvement(target.value.building)) {
       return 1;
     } else if (is_small_wonder(target.value.building)) {
       return 4;
@@ -649,7 +665,7 @@ void name_and_sort_items(struct universal *targets, int num_targets,
       cost = utype_build_shield_cost(pcity, client_player(), target.value.utype);
     } else {
       name = city_improvement_name_translation(pcity, target.value.building);
-      if (improvement_has_flag(target.value.building, IF_GOLD)) {
+      if (is_convert_improvement(target.value.building)) {
         cost = -1;
       } else {
         if (pcity != NULL) {
@@ -805,6 +821,7 @@ int collect_eventually_buildable_targets(struct universal *targets,
 {
   struct player *pplayer = client_player();
   int cids_used = 0;
+  const struct civ_map *nmap = &(wld.map);
 
   improvement_iterate(pimprove) {
     bool can_build;
@@ -853,8 +870,8 @@ int collect_eventually_buildable_targets(struct universal *targets,
 
     if (NULL != pcity) {
       /* Can the city build? */
-      can_build = can_city_build_unit_now(pcity, punittype);
-      can_eventually_build = can_city_build_unit_later(pcity, punittype);
+      can_build = can_city_build_unit_now(nmap, pcity, punittype);
+      can_eventually_build = can_city_build_unit_later(nmap, pcity, punittype);
     } else if (NULL != pplayer) {
       /* Can our player build? */
       can_build = can_player_build_unit_now(pplayer, punittype);
@@ -1138,7 +1155,7 @@ void cityrep_buy(struct city *pcity)
 {
   int value;
 
-  if (city_production_has_flag(pcity, IF_GOLD)) {
+  if (city_production_is_genus(pcity, IG_CONVERT)) {
     create_event(pcity->tile, E_BAD_COMMAND, ftc_client,
                  _("You can't buy %s in %s!"),
                  improvement_name_translation(pcity->production.value.building),
