@@ -21,7 +21,7 @@
 /* utility */
 #include "support.h"
 
-/* gui-gtk-4.0 */
+/* gui-gtk-3.22 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 
@@ -94,7 +94,7 @@ void choice_dialog_button_move_to_the_end(GtkWidget *cd,
   GtkWidget *button = choice_dialog_get_nth_button(cd, number);
   GtkWidget *bbox = g_object_get_data(G_OBJECT(cd), "bbox");
 
-  gtk_box_reorder_child_after(GTK_BOX(bbox), button, NULL);
+  gtk_box_reorder_child(GTK_BOX(bbox), button, -1);
 }
 
 /*******************************************************************//**
@@ -103,41 +103,39 @@ void choice_dialog_button_move_to_the_end(GtkWidget *cd,
 GtkWidget *choice_dialog_start(GtkWindow *parent, const gchar *name,
                                const gchar *text)
 {
-  GtkWidget *dshell, *dlabel, *vgrid, *bbox;
-  int grid_row = 0;
+  GtkWidget *dshell, *dlabel, *vbox, *bbox;
 
-  dshell = gtk_window_new();
+  dshell = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   setup_dialog(dshell, toplevel);
+  gtk_window_set_position (GTK_WINDOW(dshell), GTK_WIN_POS_MOUSE);
 
   gtk_window_set_title(GTK_WINDOW(dshell), name);
 
   gtk_window_set_transient_for(GTK_WINDOW(dshell), parent);
   gtk_window_set_destroy_with_parent(GTK_WINDOW(dshell), TRUE);
 
-  vgrid = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vgrid),
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
                                  GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_row_spacing(GTK_GRID(vgrid), 5);
-  gtk_window_set_child(GTK_WINDOW(dshell), vgrid);
+  gtk_grid_set_row_spacing(GTK_GRID(vbox), 5);
+  gtk_container_add(GTK_CONTAINER(dshell),vbox);
 
-  gtk_widget_set_margin_start(vgrid, 5);
-  gtk_widget_set_margin_end(vgrid, 5);
-  gtk_widget_set_margin_top(vgrid, 5);
-  gtk_widget_set_margin_bottom(vgrid, 5);
+  gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 
   dlabel = gtk_label_new(text);
-  gtk_grid_attach(GTK_GRID(vgrid), dlabel, 0, grid_row++, 1, 1);
-
-  bbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
-  gtk_grid_attach(GTK_GRID(vgrid), bbox, 0, grid_row++, 1, 1);
+  gtk_container_add(GTK_CONTAINER(vbox), dlabel);
 
+  bbox = gtk_button_box_new(GTK_ORIENTATION_VERTICAL);
+  gtk_box_set_spacing(GTK_BOX(bbox), 2);
+  gtk_container_add(GTK_CONTAINER(vbox), bbox);
+  
   g_object_set_data(G_OBJECT(dshell), "bbox", bbox);
   g_object_set_data(G_OBJECT(dshell), "nbuttons", GINT_TO_POINTER(0));
   g_object_set_data(G_OBJECT(dshell), "hide", GINT_TO_POINTER(FALSE));
-
-  gtk_widget_show(vgrid);
+  
+  gtk_widget_show(vbox);
   gtk_widget_show(dlabel);
-
+  
   return dshell;
 }
 
@@ -150,7 +148,7 @@ static void choice_dialog_clicked(GtkWidget *w, gpointer data)
   if (g_object_get_data(G_OBJECT(data), "hide")) {
     gtk_widget_hide(GTK_WIDGET(data));
   } else {
-    gtk_window_destroy(GTK_WINDOW(data));
+    gtk_widget_destroy(GTK_WIDGET(data));
   }
 }
 
@@ -172,7 +170,7 @@ void choice_dialog_add(GtkWidget *dshell, const gchar *label,
   fc_snprintf(name, sizeof(name), "button%d", nbuttons);
 
   button = gtk_button_new_with_mnemonic(label);
-  gtk_box_append(GTK_BOX(bbox), button);
+  gtk_container_add(GTK_CONTAINER(bbox), button);
   g_object_set_data(G_OBJECT(dshell), name, button);
 
   if (handler) {
@@ -196,11 +194,11 @@ void choice_dialog_add(GtkWidget *dshell, const gchar *label,
 void choice_dialog_end(GtkWidget *dshell)
 {
   GtkWidget *bbox;
-
+  
   bbox = g_object_get_data(G_OBJECT(dshell), "bbox");
-
-  gtk_widget_show(bbox);
-  gtk_widget_show(dshell);
+  
+  gtk_widget_show_all(bbox);
+  gtk_widget_show(dshell);  
 }
 
 /*******************************************************************//**
@@ -222,7 +220,7 @@ GtkWidget *popup_choice_dialog(GtkWindow *parent, const gchar *dialogname,
   gchar *name;
 
   dshell = choice_dialog_start(parent, dialogname, text);
-
+  
   va_start(args, text);
 
   while ((name = va_arg(args, gchar *))) {
@@ -241,13 +239,3 @@ GtkWidget *popup_choice_dialog(GtkWindow *parent, const gchar *dialogname,
 
   return dshell;
 }
-
-/*******************************************************************//**
-  Free choice dialog.
-***********************************************************************/
-void choice_dialog_destroy(GtkWidget *dlg)
-{
-  if (dlg != NULL) {
-    gtk_window_destroy(GTK_WINDOW(dlg));
-  }
-}
