@@ -879,7 +879,8 @@ static void editbar_reload_tileset(struct editbar *eb)
                        TVS_COL_ID, utype_number(putype),
                        TVS_COL_NAME, utype_name_translation(putype),
                        -1);
-    sprite = get_unittype_sprite(tileset, putype, direction8_invalid());
+    sprite = get_unittype_sprite(tileset, putype, ACTIVITY_LAST,
+                                 direction8_invalid());
     if (sprite == NULL) {
       continue;
     }
@@ -1434,7 +1435,8 @@ static GdkPixbuf *get_tool_value_pixbuf(enum editor_tool_type ett,
   case ETT_UNIT:
     putype = utype_by_number(value);
     if (putype) {
-      sprite = get_unittype_sprite(tileset, putype, direction8_invalid());
+      sprite = get_unittype_sprite(tileset, putype,
+                                   ACTIVITY_LAST, direction8_invalid());
     }
     break;
   case ETT_CITY:
@@ -1600,6 +1602,7 @@ static void editinfobox_refresh(struct editinfobox *ei)
 
 /************************************************************************//**
   Handle ctrl+[key] combinations.
+  Mac only - Handle meta+[key] combinations.
 ****************************************************************************/
 static gboolean handle_edit_key_press_with_ctrl(GdkEventKey *ev)
 {
@@ -1661,9 +1664,10 @@ gboolean handle_edit_key_press(GdkEventKey *ev)
 {
   enum editor_tool_type ett, new_ett = NUM_EDITOR_TOOL_TYPES;
 
-  /* Check ctrl before shift - this is correct also for the case where
+  /* Check ctrl/meta before shift - this is correct also for the case where
    * they are both active. */
-  if (ev->state & GDK_CONTROL_MASK) {
+  /* ACCL_MOD_KEY is GDK_META_MASK on Mac, else GDK_CONTROL_MASK */
+  if (ev->state & ACCL_MOD_KEY) {
     return handle_edit_key_press_with_ctrl(ev);
   }
 
