@@ -28,6 +28,7 @@
 
 /* common */
 #include "government.h"
+#include "nation.h"
 #include "packets.h"
 #include "player.h"
 #include "research.h"
@@ -36,7 +37,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -222,6 +223,7 @@ static void intel_wonder_destroy_callback(GtkWidget *w, gpointer data)
 void close_intel_dialog(struct player *p)
 {
   struct intel_dialog *pdialog = get_intel_dialog(p);
+
   intel_destroy_callback(NULL, pdialog);
 }
 
@@ -246,18 +248,17 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   GtkWidget *shell, *notebook, *label, *sw, *view, *table;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
-
   int i;
- 
+
   pdialog = fc_malloc(sizeof(*pdialog));
   pdialog->pplayer = p;
- 
+
   shell = gtk_dialog_new_with_buttons(NULL,
-      NULL,
-      0,
-      GTK_STOCK_CLOSE,
-      GTK_RESPONSE_CLOSE,
-      NULL);
+                                      NULL,
+                                      0,
+                                      _("_Close"),
+                                      GTK_RESPONSE_CLOSE,
+                                      NULL);
   pdialog->shell = shell;
   gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
   setup_dialog(shell, toplevel);
@@ -400,6 +401,7 @@ static struct intel_wonder_dialog *create_intel_wonder_dialog(struct player *p)
   g_signal_connect(shell, "response",
                    G_CALLBACK(gtk_widget_destroy), NULL);
 
+
   pdialog->rule = gtk_label_new("-");
 
   /* columns: 0 - wonder name, 1 - location (city/unknown/lost),
@@ -650,6 +652,9 @@ void update_intel_wonder_dialog(struct player *p)
     case WV_NEVER:
       rule = _("Small Wonders not known");
       break;
+    case WV_EMBASSY:
+      rule = _("Small Wonders visible if we have an embassy");
+      break;
     }
 
     gtk_label_set_text(GTK_LABEL(pdialog->rule), rule);
@@ -664,7 +669,6 @@ void update_intel_wonder_dialog(struct player *p)
 
         if (wonder_is_built(p, impr)) {
           struct city *pcity = city_from_wonder(p, impr);
-
           if (pcity) {
             cityname = city_name_get(pcity);
           } else {
