@@ -43,7 +43,7 @@
 #include "text.h"
 #include "tilespec.h"
 
-/* client/gui-gtk-4.0 */
+/* client/gui-gtk-3.22 */
 #include "dialogs.h"
 #include "graphics.h"
 #include "gui_main.h"
@@ -167,11 +167,11 @@ void popdown_spaceship_dialog(struct player *pplayer)
 }
 
 /************************************************************************//**
-  Draw spaceship dialog canvas.
+  Spaceship dialog canvas got exposed
 ****************************************************************************/
-static void spaceship_image_canvas_draw(GtkDrawingArea *w, cairo_t *cr,
-                                        int width, int height,
-                                        gpointer data)
+static gboolean spaceship_image_canvas_expose(GtkWidget *widget,
+                                              cairo_t *cr,
+                                              gpointer data)
 {
   struct spaceship_dialog *pdialog = (struct spaceship_dialog *)data;
   struct canvas store = FC_STATIC_CANVAS_INIT;
@@ -179,6 +179,8 @@ static void spaceship_image_canvas_draw(GtkDrawingArea *w, cairo_t *cr,
   store.drawable = cr;
 
   put_spaceship(&store, 0, 0, pdialog->pplayer);
+
+  return TRUE;
 }
 
 /************************************************************************//**
@@ -216,9 +218,8 @@ static void spaceship_response(struct gui_dialog *dlg, int response,
 struct spaceship_dialog *create_spaceship_dialog(struct player *pplayer)
 {
   struct spaceship_dialog *pdialog;
-  GtkWidget *hgrid, *frame;
+  GtkWidget *hbox, *frame;
   int w, h;
-  int grid_col = 0;
 
   pdialog = fc_malloc(sizeof(struct spaceship_dialog));
   pdialog->pplayer = pplayer;
@@ -231,27 +232,28 @@ struct spaceship_dialog *create_spaceship_dialog(struct player *pplayer)
   gui_dialog_add_button(pdialog->shell, NULL, _("_Launch"),
                         GTK_RESPONSE_ACCEPT);
 
-  g_signal_connect(pdialog->shell->grid, "destroy",
+  g_signal_connect(pdialog->shell->vbox, "destroy",
                    G_CALLBACK(spaceship_destroy_callback), pdialog);
   gui_dialog_response_set_callback(pdialog->shell, spaceship_response);
 
-  hgrid = gtk_grid_new();
-  gtk_grid_set_column_spacing(GTK_GRID(hgrid), 5);
-  gui_dialog_add_content_widget(pdialog->shell, hgrid);
+  hbox = gtk_grid_new();
+  gtk_grid_set_column_spacing(GTK_GRID(hbox), 5);
+  gtk_container_add(GTK_CONTAINER(pdialog->shell->vbox), hbox);
 
   frame = gtk_frame_new(NULL);
-  gtk_grid_attach(GTK_GRID(hgrid), frame, grid_col++, 0, 1, 1);
+  gtk_container_add(GTK_CONTAINER(hbox), frame);
 
   pdialog->image_canvas = gtk_drawing_area_new();
   gtk_widget_set_can_focus(pdialog->image_canvas, TRUE);
   get_spaceship_dimensions(&w, &h);
   gtk_widget_set_size_request(pdialog->image_canvas, w, h);
 
-  gtk_frame_set_child(GTK_FRAME(frame), pdialog->image_canvas);
+  gtk_widget_set_events(pdialog->image_canvas, GDK_EXPOSURE_MASK);
+  gtk_container_add(GTK_CONTAINER(frame), pdialog->image_canvas);
   gtk_widget_realize(pdialog->image_canvas);
 
-  gtk_drawing_area_set_draw_func(GTK_DRAWING_AREA(pdialog->image_canvas),
-                                 spaceship_image_canvas_draw, pdialog, NULL);
+  g_signal_connect(pdialog->image_canvas, "draw",
+                   G_CALLBACK(spaceship_image_canvas_expose), pdialog);
 
   pdialog->info_label = gtk_label_new(get_spaceship_descr(NULL));
 
@@ -259,7 +261,7 @@ struct spaceship_dialog *create_spaceship_dialog(struct player *pplayer)
   gtk_widget_set_halign(pdialog->info_label, GTK_ALIGN_START);
   gtk_widget_set_valign(pdialog->info_label, GTK_ALIGN_START);
 
-  gtk_grid_attach(GTK_GRID(hgrid), pdialog->info_label, grid_col++, 0, 1, 1);
+  gtk_container_add(GTK_CONTAINER(hbox), pdialog->info_label);
   gtk_widget_set_name(pdialog->info_label, "spaceship_label");
 
   dialog_list_prepend(dialog_list, pdialog);
