@@ -20,7 +20,7 @@
 #include "mem.h"
 #include "shared.h"
 
-/* client/gui-gtk-4.0 */
+/* client/gui-gtk-3.22 */
 #include "colors.h"
 #include "mapview.h"
 
@@ -50,10 +50,10 @@
   neighbor
 ****************************************************************************/
 struct sprite *crop_sprite(struct sprite *source,
-                           int x, int y,
-                           int width, int height,
-                           struct sprite *mask, int mask_offset_x, int mask_offset_y,
-                           float scale, bool smooth)
+			   int x, int y,
+			   int width, int height,
+			   struct sprite *mask, int mask_offset_x, int mask_offset_y,
+               float scale, bool smooth)
 {
   struct sprite *new = fc_malloc(sizeof(*new));
   cairo_t *cr;
@@ -65,7 +65,7 @@ struct sprite *crop_sprite(struct sprite *source,
   cr = cairo_create(new->surface);
   cairo_rectangle(cr, 0, 0, width, height);
   cairo_clip(cr);
-
+  
   cairo_set_source_surface(cr, source->surface, -x, -y);
   cairo_paint(cr);
   if (mask) {
@@ -91,7 +91,7 @@ struct sprite *create_sprite(int width, int height, struct color *pcolor)
   fc_assert_ret_val(pcolor != NULL, NULL);
 
   sprite->surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
-                                               width, height);
+         width, height);
 
   cr = cairo_create(sprite->surface);
   gdk_cairo_set_source_rgba(cr, &pcolor->color);
@@ -275,7 +275,7 @@ struct sprite *load_gfxfile(const char *filename, bool svgflag)
 /************************************************************************//**
   Free a sprite and all associated image data.
 ****************************************************************************/
-void free_sprite(struct sprite *s)
+void free_sprite(struct sprite * s)
 {
   if (s->surface != NULL) {
     cairo_surface_destroy(s->surface);
@@ -296,7 +296,7 @@ struct sprite *sprite_scale(struct sprite *src, int new_w, int new_h)
 
   get_sprite_dimensions(src, &width, &height);
 
-  new->surface = cairo_surface_create_similar(src->surface,
+  new->surface = cairo_surface_create_similar(src->surface, 
       CAIRO_CONTENT_COLOR_ALPHA, new_w, new_h);
 
   cr = cairo_create(new->surface);
@@ -318,7 +318,7 @@ struct sprite *sprite_scale(struct sprite *src, int new_w, int new_h)
   object/mask. The bounding box contains the border (pixel which have
   unset pixel as neighbors) pixel.
 ****************************************************************************/
-void sprite_get_bounding_box(struct sprite *sprite, int *start_x,
+void sprite_get_bounding_box(struct sprite * sprite, int *start_x,
                              int *start_y, int *end_x, int *end_y)
 {
   unsigned char *data = cairo_image_surface_get_data(sprite->surface);
@@ -335,46 +335,46 @@ void sprite_get_bounding_box(struct sprite *sprite, int *start_x,
 
   fc_assert(cairo_image_surface_get_format(sprite->surface) == CAIRO_FORMAT_ARGB32);
 
-  /* Parses mask image for the first column that contains a visible pixel */
+  /* parses mask image for the first column that contains a visible pixel */
   *start_x = -1;
   for (i = 0; i < width && *start_x == -1; i++) {
     for (j = 0; j < height; j++) {
       if (data[(j * width + i) * 4 + endian]) {
-        *start_x = i;
-        break;
+	*start_x = i;
+	break;
       }
     }
   }
 
-  /* Parses mask image for the last column that contains a visible pixel */
+  /* parses mask image for the last column that contains a visible pixel */
   *end_x = -1;
   for (i = width - 1; i >= *start_x && *end_x == -1; i--) {
     for (j = 0; j < height; j++) {
       if (data[(j * width + i) * 4 + endian]) {
-        *end_x = i;
-        break;
+	*end_x = i;
+	break;
       }
     }
   }
 
-  /* Parses mask image for the first row that contains a visible pixel */
+  /* parses mask image for the first row that contains a visible pixel */
   *start_y = -1;
   for (i = 0; i < height && *start_y == -1; i++) {
     for (j = *start_x; j <= *end_x; j++) {
       if (data[(i * width + j) * 4 + endian]) {
-        *start_y = i;
-        break;
+	*start_y = i;
+	break;
       }
     }
   }
 
-  /* Parses mask image for the last row that contains a visible pixel */
+  /* parses mask image for the last row that contains a visible pixel */
   *end_y = -1;
   for (i = height - 1; i >= *end_y && *end_y == -1; i--) {
     for (j = *start_x; j <= *end_x; j++) {
       if (data[(i * width + j) * 4 + endian]) {
-        *end_y = i;
-        break;
+	*end_y = i;
+	break;
       }
     }
   }
@@ -429,7 +429,7 @@ GdkPixbuf *surface_get_pixbuf(cairo_surface_t *surf, int width, int height)
   rowstride = gdk_pixbuf_get_rowstride(pb);
 
   tmpsurf = cairo_image_surface_create_for_data(pixels, CAIRO_FORMAT_ARGB32,
-                                                width, height, rowstride);
+						width, height, rowstride);
 
   cr = cairo_create(tmpsurf);
   cairo_save(cr);
@@ -520,48 +520,6 @@ GdkPixbuf *create_extra_pixbuf(const struct extra_type *pextra)
   return pixbuf;
 }
 
-/************************************************************************//**
-  Create a GtkPicture from cairo surface.
-****************************************************************************/
-GtkWidget *picture_new_from_surface(cairo_surface_t *surf)
-{
-  GdkPixbuf *pb;
-  GtkWidget *pic;
-
-  pb = surface_get_pixbuf(surf,
-                          cairo_image_surface_get_width(surf),
-                          cairo_image_surface_get_height(surf));
-
-  pic = gtk_picture_new_for_pixbuf(pb);
-  g_object_unref(pb);
-
-  return pic;
-}
-
-/************************************************************************//**
-  Set a GtkPicture from cairo surface.
-****************************************************************************/
-void picture_set_from_surface(GtkPicture *pic, cairo_surface_t *surf)
-{
-  GdkPixbuf *pb;
-  GdkTexture *texture;
-  GdkPaintable *empty;
-
-  pb = surface_get_pixbuf(surf,
-                          cairo_image_surface_get_width(surf),
-                          cairo_image_surface_get_height(surf));
-
-  /* Workaround to gtk bug that gtk_picture_set_paintable() does
-   * not work if the new paintable is of the same size as current */
-  empty = gdk_paintable_new_empty(1, 1);
-  gtk_picture_set_paintable(pic, empty);
-
-  texture = gdk_texture_new_for_pixbuf(pb);
-  gtk_picture_set_paintable(pic, GDK_PAINTABLE(texture));
-  g_object_unref(texture);
-  g_object_unref(pb);
-}
-
 /************************************************************************//**
   Return a sprite image of a number.
 ****************************************************************************/
