@@ -32,7 +32,7 @@
 /* client */
 #include "themes_common.h"
 
-/* gui-gtk-4.0 */
+/* gui-gtk-3.22 */
 #include "gui_main.h"
 
 #include "themes_g.h"
@@ -44,21 +44,26 @@ static GtkCssProvider *theme_provider = NULL;
 *****************************************************************************/
 void gui_load_theme(const char *directory, const char *theme_name)
 {
+  GError *error = NULL;
   char buf[strlen(directory) + strlen(theme_name) + 32];
 
   if (theme_provider == NULL) {
     theme_provider = gtk_css_provider_new();
-    gtk_style_context_add_provider_for_display(
-        gtk_widget_get_display(toplevel),
+    gtk_style_context_add_provider_for_screen(
+        gtk_widget_get_screen(toplevel),
         GTK_STYLE_PROVIDER(theme_provider),
         GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   }
 
-  /* Gtk theme is a directory containing gtk-4.0/gtk.css file */
-  fc_snprintf(buf, sizeof(buf), "%s/%s/gtk-4.0/gtk.css", directory,
+  /* Gtk theme is a directory containing gtk-3.0/gtk.css file */
+  fc_snprintf(buf, sizeof(buf), "%s/%s/gtk-3.0/gtk.css", directory,
               theme_name);
 
-  gtk_css_provider_load_from_path(theme_provider, buf);
+  gtk_css_provider_load_from_path(theme_provider, buf, &error);
+
+  if (error != NULL) {
+    g_warning("%s\n", error->message);
+  }
 }
 
 /*************************************************************************//**
@@ -79,10 +84,10 @@ void gui_clear_theme(void)
     }
   }
 
-  /* Still no theme loaded -> drop theme provider */
+  /* Still no theme loaded -> load system default theme */
   if (!theme_loaded && theme_provider != NULL) {
-    gtk_style_context_remove_provider_for_display(
-        gtk_widget_get_display(toplevel),
+    gtk_style_context_remove_provider_for_screen(
+        gtk_widget_get_screen(toplevel),
         GTK_STYLE_PROVIDER(theme_provider));
     theme_provider = NULL;
   }
@@ -90,7 +95,7 @@ void gui_clear_theme(void)
 
 /*************************************************************************//**
   Each gui has its own themes directories.
-  For gtk4 these are:
+  For gtk3.22 these are:
   - /usr/share/themes
   - ~/.themes
   Returns an array containing these strings and sets array size in count.
@@ -106,16 +111,16 @@ char **get_gui_specific_themes_directories(int *count)
 
   *count = 0;
 
-  /* Freeciv-specific GTK4 themes directories */
+  /* Freeciv-specific GTK3.22 themes directories */
   strvec_iterate(data_dirs, dir_name) {
-    char buf[strlen(dir_name) + strlen("/themes/gtk4") + 1];
+    char buf[strlen(dir_name) + strlen("/themes/gtk3.22") + 1];
 
-    fc_snprintf(buf, sizeof(buf), "%s/themes/gtk4", dir_name);
+    fc_snprintf(buf, sizeof(buf), "%s/themes/gtk3.22", dir_name);
 
     directories[(*count)++] = fc_strdup(buf);
   } strvec_iterate_end;
 
-  /* standard GTK themes directory */
+  /* standard GTK+ themes directory */
 #ifdef CROSSER
   standard_dir = "../share/themes";
 #else  /* CROSSER */
@@ -123,7 +128,7 @@ char **get_gui_specific_themes_directories(int *count)
 #endif /* CROSSER */
   directories[(*count)++] = fc_strdup(standard_dir);
 
-  /* user GTK themes directory (~/.themes) */
+  /* user GTK+ themes directory (~/.themes) */
   home_dir = user_home_dir();
   if (home_dir) {
     char buf[strlen(home_dir) + 16];
@@ -138,7 +143,7 @@ char **get_gui_specific_themes_directories(int *count)
 /*************************************************************************//**
   Return an array of names of usable themes in the given directory.
   Array size is stored in count.
-  Usable theme for gtk is a directory which contains file gtk-4.0/gtk.css.
+  Usable theme for gtk+ is a directory which contains file gtk-3.0/gtk.css.
   The caller is responsible for freeing the array and the names
 *****************************************************************************/
 char **get_usable_themes_in_directory(const char *directory, int *count)
@@ -163,20 +168,20 @@ char **get_usable_themes_in_directory(const char *directory, int *count)
     struct stat stat_result;
 
     fc_snprintf(buf, sizeof(buf),
-                "%s/%s/gtk-4.0/gtk.css", directory, entry->d_name);
+                "%s/%s/gtk-3.0/gtk.css", directory, entry->d_name);
 
     if (fc_stat(buf, &stat_result) != 0) {
       /* File doesn't exist */
       continue;
     }
-
+    
     if (!S_ISREG(stat_result.st_mode)) {
       /* Not a regular file */
       continue;
     }
-
+    
     /* Otherwise it's ok */
-
+    
     /* Increase array size if needed */
     if (*count == t_size) {
       theme_names = fc_realloc(theme_names, t_size * 2 * sizeof(char *));
