@@ -24,6 +24,7 @@
 #include "extras.h"
 #include "game.h"
 #include "movement.h"
+#include "nation.h"
 #include "unit.h"
 
 /* client */
@@ -144,7 +145,8 @@ bool select_tgt_extra(struct unit *actor, struct tile *ptile,
   lbl = gtk_label_new(actor_label);
   gtk_grid_attach(GTK_GRID(box), lbl, 0, 0, 1, 1);
 
-  spr = get_unittype_sprite(tileset, actor_type, direction8_invalid());
+  spr = get_unittype_sprite(tileset, actor_type,
+                            actor->activity, direction8_invalid());
   if (spr != NULL) {
     icon = gtk_image_new_from_pixbuf(sprite_get_pixbuf(spr));
   } else {
