@@ -20,8 +20,11 @@
 
 void popup_revolution_dialog(struct government *government);
 void message_dialog_button_set_sensitive(GtkWidget *shl, int button,
-					 gboolean state);
-gboolean taxrates_callback(GtkWidget *w, GdkEventButton *ev, gpointer data);
+                                         gboolean state);
+gboolean taxrates_callback(GtkGestureClick *gesture, int n_press,
+                           double x, double y);
+gboolean reverse_taxrates_callback(GtkGestureClick *gesture, int n_press,
+				   double x, double y);
 void nationset_sync_to_server(const char *nationset);
 
 #endif /* FC__DIALOGS_H */
