@@ -50,7 +50,7 @@
 #include "reqtree.h"
 #include "text.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-4.0 */
 #include "canvas.h"
 #include "cityrep.h"
 #include "dialogs.h"
@@ -74,7 +74,7 @@ struct science_report {
   GtkLabel *main_label;         /* Gets science_dialog_text(). */
   GtkProgressBar *progress_bar;
   GtkLabel *goal_label;
-  GtkLayout *drawing_area;
+  GtkDrawingArea *drawing_area;
 };
 
 static GtkListStore *science_report_store_new(void);
@@ -86,11 +86,15 @@ static bool science_report_combo_get_active(GtkComboBox *combo,
                                             char **name);
 static void science_report_combo_set_active(GtkComboBox *combo,
                                             Tech_type_id tech);
-static gboolean science_diagram_button_release_callback(GtkWidget *widget,
-    GdkEventButton *event, gpointer data);
-static gboolean science_diagram_update(GtkWidget *widget,
-                                       cairo_t *cr,
-                                       gpointer data);
+static gboolean science_diagram_left_button_up(GtkGestureClick *gesture,
+                                               int n_press,
+                                               double x, double y);
+static gboolean science_diagram_right_button_up(GtkGestureClick *gesture,
+                                                int n_press,
+                                                double x, double y);
+
+static void science_diagram_update(GtkDrawingArea *widget, cairo_t *cr,
+                                   int width, int height, gpointer data);
 static GtkWidget *science_diagram_new(void);
 static void science_diagram_data(GtkWidget *widget, bool show_all);
 static void science_diagram_center(GtkWidget *diagram, Tech_type_id tech);
@@ -166,6 +170,7 @@ static bool science_report_combo_get_active(GtkComboBox *combo,
                      SRD_COL_NAME, name,
                      SRD_COL_ID, tech,
                      -1);
+
   return TRUE;
 }
 
@@ -192,63 +197,96 @@ static void science_report_combo_set_active(GtkComboBox *combo,
 }
 
 /************************************************************************//**
-  Change tech goal, research or open help dialog.
+  Change tech goal or research.
 ****************************************************************************/
-static gboolean science_diagram_button_release_callback(GtkWidget *widget,
-    GdkEventButton *event, gpointer data)
+static gboolean science_diagram_left_button_up(GtkGestureClick *gesture,
+                                               int n_press,
+                                               double x, double y)
 {
-  const struct research *presearch = research_get(client_player());
-  struct reqtree *reqtree = g_object_get_data(G_OBJECT(widget), "reqtree");
-  Tech_type_id tech = get_tech_on_reqtree(reqtree, event->x, event->y);
+  GtkEventController *controller = GTK_EVENT_CONTROLLER(gesture);
+  GtkWidget *w = gtk_event_controller_get_widget(controller);
+  struct reqtree *reqtree = g_object_get_data(G_OBJECT(w), "reqtree");
+  Tech_type_id tech;
+
+  tech = get_tech_on_reqtree(reqtree, x, y);
 
   if (tech == A_NONE) {
     return TRUE;
   }
 
-  if (event->button == 3) {
-    /* RMB: get help */
-    popup_help_dialog_typed(research_advance_name_translation(presearch,
-                                                              tech),
-                            HELP_TECH);
-  } else {
-    if (event->button == 1 && can_client_issue_orders()) {
-      /* LMB: set research or research goal */
-      switch (research_invention_state(research_get(client_player()),
-                                       tech)) {
-       case TECH_PREREQS_KNOWN:
-         dsend_packet_player_research(&client.conn, tech);
-         break;
-       case TECH_UNKNOWN:
-         dsend_packet_player_tech_goal(&client.conn, tech);
-         break;
-       case TECH_KNOWN:
-         break;
-      }
+  if (can_client_issue_orders()) {
+    /* Set research or research goal */
+    switch (research_invention_state(research_get(client_player()),
+                                     tech)) {
+    case TECH_PREREQS_KNOWN:
+      dsend_packet_player_research(&client.conn, tech);
+      break;
+    case TECH_UNKNOWN:
+      dsend_packet_player_tech_goal(&client.conn, tech);
+      break;
+    case TECH_KNOWN:
+      break;
     }
   }
+
+  return TRUE;
+}
+
+/************************************************************************//**
+  Open tech help dialog.
+****************************************************************************/
+static gboolean science_diagram_right_button_up(GtkGestureClick *gesture,
+                                                int n_press,
+                                                double x, double y)
+{
+  const struct research *presearch;
+  GtkEventController *controller = GTK_EVENT_CONTROLLER(gesture);
+  GtkWidget *w = gtk_event_controller_get_widget(controller);
+  struct reqtree *reqtree = g_object_get_data(G_OBJECT(w), "reqtree");
+  Tech_type_id tech;
+
+  tech = get_tech_on_reqtree(reqtree, x, y);
+
+  if (tech == A_NONE) {
+    return TRUE;
+  }
+
+  presearch = research_get(client_player());
+
+  /* Open help */
+  popup_help_dialog_typed(research_advance_name_translation(presearch,
+                                                            tech),
+                          HELP_TECH);
+
   return TRUE;
 }
 
 /************************************************************************//**
   Draw the invalidated portion of the reqtree.
 ****************************************************************************/
-static gboolean science_diagram_update(GtkWidget *widget, cairo_t *cr, gpointer data)
+static void science_diagram_update(GtkDrawingArea *widget, cairo_t *cr,
+                                   int width, int height, gpointer data)
 {
   /* FIXME: this currently redraws everything! */
   struct canvas canvas = FC_STATIC_CANVAS_INIT;
   struct reqtree *reqtree = g_object_get_data(G_OBJECT(widget), "reqtree");
-  int width, height;
+  int rtwidth, rtheight;
   GtkAdjustment *hadjustment;
   GtkAdjustment *vadjustment;
   gint hadjustment_value;
   gint vadjustment_value;
+  GtkViewport *vp;
 
   if (!tileset_is_fully_loaded()) {
-    return TRUE;
+    return;
   }
 
-  hadjustment = gtk_scrollable_get_hadjustment(GTK_SCROLLABLE(widget));
-  vadjustment = gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(widget));
+  get_reqtree_dimensions(reqtree, &rtwidth, &rtheight);
+  gtk_widget_set_size_request(GTK_WIDGET(widget), rtwidth, rtheight);
+
+  vp = GTK_VIEWPORT(gtk_widget_get_parent(GTK_WIDGET(widget)));
+  hadjustment = gtk_scrollable_get_hadjustment(GTK_SCROLLABLE(vp));
+  vadjustment = gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(vp));
 
   hadjustment_value = (gint)gtk_adjustment_get_value(hadjustment);
   vadjustment_value = (gint)gtk_adjustment_get_value(vadjustment);
@@ -257,10 +295,7 @@ static gboolean science_diagram_update(GtkWidget *widget, cairo_t *cr, gpointer
 
   canvas.drawable = cr;
 
-  get_reqtree_dimensions(reqtree, &width, &height);
-  draw_reqtree(reqtree, &canvas, 0, 0, 0, 0, width, height);
-
-  return TRUE;
+  draw_reqtree(reqtree, &canvas, 0, 0, 0, 0, rtwidth, rtheight);
 }
 
 /************************************************************************//**
@@ -270,16 +305,23 @@ static gboolean science_diagram_update(GtkWidget *widget, cairo_t *cr, gpointer
 static GtkWidget *science_diagram_new(void)
 {
   GtkWidget *diagram;
+  GtkEventController *controller;
+  GtkGesture *gesture;
 
-  diagram = gtk_layout_new(NULL, NULL);
-  gtk_widget_add_events(diagram,
-                        GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-                        | GDK_BUTTON2_MOTION_MASK | GDK_BUTTON3_MOTION_MASK);
-  g_signal_connect(diagram, "draw",
-                   G_CALLBACK(science_diagram_update), NULL);
-  g_signal_connect(diagram, "button-release-event",
-                   G_CALLBACK(science_diagram_button_release_callback),
-                   NULL);
+  diagram = gtk_drawing_area_new();
+  gtk_drawing_area_set_draw_func(GTK_DRAWING_AREA(diagram),
+                                 science_diagram_update, NULL, NULL);
+
+  controller = GTK_EVENT_CONTROLLER(gtk_gesture_click_new());
+  g_signal_connect(controller, "released",
+                   G_CALLBACK(science_diagram_left_button_up), NULL);
+  gtk_widget_add_controller(diagram, controller);
+  gesture = gtk_gesture_click_new();
+  gtk_gesture_single_set_button(GTK_GESTURE_SINGLE(gesture), 3);
+  controller = GTK_EVENT_CONTROLLER(gesture);
+  g_signal_connect(controller, "released",
+                   G_CALLBACK(science_diagram_right_button_up), NULL);
+  gtk_widget_add_controller(diagram, controller);
 
   return diagram;
 }
@@ -290,7 +332,6 @@ static GtkWidget *science_diagram_new(void)
 static void science_diagram_data(GtkWidget *widget, bool show_all)
 {
   struct reqtree *reqtree;
-  int width, height;
 
   if (can_conn_edit(&client.conn)) {
     /* Show all techs in editor mode, not only currently reachable ones */
@@ -300,8 +341,6 @@ static void science_diagram_data(GtkWidget *widget, bool show_all)
     reqtree = create_reqtree(client_player(), show_all);
   }
 
-  get_reqtree_dimensions(reqtree, &width, &height);
-  gtk_layout_set_size(GTK_LAYOUT(widget), width, height);
   g_object_set_data_full(G_OBJECT(widget), "reqtree", reqtree,
                          (GDestroyNotify) destroy_reqtree);
 }
@@ -311,27 +350,23 @@ static void science_diagram_data(GtkWidget *widget, bool show_all)
 ****************************************************************************/
 static void science_diagram_center(GtkWidget *diagram, Tech_type_id tech)
 {
-  GtkScrolledWindow *sw = GTK_SCROLLED_WINDOW(gtk_widget_get_parent(diagram));
+  GtkViewport *vp = GTK_VIEWPORT(gtk_widget_get_parent(diagram));
   struct reqtree *reqtree;
   int x, y, width, height;
 
-  if (!GTK_IS_SCROLLED_WINDOW(sw)) {
-    return;
-  }
-
   reqtree = g_object_get_data(G_OBJECT(diagram), "reqtree");
   get_reqtree_dimensions(reqtree, &width, &height);
   if (find_tech_on_reqtree(reqtree, tech, &x, &y, NULL, NULL)) {
     GtkAdjustment *adjust = NULL;
     gdouble value;
 
-    adjust = gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(sw));
+    adjust = gtk_scrollable_get_hadjustment(GTK_SCROLLABLE(vp));
     value = (gtk_adjustment_get_lower(adjust)
       + gtk_adjustment_get_upper(adjust)
       - gtk_adjustment_get_page_size(adjust)) / width * x;
     gtk_adjustment_set_value(adjust, value);
 
-    adjust = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(sw));
+    adjust = gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(vp));
     value = (gtk_adjustment_get_lower(adjust)
       + gtk_adjustment_get_upper(adjust)
       - gtk_adjustment_get_page_size(adjust)) / height * y;
@@ -405,7 +440,7 @@ static void science_report_update(struct science_report *preport)
   text = get_science_target_text(&pct);
   gtk_progress_bar_set_text(preport->progress_bar, text);
   gtk_progress_bar_set_fraction(preport->progress_bar, pct);
-  /* Work around GTK+ refresh bug? */
+  /* Work around GTK refresh bug? */
   gtk_widget_queue_resize(GTK_WIDGET(preport->progress_bar));
 
   /* Update reachable techs. */
@@ -527,7 +562,7 @@ static void science_report_current_callback(GtkComboBox *combo,
     return;
   }
 
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data))) {
+  if (gtk_check_button_get_active(GTK_CHECK_BUTTON(data))) {
     popup_help_dialog_typed(tech_name, HELP_TECH);
   } else if (can_client_issue_orders()) {
     dsend_packet_player_research(&client.conn, tech);
@@ -562,7 +597,7 @@ static void science_report_goal_callback(GtkComboBox *combo, gpointer data)
     return;
   }
 
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data))) {
+  if (gtk_check_button_get_active(GTK_CHECK_BUTTON(data))) {
     popup_help_dialog_typed(tech_name, HELP_TECH);
   } else if (can_client_issue_orders()) {
     dsend_packet_player_tech_goal(&client.conn, tech);
@@ -581,7 +616,6 @@ static void science_report_init(struct science_report *preport)
 {
   GtkWidget *frame, *table, *help_button, *show_all_button, *sw, *w;
   GtkSizeGroup *group;
-  GtkContainer *vbox;
   GtkListStore *store;
   GtkCellRenderer *renderer;
 
@@ -593,22 +627,20 @@ static void science_report_init(struct science_report *preport)
 
   gui_dialog_add_button(preport->shell, "window-close", _("_Close"),
                         GTK_RESPONSE_CLOSE);
-  gui_dialog_set_default_response(preport->shell, GTK_RESPONSE_CLOSE);
 
-  vbox = GTK_CONTAINER(preport->shell->vbox);
   group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
   w = gtk_label_new(NULL);
-  gtk_container_add(vbox, w);
+  gui_dialog_add_content_widget(preport->shell, w);
   preport->main_label = GTK_LABEL(w);
 
   /* Current research target line. */
   frame = gtk_frame_new(_("Researching"));
-  gtk_container_add(vbox, frame);
+  gui_dialog_add_content_widget(preport->shell, frame);
 
   table = gtk_grid_new();
   gtk_grid_set_column_spacing(GTK_GRID(table), 4);
-  gtk_container_add(GTK_CONTAINER(frame), table);
+  gtk_frame_set_child(GTK_FRAME(frame), table);
 
   help_button = gtk_check_button_new_with_label(_("Help"));
   gtk_grid_attach(GTK_GRID(table), help_button, 5, 0, 1, 1);
@@ -636,11 +668,11 @@ static void science_report_init(struct science_report *preport)
 
   /* Research goal line. */
   frame = gtk_frame_new( _("Goal"));
-  gtk_container_add(vbox, frame);
+  gui_dialog_add_content_widget(preport->shell, frame);
 
   table = gtk_grid_new();
   gtk_grid_set_column_spacing(GTK_GRID(table), 4);
-  gtk_container_add(GTK_CONTAINER(frame),table);
+  gtk_frame_set_child(GTK_FRAME(frame), table);
 
   store = science_report_store_new();
   w = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
@@ -677,16 +709,16 @@ static void science_report_init(struct science_report *preport)
   preport->button_show_all = show_all_button;
 
   /* Science diagram. */
-  sw = gtk_scrolled_window_new(NULL, NULL);
+  sw = gtk_scrolled_window_new();
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(vbox, sw);
+  gui_dialog_add_content_widget(preport->shell, sw);
 
   w = science_diagram_new();
   gtk_widget_set_hexpand(w, TRUE);
   gtk_widget_set_vexpand(w, TRUE);
-  gtk_container_add(GTK_CONTAINER(sw), w);
-  preport->drawing_area = GTK_LAYOUT(w);
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), w);
+  preport->drawing_area = GTK_DRAWING_AREA(w);
 
   science_report_update(preport);
   gui_dialog_show_all(preport->shell);
@@ -1013,10 +1045,10 @@ static void economy_report_command_callback(struct gui_dialog *pdialog,
         setup_dialog(shell, gui_dialog_get_toplevel(pdialog));
         gtk_window_set_title(GTK_WINDOW(shell), _("Sell Improvements"));
 
-        if (GTK_RESPONSE_YES == gtk_dialog_run(GTK_DIALOG(shell))) {
+        if (GTK_RESPONSE_YES == blocking_dialog(shell)) {
           sell_all_improvements(pimprove, redundant, buf, sizeof(buf));
         }
-        gtk_widget_destroy(shell);
+        gtk_window_destroy(GTK_WINDOW(shell));
       }
     }
     break;
@@ -1025,6 +1057,7 @@ static void economy_report_command_callback(struct gui_dialog *pdialog,
       if (ERD_RES_DISBAND_UNITS == response) {
         const struct unit_type *putype = selected.value.utype;
         gint count;
+
         gtk_tree_model_get(model, &iter, ERD_COL_COUNT, &count, -1);
 
         shell = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL
@@ -1039,10 +1072,10 @@ static void economy_report_command_callback(struct gui_dialog *pdialog,
         setup_dialog(shell, gui_dialog_get_toplevel(pdialog));
         gtk_window_set_title(GTK_WINDOW(shell), _("Disband Units"));
 
-        if (GTK_RESPONSE_YES == gtk_dialog_run(GTK_DIALOG(shell))) {
+        if (GTK_RESPONSE_YES == blocking_dialog(shell)) {
           disband_all_units(putype, FALSE, buf, sizeof(buf));
         }
-        gtk_widget_destroy(shell);
+        gtk_window_destroy(GTK_WINDOW(shell));
       }
     }
     break;
@@ -1055,7 +1088,7 @@ static void economy_report_command_callback(struct gui_dialog *pdialog,
                                    GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
                                    "%s", buf);
     setup_dialog(shell, gui_dialog_get_toplevel(pdialog));
-    g_signal_connect(shell, "response", G_CALLBACK(gtk_widget_destroy),
+    g_signal_connect(shell, "response", G_CALLBACK(gtk_window_destroy),
                      NULL);
     gtk_window_set_title(GTK_WINDOW(shell), _("Sell-Off: Results"));
     gtk_window_present(GTK_WINDOW(shell));
@@ -1119,7 +1152,6 @@ static void economy_report_init(struct economy_report *preport)
   GtkWidget *view, *sw, *label, *button;
   GtkListStore *store;
   GtkTreeSelection *selection;
-  GtkContainer *vbox;
   const char *title;
   enum economy_report_columns i;
 
@@ -1127,15 +1159,13 @@ static void economy_report_init(struct economy_report *preport)
 
   gui_dialog_new(&preport->shell, GTK_NOTEBOOK(top_notebook), preport, TRUE);
   gui_dialog_set_title(preport->shell, _("Economy"));
-  vbox = GTK_CONTAINER(preport->shell->vbox);
 
-  sw = gtk_scrolled_window_new(NULL, NULL);
+  sw = gtk_scrolled_window_new();
   gtk_widget_set_halign(sw, GTK_ALIGN_CENTER);
-  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                      GTK_SHADOW_ETCHED_IN);
+  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(GTK_CONTAINER(vbox), sw);
+  gui_dialog_add_content_widget(preport->shell, sw);
 
   store = economy_report_store_new();
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -1143,7 +1173,7 @@ static void economy_report_init(struct economy_report *preport)
   g_object_unref(store);
   gtk_widget_set_name(view, "small_font");
   gtk_tree_view_columns_autosize(GTK_TREE_VIEW(view));
-  gtk_container_add(GTK_CONTAINER(sw), view);
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
   preport->tree_view = GTK_TREE_VIEW(view);
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
@@ -1190,7 +1220,7 @@ static void economy_report_init(struct economy_report *preport)
   }
 
   label = gtk_label_new(NULL);
-  gtk_container_add(vbox, label);
+  gui_dialog_add_content_widget(preport->shell, label);
   gtk_widget_set_margin_start(label, 5);
   gtk_widget_set_margin_end(label, 5);
   gtk_widget_set_margin_top(label, 5);
@@ -1212,7 +1242,6 @@ static void economy_report_init(struct economy_report *preport)
                                  ERD_RES_SELL_REDUNDANT);
   gtk_widget_set_sensitive(button, FALSE);
 
-  gui_dialog_set_default_response(preport->shell, GTK_RESPONSE_CLOSE);
   gui_dialog_response_set_callback(preport->shell,
                                    economy_report_command_callback);
 
@@ -1355,7 +1384,7 @@ static GtkListStore *units_report_store_new(void)
   for (i = 0; i < URD_COL_NUM; i++) {
     cols[i] = unit_report_columns[i].type;
   }
-  
+
   return gtk_list_store_newv(URD_COL_NUM, cols);
 }
 
@@ -1439,7 +1468,7 @@ static void units_report_update(struct units_report *preport)
 
     upgradable = client_has_player()
                  && NULL != can_upgrade_unittype(client_player(), utype);
-    
+
     gtk_list_store_append(store, &iter);
     gtk_list_store_set(store, &iter,
                        URD_COL_UTYPE_NAME, utype_name_translation(utype),
@@ -1639,11 +1668,11 @@ static void units_report_command_callback(struct gui_dialog *pdialog,
 
     gtk_window_set_title(GTK_WINDOW(shell), _("Upgrade Obsolete Units"));
 
-    if (GTK_RESPONSE_YES == gtk_dialog_run(GTK_DIALOG(shell))) {
+    if (GTK_RESPONSE_YES == blocking_dialog(shell)) {
       dsend_packet_unit_type_upgrade(&client.conn, utype_number(utype));
     }
 
-    gtk_widget_destroy(shell);
+    gtk_window_destroy(GTK_WINDOW(shell));
   }
 }
 
@@ -1655,7 +1684,6 @@ static void units_report_init(struct units_report *preport)
   GtkWidget *view, *sw, *button;
   GtkListStore *store;
   GtkTreeSelection *selection;
-  GtkContainer *vbox;
   GtkTreeViewColumn *col = NULL;
   enum units_report_columns i;
 
@@ -1663,15 +1691,13 @@ static void units_report_init(struct units_report *preport)
 
   gui_dialog_new(&preport->shell, GTK_NOTEBOOK(top_notebook), preport, TRUE);
   gui_dialog_set_title(preport->shell, _("Units"));
-  vbox = GTK_CONTAINER(preport->shell->vbox);
 
-  sw = gtk_scrolled_window_new(NULL,NULL);
+  sw = gtk_scrolled_window_new();
   gtk_widget_set_halign(sw, GTK_ALIGN_CENTER);
-  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                      GTK_SHADOW_ETCHED_IN);
+  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(GTK_CONTAINER(vbox), sw);
+  gui_dialog_add_content_widget(preport->shell, sw);
 
   store = units_report_store_new();
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
@@ -1679,7 +1705,7 @@ static void units_report_init(struct units_report *preport)
   g_object_unref(store);
   gtk_widget_set_name(view, "small_font");
   gtk_tree_view_columns_autosize(GTK_TREE_VIEW(view));
-  gtk_container_add(GTK_CONTAINER(sw), view);
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
   preport->tree_view = GTK_TREE_VIEW(view);
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
@@ -1691,11 +1717,12 @@ static void units_report_init(struct units_report *preport)
 
     if (strlen(unit_report_columns[i].title) > 0) {
       GtkWidget *header = gtk_label_new(Q_(unit_report_columns[i].title));
+
       if (unit_report_columns[i].tooltip) {
         gtk_widget_set_tooltip_text(header,
                                     Q_(unit_report_columns[i].tooltip));
       }
-      gtk_widget_show(header);
+      gtk_widget_set_visible(header, TRUE);
       col = gtk_tree_view_column_new();
       gtk_tree_view_column_set_widget(col, header);
       if (unit_report_columns[i].rightalign) {
@@ -1738,7 +1765,6 @@ static void units_report_init(struct units_report *preport)
                                  _("Find _Nearest"), URD_RES_NEAREST);
   gtk_widget_set_sensitive(button, FALSE);
 
-  gui_dialog_set_default_response(preport->shell, GTK_RESPONSE_CLOSE);
   gui_dialog_response_set_callback(preport->shell,
                                    units_report_command_callback);
 
@@ -1957,16 +1983,15 @@ static void endgame_report_init(struct endgame_report *preport)
   gui_dialog_set_default_size(preport->shell, 700, 420);
 
   /* Setup the layout. */
-  sw = gtk_scrolled_window_new(NULL, NULL);
-  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                      GTK_SHADOW_ETCHED_IN);
+  sw = gtk_scrolled_window_new();
+  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-  gtk_container_add(GTK_CONTAINER(preport->shell->vbox), sw);
+  gui_dialog_add_content_widget(preport->shell, sw);
 
   view = gtk_tree_view_new();
   gtk_widget_set_name(view, "small_font");
-  gtk_container_add(GTK_CONTAINER(sw), view);
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
   preport->tree_view = GTK_TREE_VIEW(view);
 
   if (preport->shell->type == GUI_DIALOG_TAB) {
