@@ -35,7 +35,7 @@
 #include "tilespec.h"
 #include "unitselect_common.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-4.0 */
 #include "graphics.h"
 #include "gui_stuff.h"
 #include "gui_main.h"
@@ -152,7 +152,7 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
                              const char *title,
                              enum unit_select_location_mode loc);
 static GtkTreeStore *usdlg_tab_store_new(void);
-static bool usdlg_tab_update(struct unit_select_dialog *pdialog, 
+static bool usdlg_tab_update(struct unit_select_dialog *pdialog,
                              struct usdata_hash *ushash,
                              enum unit_select_location_mode loc);
 static void usdlg_tab_append_utype(GtkTreeStore *store,
@@ -177,7 +177,7 @@ static void usdlg_cmd_sentry(GObject *object, gpointer data);
 static void usdlg_cmd_select(GObject *object, gpointer data);
 static void usdlg_cmd_deselect(GObject *object, gpointer data);
 static void usdlg_cmd_exec(GObject *object, gpointer mode_data,
-			   enum usdlg_cmd cmd);
+                           enum usdlg_cmd cmd);
 static void usdlg_cmd_exec_unit(struct unit *punit, enum usdlg_cmd cmd);
 static void usdlg_cmd_center(GObject *object, gpointer data);
 static void usdlg_cmd_focus(GObject *object, gpointer data);
@@ -200,7 +200,7 @@ void unit_select_dialog_popup_main(struct tile *ptile, bool create)
   /* Present the unit selection dialog if it exists. */
   if (pdialog) {
     /* Show all. */
-    gtk_widget_show_all(GTK_WIDGET(pdialog->shell));
+    gtk_widget_set_visible(GTK_WIDGET(pdialog->shell), TRUE);
     /* Update tile. */
     usdlg_tile(pdialog, ptile);
     /* Refresh data and hide unused tabs. */
@@ -256,7 +256,6 @@ static struct unit_select_dialog *usdlg_create(void)
   setup_dialog(pdialog->shell, toplevel);
   g_signal_connect(pdialog->shell, "destroy",
                    G_CALLBACK(usdlg_destroy_callback), pdialog);
-  gtk_window_set_position(GTK_WINDOW(pdialog->shell), GTK_WIN_POS_MOUSE);
   gtk_widget_realize(pdialog->shell);
 
   vbox = gtk_dialog_get_content_area(GTK_DIALOG(pdialog->shell));
@@ -265,7 +264,7 @@ static struct unit_select_dialog *usdlg_create(void)
   pdialog->notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(pdialog->notebook),
                            GTK_POS_BOTTOM);
-  gtk_box_pack_start(GTK_BOX(vbox), pdialog->notebook, TRUE, TRUE, 0);
+  gtk_box_insert_child_after(GTK_BOX(vbox), pdialog->notebook, NULL);
 
   /* Append pages. */
   usdlg_tab_select(pdialog, _("_Units"), SELLOC_UNITS);
@@ -293,7 +292,7 @@ static struct unit_select_dialog *usdlg_create(void)
 static void usdlg_destroy(void)
 {
   if (unit_select_dlg) {
-    gtk_widget_destroy(GTK_WIDGET(unit_select_dlg->shell));
+    gtk_window_destroy(GTK_WINDOW(unit_select_dlg->shell));
     free(unit_select_dlg);
   }
   unit_select_dlg = NULL;
@@ -353,9 +352,9 @@ static void usdlg_refresh(struct unit_select_dialog *pdialog)
     bool show = usdlg_tab_update(pdialog, ushash, loc);
 
     if (!show) {
-      gtk_widget_hide(pdialog->tabs[loc].page);
+      gtk_widget_set_visible(pdialog->tabs[loc].page, FALSE);
     } else {
-      gtk_widget_show(pdialog->tabs[loc].page);
+      gtk_widget_set_visible(pdialog->tabs[loc].page, TRUE);
 
       if (pdialog->tabs[loc].path) {
         gtk_tree_view_expand_row(GTK_TREE_VIEW(pdialog->tabs[loc].view),
@@ -367,6 +366,7 @@ static void usdlg_refresh(struct unit_select_dialog *pdialog)
       }
     }
   }
+
   /* Destroy the hash. */
   usdlg_data_destroy(ushash);
 }
@@ -388,22 +388,28 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
                              const char *title,
                              enum unit_select_location_mode loc)
 {
-  GtkWidget *page, *label, *hbox, *vbox, *view, *sw;
+  GtkWidget *page, *label, *hgrid, *vgrid, *view, *sw;
   GtkTreeStore *store;
   static bool titles_done;
   int i;
+  int page_row = 0;
+  int grid_col = 0;
+  int grid_row = 0;
 
   page = gtk_grid_new();
   gtk_orientable_set_orientation(GTK_ORIENTABLE(page),
                                  GTK_ORIENTATION_VERTICAL);
-  gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+  gtk_widget_set_margin_start(page, 8);
+  gtk_widget_set_margin_end(page, 8);
+  gtk_widget_set_margin_top(page, 8);
+  gtk_widget_set_margin_bottom(page, 8);
   pdialog->tabs[loc].page = page;
 
   label = gtk_label_new_with_mnemonic(title);
   gtk_notebook_append_page(GTK_NOTEBOOK(pdialog->notebook), page, label);
 
-  hbox = gtk_grid_new();
-  gtk_container_add(GTK_CONTAINER(page), hbox);
+  hgrid = gtk_grid_new();
+  gtk_grid_attach(GTK_GRID(page), hgrid, 0, page_row++, 1, 1);
 
   store = usdlg_tab_store_new();
   pdialog->tabs[loc].store = store;
@@ -455,26 +461,26 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
     gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
   }
 
-  sw = gtk_scrolled_window_new(NULL, NULL);
+  sw = gtk_scrolled_window_new();
   gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 300);
-  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                      GTK_SHADOW_ETCHED_IN);
+  gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(sw), TRUE);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(GTK_CONTAINER(sw), view);
-  gtk_container_add(GTK_CONTAINER(hbox), sw);
+  gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(sw), view);
+  gtk_grid_attach(GTK_GRID(hgrid), sw, grid_col++, 0, 1, 1);
 
-  vbox = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
+  vgrid = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vgrid),
                                  GTK_ORIENTATION_VERTICAL);
-  gtk_container_add(GTK_CONTAINER(hbox), vbox);
+  gtk_grid_attach(GTK_GRID(hgrid), vgrid, grid_col++, 0, 1, 1);
 
   /* button box 1: ready, sentry */
 
   pdialog->tabs[loc].cmd[USDLG_CMD_READY]
     = gtk_button_new_with_mnemonic(_("Ready"));
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_READY]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_READY],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_READY], "clicked",
                    G_CALLBACK(usdlg_cmd_ready), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -484,8 +490,9 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
     = gtk_button_new_with_mnemonic(_("Sentry"));
   gtk_widget_set_margin_bottom(
     GTK_WIDGET(pdialog->tabs[loc].cmd[USDLG_CMD_SENTRY]), 10);
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_SENTRY]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_SENTRY],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_SENTRY], "clicked",
                    G_CALLBACK(usdlg_cmd_sentry), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -495,8 +502,9 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
 
   pdialog->tabs[loc].cmd[USDLG_CMD_SELECT]
     = gtk_button_new_with_mnemonic(_("_Select"));
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_SELECT]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_SELECT],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_SELECT], "clicked",
                    G_CALLBACK(usdlg_cmd_select), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -506,8 +514,9 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
     = gtk_button_new_with_mnemonic(_("_Deselect"));
   gtk_widget_set_margin_bottom(
     GTK_WIDGET(pdialog->tabs[loc].cmd[USDLG_CMD_DESELECT]), 10);
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_DESELECT]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_DESELECT],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_DESELECT], "clicked",
                    G_CALLBACK(usdlg_cmd_deselect), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -517,8 +526,9 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
 
   pdialog->tabs[loc].cmd[USDLG_CMD_CENTER]
     = gtk_button_new_with_mnemonic(_("C_enter"));
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_CENTER]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_CENTER],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_CENTER], "clicked",
                    G_CALLBACK(usdlg_cmd_center), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -526,8 +536,9 @@ static void usdlg_tab_select(struct unit_select_dialog *pdialog,
 
   pdialog->tabs[loc].cmd[USDLG_CMD_FOCUS]
     = gtk_button_new_with_mnemonic(_("_Focus"));
-  gtk_container_add(GTK_CONTAINER(vbox),
-                    pdialog->tabs[loc].cmd[USDLG_CMD_FOCUS]);
+  gtk_grid_attach(GTK_GRID(vgrid),
+                  pdialog->tabs[loc].cmd[USDLG_CMD_FOCUS],
+                  0, grid_row++, 1, 1);
   g_signal_connect(pdialog->tabs[loc].cmd[USDLG_CMD_FOCUS], "clicked",
                    G_CALLBACK(usdlg_cmd_focus), GINT_TO_POINTER(loc));
   gtk_widget_set_sensitive(
@@ -1001,7 +1012,7 @@ static void usdlg_cmd_exec(GObject *object, gpointer mode_data,
       ushash = usdlg_data_new(pdialog->ptile);
 
       usdata_hash_lookup(ushash, utid, &data);
-      if (data != NULL 
+      if (data != NULL
           && unit_list_size(data->units[loc][act]) != 0) {
         unit_list_iterate(data->units[loc][act], punit) {
           usdlg_cmd_exec_unit(punit, cmd);
