@@ -36,7 +36,7 @@
 
 #ifdef FC_QT5_MODE
 #include <QTextCodec>
-#endif /* FC_QT5_MODE */
+#endif // FC_QT5_MODE
 
 #include <QTextEdit>
 
@@ -73,7 +73,7 @@ fc_client::fc_client() : QMainWindow()
 
 #ifdef FC_QT5_MODE
   QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));
-#endif /* FC_QT5_MODE */
+#endif // FC_QT5_MODE
   /**
    * Somehow freeciv-client-common asks to switch to page when all widgets
    * haven't been created yet by Qt, even constructor finished job,
@@ -376,7 +376,7 @@ void fc_client::switch_page(int new_pg)
       setWindowFlags(Qt::Window | Qt::CustomizeWindowHint);
     }
     showMaximized();
-    /* For MS Windows, it might ignore first */
+    // For MS Windows, it might ignore first
     showMaximized();
     gui()->infotab->chtwdg->update_widgets();
     status_bar->setVisible(false);
@@ -413,7 +413,7 @@ void fc_client::switch_page(int new_pg)
     break;
   default:
     if (client.conn.used) {
-      disconnect_from_server();
+      disconnect_from_server(TRUE);
     }
     set_client_page(PAGE_MAIN);
     break;
@@ -537,7 +537,7 @@ void fc_client::quit()
 void fc_client::slot_disconnect()
 {
   if (client.conn.used) {
-    disconnect_from_server();
+    disconnect_from_server(TRUE);
   }
 
   switch_page(PAGE_MAIN);
@@ -870,7 +870,7 @@ void fc_client::popdown_unit_sel()
 ****************************************************************************/
 void fc_client::remove_repo_dlg(QString str)
 {
-  /* if app is closing opened_repo_dlg is already deleted */
+  // If app is closing, opened_repo_dlg is already deleted */
   if (!is_closing()) {
     opened_repo_dlgs.remove(str);
   }
@@ -1022,14 +1022,14 @@ QIcon fc_icons::get_icon(const QString &id)
   QByteArray png_bytes;
 
   str = QString("themes") + DIR_SEPARATOR + "gui-qt" + DIR_SEPARATOR;
-  /* Try custom icon from theme */
+  // Try custom icon from theme
   pn_bytes = str.toUtf8();
   png_bytes = QString(pn_bytes.data() + current_theme + DIR_SEPARATOR
                       + id + ".png").toUtf8();
   icon.addFile(fileinfoname(get_data_dirs(),
                             png_bytes.data()));
   str = str + "icons" + DIR_SEPARATOR;
-  /* Try icon from icons dir */
+  // Try icon from icons dir
   if (icon.isNull()) {
     pn_bytes = str.toUtf8();
     png_bytes = QString(pn_bytes.data() + id + ".png").toUtf8();
@@ -1147,7 +1147,7 @@ void fc_game_tab_widget::current_changed(int index)
   currentWidget()->hide();
   widget(index)->show();
 
-  /* Set focus to map instead sidebar */
+  // Set focus to map instead sidebar
   if (gui()->mapview_wdg && gui()->current_page() == PAGE_GAME
       && index == 0) {
     gui()->mapview_wdg->setFocus();
@@ -1240,7 +1240,7 @@ void pregame_options::set_rulesets(int num_rulesets, char **rulesets)
     }
   }
 
-  /* HACK: server should tell us the current ruleset. */
+  // HACK: server should tell us the current ruleset.
   cruleset->setCurrentIndex(def_idx);
   cruleset->blockSignals(false);
 }
@@ -1316,7 +1316,7 @@ void pregame_options::ailevel_change(int i)
   if (v.isValid()) {
     enum ai_level k = static_cast<ai_level>(v.toInt());
 
-    /* Suppress changes provoked by server rather than local user */
+    // Suppress changes provoked by server rather than local user
     if (server_ai_level() != k) {
       const char *name = ai_level_cmd(k);
 
