@@ -582,9 +582,9 @@ void plr_widget::nation_selected(const QItemSelection &sl,
     egold = _("(Unknown)");
     egov = _("(Unknown)");
   }
-  /** Formatting rich text */
+  // Formatting rich text
   intel_str =
-    /* TRANS: this and similar literal strings interpreted as (Qt) HTML */
+    // TRANS: this and similar literal strings interpreted as (Qt) HTML
     QString("<table><tr><td><b>") + _("Nation") + QString("</b></td><td>")
     + QString(nation_adjective_for_player(pplayer)).toHtmlEscaped()
     + QString("</td><tr><td><b>") + _("Ruler:") + QString("</b></td><td>")
@@ -657,7 +657,7 @@ void plr_widget::nation_selected(const QItemSelection &sl,
                         .toHtmlEscaped());
       techs_unknown = QString(_("<b>Techs unknown by you :</b>"));
 
-      advance_iterate(A_FIRST, padvance) {
+      advance_iterate(padvance) {
         tech_id = advance_number(padvance);
         if (research_invention_state(my_research, tech_id) == TECH_KNOWN
             && (research_invention_state(research, tech_id) 
@@ -702,7 +702,7 @@ void plr_widget::nation_selected(const QItemSelection &sl,
   } else {
     tech_str = QString(_("<b>Techs known by %1:</b>")).
                arg(QString(nation_plural_for_player(pplayer)).toHtmlEscaped());
-    advance_iterate(A_FIRST, padvance) {
+    advance_iterate(padvance) {
       tech_id = advance_number(padvance);
       if (research_invention_state(research, tech_id) == TECH_KNOWN) {
         sorted_list_a << research_advance_name_translation(research, tech_id);
@@ -722,6 +722,9 @@ void plr_widget::nation_selected(const QItemSelection &sl,
   case WV_NEVER:
     rule = _("Small Wonders not known");
     break;
+  case WV_EMBASSY:
+    rule = _("Small Wonders visible if we have an embassy");
+    break;
   }
 
   wonder_str = "<b>"
@@ -824,12 +827,28 @@ plr_report::plr_report():QWidget()
   withdraw_but->setText(_("Withdraw Vision"));
   toggle_ai_but = new QPushButton;
   toggle_ai_but->setText(_("AI Mode"));
+
   show_relations = new QPushButton;
-  show_relations->setText(_("Hide Relations"));
+  if (gui_options.gui_qt_show_relations_panel) {
+    show_relations->setText(_("Hide Relations"));
+  } else {
+    show_relations->setText(_("Show Relations"));
+  }
+
   show_techs = new QPushButton;
-  show_techs->setText(_("Hide Techs"));
+  if (gui_options.gui_qt_show_techs_panel) {
+    show_techs->setText(_("Hide Techs"));
+  } else {
+    show_techs->setText(_("Show Techs"));
+  }
+
   show_wonders = new QPushButton;
-  show_wonders->setText(_("Hide Wonders"));
+  if (gui_options.gui_qt_show_wonders_panel) {
+    show_wonders->setText(_("Hide Wonders"));
+  } else {
+    show_wonders->setText(_("Show Wonders"));
+  }
+
   meet_but->setDisabled(true);
   cancel_but->setDisabled(true);
   withdraw_but->setDisabled(true);
@@ -838,6 +857,9 @@ plr_report::plr_report():QWidget()
   h_splitter->addWidget(ally_label);
   h_splitter->addWidget(tech_label);
   h_splitter->addWidget(wonder_label);
+  ally_label->setVisible(gui_options.gui_qt_show_relations_panel);
+  tech_label->setVisible(gui_options.gui_qt_show_techs_panel);
+  wonder_label->setVisible(gui_options.gui_qt_show_wonders_panel);
   v_splitter->addWidget(h_splitter);
   layout->addWidget(v_splitter);
   hlayout->addWidget(meet_but);
@@ -911,8 +933,14 @@ void plr_report::req_caancel_threaty()
 **************************************************************************/
 void plr_report::req_meeeting()
 {
-  dsend_packet_diplomacy_init_meeting_req(&client.conn,
-                                          player_number(other_player));
+  struct Treaty *ptreaty = find_treaty(client_player(), other_player);
+
+  if (ptreaty != nullptr) {
+    qtg_init_meeting(ptreaty, other_player, client_player());
+  } else {
+    dsend_packet_diplomacy_init_meeting_req(&client.conn,
+                                            player_number(other_player));
+  }
 }
 
 /**********************************************************************//**
@@ -988,9 +1016,11 @@ void plr_report::show_relations_toggle()
   if (ally_label->isVisible()) {
     ally_label->hide();
     show_relations->setText(_("Show Relations"));
+    gui_options.gui_qt_show_relations_panel = FALSE;
   } else {
     ally_label->show();
     show_relations->setText(_("Hide Relations"));
+    gui_options.gui_qt_show_relations_panel = TRUE;
   }
 }
 
@@ -1002,9 +1032,11 @@ void plr_report::show_techs_toggle()
   if (tech_label->isVisible()) {
     tech_label->hide();
     show_techs->setText(_("Show Techs"));
+    gui_options.gui_qt_show_techs_panel = FALSE;
   } else {
     tech_label->show();
     show_techs->setText(_("Hide Techs"));
+    gui_options.gui_qt_show_techs_panel = TRUE;
   }
 }
 
@@ -1016,9 +1048,11 @@ void plr_report::show_wonders_toggle()
   if (wonder_label->isVisible()) {
     wonder_label->hide();
     show_wonders->setText(_("Show Wonders"));
+    gui_options.gui_qt_show_wonders_panel = FALSE;
   } else {
     wonder_label->show();
     show_wonders->setText(_("Hide Wonders"));
+    gui_options.gui_qt_show_wonders_panel = TRUE;
   }
 }
 
@@ -1060,7 +1094,7 @@ void plr_report::update_report(bool update_selection)
     plr_wdg->get_model()->populate();
   }
 
-  /* Force updating selected player information */
+  // Force updating selected player information
   if (update_selection) {
     qmi = plr_wdg->currentIndex();
     if (qmi.isValid()) {
