@@ -60,6 +60,7 @@ void setup_gui_funcs()
   funcs->canvas_copy = qtg_canvas_copy;
   funcs->canvas_put_sprite = qtg_canvas_put_sprite;
   funcs->canvas_put_sprite_full = qtg_canvas_put_sprite_full;
+  funcs->canvas_put_sprite_full_scaled = qtg_canvas_put_sprite_full_scaled;
   funcs->canvas_put_sprite_fogged = qtg_canvas_put_sprite_fogged;
   funcs->canvas_put_rectangle = qtg_canvas_put_rectangle;
   funcs->canvas_fill_sprite_area = qtg_canvas_fill_sprite_area;
@@ -112,6 +113,18 @@ void setup_gui_funcs()
 
   funcs->gui_load_theme = qtg_gui_load_theme;
   funcs->gui_clear_theme = qtg_gui_clear_theme;
-  funcs->get_gui_specific_themes_directories = qtg_get_gui_specific_themes_directories;
+  funcs->get_gui_specific_themes_directories
+    = qtg_get_gui_specific_themes_directories;
   funcs->get_usable_themes_in_directory = qtg_get_usable_themes_in_directory;
+
+  funcs->gui_init_meeting = qtg_init_meeting;
+  funcs->gui_recv_cancel_meeting = qtg_recv_cancel_meeting;
+  funcs->gui_prepare_clause_updt = qtg_prepare_clause_updt;
+  funcs->gui_recv_create_clause = qtg_recv_create_clause;
+  funcs->gui_recv_remove_clause = qtg_recv_remove_clause;
+  funcs->gui_recv_accept_treaty = qtg_recv_accept_treaty;
+
+  funcs->request_action_confirmation = qtg_request_action_confirmation;
+
+  funcs->popup_image = qtg_popup_image;
 }
