@@ -41,7 +41,7 @@ void qtg_real_output_window_append(const char *astring,
 
 bool qtg_is_view_supported(enum ts_type type);
 void qtg_tileset_type_set(enum ts_type type);
-struct sprite *qtg_load_gfxfile(const char *filename);
+struct sprite *qtg_load_gfxfile(const char *filename, bool svgflag);
 struct sprite *qtg_load_gfxnumber(int num);
 struct sprite *qtg_create_sprite(int width, int height, struct color *pcolor);
 void qtg_get_sprite_dimensions(struct sprite *sprite, int *width, int *height);
@@ -70,6 +70,10 @@ void qtg_canvas_put_sprite(struct canvas *pcanvas,
 void qtg_canvas_put_sprite_full(struct canvas *pcanvas,
                                 int canvas_x, int canvas_y,
                                 struct sprite *sprite);
+void qtg_canvas_put_sprite_full_scaled(struct canvas *pcanvas,
+                                       int canvas_x, int canvas_y,
+                                       int canvas_w, int canvas_h,
+                                       struct sprite *sprite);
 void qtg_canvas_put_sprite_fogged(struct canvas *pcanvas,
                                   int canvas_x, int canvas_y,
                                   struct sprite *psprite,
@@ -142,4 +146,18 @@ void qtg_gui_clear_theme();
 char **qtg_get_gui_specific_themes_directories(int *count);
 char **qtg_get_usable_themes_in_directory(const char *directory, int *count);
 
-#endif /* FC__QTG_CXXSIDE_H */
+void qtg_init_meeting(struct Treaty *ptreaty, struct player *they,
+                      struct player *initiator);
+void qtg_recv_cancel_meeting(struct Treaty *ptreaty, struct player *they,
+                             struct player *initiator);
+void qtg_prepare_clause_updt(struct Treaty *ptreaty, struct player *they);
+void qtg_recv_create_clause(struct Treaty *ptreaty, struct player *they);
+void qtg_recv_remove_clause(struct Treaty *ptreaty, struct player *they);
+void qtg_recv_accept_treaty(struct Treaty *ptreaty, struct player *they);
+
+void qtg_request_action_confirmation(const char *expl,
+                                     struct act_confirmation_data *data);
+
+void qtg_popup_image(const char *tag);
+
+#endif // FC__QTG_CXXSIDE_H
