@@ -182,9 +182,9 @@ void tilespec_setup_city_icons(void)
   load_city_icon_surface(spr, big_colb, "city.colb");
   load_city_icon_surface(spr, pBIG_Face, "city.red_face");
   load_city_icon_surface(spr, big_coin_corr, "city.dark_coin");
-  load_city_icon_surface(spr, big_coin_upkeep, "city.unkeep_coin");
+  load_city_icon_surface(spr, big_coin_upkeep, "city.upkeep_coin");
 
-  /* small icon */
+  /* Small icon */
   load_city_icon_surface(spr, food, "city.small_food");
   load_city_icon_surface(spr, shield, "city.small_shield");
   load_city_icon_surface(spr, trade, "city.small_trade");
@@ -217,7 +217,7 @@ void tilespec_setup_city_icons(void)
 
   /* ================================================================= */
 
-  /* force reload citizens icons */
+  /* Force reload citizens icons */
   icons->style = 999;
 }
 
@@ -347,8 +347,7 @@ void tilespec_setup_theme(void)
   load_order_theme_surface(buf, o_unload_icon, "theme.order_unload");
   load_order_theme_surface(buf, o_wait_icon, "theme.order_wait");
   load_order_theme_surface(buf, o_fortress_icon, "theme.order_build_fortress");
-  load_order_theme_surface(buf, o_fallout_icon, "theme.order_clean_fallout");
-  load_order_theme_surface(buf, o_pollution_icon, "theme.order_clean_pollution");
+  load_order_theme_surface(buf, o_clean_icon, "theme.order_clean");
   load_order_theme_surface(buf, o_airbase_icon, "theme.order_build_airbase");
   load_order_theme_surface(buf, o_transform_icon, "theme.order_transform");
   load_order_theme_surface(buf, OAddCity_Icon, "theme.order_add_to_city");
