@@ -383,7 +383,7 @@ void popup_impr_info(Impr_type_id impr)
   widget_add_as_prev(impr_name_label, dock);
   dock = impr_name_label;
 
-  if (!improvement_has_flag(pimpr_type, IF_GOLD)) {
+  if (!is_convert_improvement(pimpr_type)) {
     sprintf(buffer, "%s %d", _("Base Cost:"),
             impr_base_build_shield_cost(pimpr_type));
     cost_label = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
@@ -543,7 +543,7 @@ void popup_impr_info(Impr_type_id impr)
 
   start_y = impr_name_label->size.y + impr_name_label->size.h + adj_size(10);
 
-  if (!improvement_has_flag(pimpr_type, IF_GOLD)) {
+  if (!is_convert_improvement(pimpr_type)) {
     cost_label = impr_name_label->prev;
     widget_set_position(cost_label, start_x, start_y);
     if (!is_wonder(pimpr_type)) {
@@ -654,6 +654,7 @@ void popup_unit_info(Unit_type_id type_id)
   struct unit_type *punittype;
   char buffer[bufsz];
   SDL_Rect area;
+  struct advance *req;
 
   if (current_help_dlg != HELP_UNIT) {
     popdown_help_dialog();
@@ -801,11 +802,10 @@ void popup_unit_info(Unit_type_id type_id)
 
   punittype = utype_by_number(type_id);
   unit_name_label
-    = create_iconlabel_from_chars_fonto(
-                  adj_surf(get_unittype_surface(punittype,
-                                                direction8_invalid())),
-                  pwindow->dst, utype_name_translation(punittype),
-                  FONTO_MAX, WF_FREE_THEME);
+    = create_iconlabel_from_chars_fonto(adj_surf(get_unittype_surface(punittype,
+                                                                      direction8_invalid())),
+                                        pwindow->dst, utype_name_translation(punittype),
+                                        FONTO_MAX, WF_FREE_THEME);
 
   unit_name_label->id = ID_LABEL;
   widget_add_as_prev(unit_name_label, dock);
@@ -870,20 +870,23 @@ void popup_unit_info(Unit_type_id type_id)
   widget_add_as_prev(requirement_label, dock);
   dock = requirement_label;
 
-  if (A_NEVER == punittype->require_advance
-      || advance_by_number(A_NONE) == punittype->require_advance) {
+  req = utype_primary_tech_req(punittype);
+
+  if (advance_number(req) == A_NONE) {
     requirement_label2 = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
                                                            Q_("?tech:None"),
                                                            FONTO_ATTENTION, 0);
     requirement_label2->id = ID_LABEL;
   } else {
+    Tech_type_id req_id = advance_number(req);
+
     requirement_label2
       = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
-                                          advance_name_translation(punittype->require_advance),
+                                          advance_name_translation(req),
                                           FONTO_ATTENTION,
                                           WF_RESTORE_BACKGROUND);
-    requirement_label2->id = MAX_ID - advance_number(punittype->require_advance);
-    requirement_label2->string_utf8->fgcol = *get_tech_color(advance_number(punittype->require_advance));
+    requirement_label2->id = MAX_ID - req_id;
+    requirement_label2->string_utf8->fgcol = *get_tech_color(req_id);
     requirement_label2->action = change_tech_callback;
     set_wstate(requirement_label2, FC_WS_NORMAL);
   }
@@ -906,14 +909,16 @@ void popup_unit_info(Unit_type_id type_id)
     obsolete_by_label2->id = ID_LABEL;
   } else {
     const struct unit_type *utype = punittype->obsoleted_by;
+    struct advance *obs_req = utype_primary_tech_req(utype);
 
-    obsolete_by_label2 = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
-                                                           utype_name_translation(utype),
-                                                           FONTO_ATTENTION,
-                                                           WF_RESTORE_BACKGROUND);
+    obsolete_by_label2
+      = create_iconlabel_from_chars_fonto(NULL, pwindow->dst,
+                                          utype_name_translation(utype),
+                                          FONTO_ATTENTION,
+                                          WF_RESTORE_BACKGROUND);
     obsolete_by_label2->string_utf8->fgcol
-      = *get_tech_color(advance_number(utype->require_advance));
-    obsolete_by_label2->id = MAX_ID - utype_number(punittype->obsoleted_by);
+      = *get_tech_color(advance_number(obs_req));
+    obsolete_by_label2->id = MAX_ID - utype_number(utype);
     obsolete_by_label2->action = change_unit_callback;
     set_wstate(obsolete_by_label2, FC_WS_NORMAL);
   }
@@ -925,7 +930,8 @@ void popup_unit_info(Unit_type_id type_id)
   start_x = (area.x + 1 + scrollbar_width + help_dlg->active_widget_list->size.w + adj_size(20));
 
   buffer[0] = '\0';
-  helptext_unit(buffer, sizeof(buffer), client.conn.playing, "", utype_by_number(type_id));
+  helptext_unit(buffer, sizeof(buffer), client.conn.playing, "", utype_by_number(type_id),
+                TRUE);
   if (buffer[0] != '\0') {
     utf8_str *ustr = create_utf8_from_char_fonto(buffer, FONTO_ATTENTION);
 
@@ -1280,7 +1286,7 @@ static struct widget *create_tech_info(Tech_type_id tech, int width,
 
   unit_count = 0;
   unit_type_iterate(un) {
-    if (advance_number(un->require_advance) == tech) {
+    if (is_tech_req_for_utype(un, advance_by_number(tech))) {
       pwidget = create_iconlabel_from_chars_fonto(
                                    resize_surface_box(get_unittype_surface(un, direction8_invalid()),
                                    adj_size(48), adj_size(48), 1, TRUE, TRUE),
