@@ -1100,7 +1100,7 @@ void get_overview_area_dimensions(int *width, int *height)
   */
   int overview_tile_size_bak = OVERVIEW_TILE_SIZE;  
   int xfact = MAP_IS_ISOMETRIC ? 2 : 1;
-  int shift = (MAP_IS_ISOMETRIC && !current_topo_has_flag(TF_WRAPX)) ? -1 : 0;
+  int shift = (MAP_IS_ISOMETRIC && !current_wrap_has_flag(WRAP_X)) ? -1 : 0;
 
   OVERVIEW_TILE_SIZE = MIN((DEFAULT_OVERVIEW_W - 1) / (wld.map.xsize * xfact),
                            (DEFAULT_OVERVIEW_H - 1) / wld.map.ysize) + 1;
