@@ -15,18 +15,7 @@
 #include <fc_config.h>
 #endif
 
-/* gui main header */
-#include "gui_stub.h"
-
 /* client */
 #include "options.h"
 
 #include "messagedlg.h"
-
-/**********************************************************************//**
-  Popup a window to let the user edit their message options.
-**************************************************************************/
-void popup_messageopt_dialog(void)
-{
-  /* PORTME */
-}
