@@ -19,6 +19,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 /* common */
+#include "diptreaty.h"
 #include "fc_types.h"
 #include "featured_text.h"
 #include "tile.h"
@@ -30,6 +31,8 @@ extern "C" {
 /* client */
 #include "tilespec.h"
 
+struct act_confirmation_data;
+
 struct gui_funcs {
   void (*ui_init)(void);
   int (*ui_main)(int argc, char *argv[]);
@@ -45,7 +48,7 @@ struct gui_funcs {
 
   bool (*is_view_supported)(enum ts_type type);
   void (*tileset_type_set)(enum ts_type type);
-  struct sprite * (*load_gfxfile)(const char *filename);
+  struct sprite * (*load_gfxfile)(const char *filename, bool svgflag);
   struct sprite * (*load_gfxnumber)(int num);
   struct sprite * (*create_sprite)(int width, int height, struct color *pcolor);
   void (*get_sprite_dimensions)(struct sprite *sprite, int *width, int *height);
@@ -74,6 +77,10 @@ struct gui_funcs {
   void (*canvas_put_sprite_full)(struct canvas *pcanvas,
                                  int canvas_x, int canvas_y,
                                  struct sprite *psprite);
+  void (*canvas_put_sprite_full_scaled)(struct canvas *pcanvas,
+                                        int canvas_x, int canvas_y,
+                                        int canvas_w, int canvas_h,
+                                        struct sprite *psprite);
   void (*canvas_put_sprite_fogged)(struct canvas *pcanvas,
                                    int canvas_x, int canvas_y,
                                    struct sprite *psprite,
@@ -145,6 +152,20 @@ struct gui_funcs {
   void (*gui_clear_theme)(void);
   char **(*get_gui_specific_themes_directories)(int *count);
   char **(*get_usable_themes_in_directory)(const char *directory, int *count);
+
+  void (*gui_init_meeting)(struct Treaty *ptreaty, struct player *they,
+                           struct player *initiator);
+  void (*gui_recv_cancel_meeting)(struct Treaty *ptreaty, struct player *they,
+                                  struct player *initiator);
+  void (*gui_prepare_clause_updt)(struct Treaty *ptreaty, struct player *they);
+  void (*gui_recv_create_clause)(struct Treaty *ptreaty, struct player *they);
+  void (*gui_recv_remove_clause)(struct Treaty *ptreaty, struct player *they);
+  void (*gui_recv_accept_treaty)(struct Treaty *ptreaty, struct player *they);
+
+  void (*request_action_confirmation)(const char *expl,
+                                      struct act_confirmation_data *data);
+
+  void (*popup_image)(const char *tag);
 };
 
 struct gui_funcs *get_gui_funcs(void);
