@@ -1,12 +1,9 @@
-
- /****************************************************************************
- *                       THIS FILE WAS GENERATED                             *
- * Script: common/generate_packets.py                                        *
- * Input:  common/networking/packets.def                                     *
- *                       DO NOT CHANGE THIS FILE                             *
- ****************************************************************************/
-
-
+ /**************************************************************************
+ *                         THIS FILE WAS GENERATED                         *
+ * Script: common/generate_packets.py                                      *
+ * Input:  common/networking/packets.def                                   *
+ *                         DO NOT CHANGE THIS FILE                         *
+ **************************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
@@ -29,19 +26,11 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     return TRUE;
 
   case PACKET_INVESTIGATE_STARTED:
-    handle_investigate_started(
-      ((const struct packet_investigate_started *)packet)->unit_id16,
-      ((const struct packet_investigate_started *)packet)->unit_id32,
-      ((const struct packet_investigate_started *)packet)->city_id16,
-      ((const struct packet_investigate_started *)packet)->city_id32);
+    handle_investigate_started(packet);
     return TRUE;
 
   case PACKET_INVESTIGATE_FINISHED:
-    handle_investigate_finished(
-      ((const struct packet_investigate_finished *)packet)->unit_id16,
-      ((const struct packet_investigate_finished *)packet)->unit_id32,
-      ((const struct packet_investigate_finished *)packet)->city_id16,
-      ((const struct packet_investigate_finished *)packet)->city_id32);
+    handle_investigate_finished(packet);
     return TRUE;
 
   case PACKET_SERVER_JOIN_REPLY:
@@ -90,10 +79,7 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     return TRUE;
 
   case PACKET_MAP_INFO:
-    handle_map_info(
-      ((const struct packet_map_info *)packet)->xsize,
-      ((const struct packet_map_info *)packet)->ysize,
-      ((const struct packet_map_info *)packet)->topology_id);
+    handle_map_info(packet);
     return TRUE;
 
   case PACKET_NUKE_TILE_INFO:
@@ -138,8 +124,7 @@ bool client_handle_packet(enum packet_type type, const void *packet)
 
   case PACKET_CITY_REMOVE:
     handle_city_remove(
-      ((const struct packet_city_remove *)packet)->city_id16,
-      ((const struct packet_city_remove *)packet)->city_id32);
+      ((const struct packet_city_remove *)packet)->city_id);
     return TRUE;
 
   case PACKET_CITY_INFO:
@@ -150,6 +135,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_city_nationalities(packet);
     return TRUE;
 
+  case PACKET_CITY_UPDATE_COUNTERS:
+    handle_city_update_counters(packet);
+    return TRUE;
+
   case PACKET_CITY_SHORT_INFO:
     handle_city_short_info(packet);
     return TRUE;
@@ -160,13 +149,17 @@ bool client_handle_packet(enum packet_type type, const void *packet)
 
   case PACKET_CITY_NAME_SUGGESTION_INFO:
     handle_city_name_suggestion_info(
-      ((const struct packet_city_name_suggestion_info *)packet)->unit_id16,
-      ((const struct packet_city_name_suggestion_info *)packet)->unit_id32,
+      ((const struct packet_city_name_suggestion_info *)packet)->unit_id,
       ((const struct packet_city_name_suggestion_info *)packet)->name);
     return TRUE;
 
   case PACKET_CITY_SABOTAGE_LIST:
-    handle_city_sabotage_list(packet);
+    handle_city_sabotage_list(
+      ((const struct packet_city_sabotage_list *)packet)->actor_id,
+      ((const struct packet_city_sabotage_list *)packet)->city_id,
+      ((const struct packet_city_sabotage_list *)packet)->improvements,
+      ((const struct packet_city_sabotage_list *)packet)->act_id,
+      ((const struct packet_city_sabotage_list *)packet)->request_kind);
     return TRUE;
 
   case PACKET_CITY_RALLY_POINT:
@@ -205,8 +198,7 @@ bool client_handle_packet(enum packet_type type, const void *packet)
 
   case PACKET_UNIT_REMOVE:
     handle_unit_remove(
-      ((const struct packet_unit_remove *)packet)->unit_id16,
-      ((const struct packet_unit_remove *)packet)->unit_id32);
+      ((const struct packet_unit_remove *)packet)->unit_id);
     return TRUE;
 
   case PACKET_UNIT_INFO:
@@ -222,7 +214,12 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     return TRUE;
 
   case PACKET_UNIT_ACTION_ANSWER:
-    handle_unit_action_answer(packet);
+    handle_unit_action_answer(
+      ((const struct packet_unit_action_answer *)packet)->actor_id,
+      ((const struct packet_unit_action_answer *)packet)->target_id,
+      ((const struct packet_unit_action_answer *)packet)->cost,
+      ((const struct packet_unit_action_answer *)packet)->action_type,
+      ((const struct packet_unit_action_answer *)packet)->request_kind);
     return TRUE;
 
   case PACKET_UNIT_ACTIONS:
@@ -412,6 +409,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_ruleset_building(packet);
     return TRUE;
 
+  case PACKET_RULESET_IMPR_FLAG:
+    handle_ruleset_impr_flag(packet);
+    return TRUE;
+
   case PACKET_RULESET_TERRAIN:
     handle_ruleset_terrain(packet);
     return TRUE;
@@ -468,6 +469,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_ruleset_action_auto(packet);
     return TRUE;
 
+  case PACKET_RULESET_COUNTER:
+    handle_ruleset_counter(packet);
+    return TRUE;
+
   case PACKET_RULESET_MUSIC:
     handle_ruleset_music(packet);
     return TRUE;
@@ -537,7 +542,8 @@ bool client_handle_packet(enum packet_type type, const void *packet)
 
   case PACKET_SET_TOPOLOGY:
     handle_set_topology(
-      ((const struct packet_set_topology *)packet)->topology_id);
+      ((const struct packet_set_topology *)packet)->topology_id,
+      ((const struct packet_set_topology *)packet)->wrap_id);
     return TRUE;
 
   case PACKET_RULESET_EFFECT:
@@ -581,6 +587,11 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_vote_resolve *)packet)->passed);
     return TRUE;
 
+  case PACKET_EDIT_FOGOFWAR_STATE:
+    handle_edit_fogofwar_state(
+      ((const struct packet_edit_fogofwar_state *)packet)->enabled);
+    return TRUE;
+
   case PACKET_EDIT_STARTPOS:
     handle_edit_startpos(packet);
     return TRUE;
@@ -600,24 +611,14 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_play_music *)packet)->tag);
     return TRUE;
 
-  case PACKET_WEB_CITY_INFO_ADDITION:
-    handle_web_city_info_addition(
-      ((const struct packet_web_city_info_addition *)packet)->id16,
-      ((const struct packet_web_city_info_addition *)packet)->id32,
-      ((const struct packet_web_city_info_addition *)packet)->granary_size,
-      ((const struct packet_web_city_info_addition *)packet)->granary_turns);
+  case PACKET_POPUP_IMAGE:
+    handle_popup_image(
+      ((const struct packet_popup_image *)packet)->tag);
     return TRUE;
 
-  case PACKET_WEB_PLAYER_INFO_ADDITION:
-    handle_web_player_info_addition(
-      ((const struct packet_web_player_info_addition *)packet)->playerno,
-      ((const struct packet_web_player_info_addition *)packet)->expected_income);
-    return TRUE;
-
-  case PACKET_WEB_RULESET_UNIT_ADDITION:
-    handle_web_ruleset_unit_addition(
-      ((const struct packet_web_ruleset_unit_addition *)packet)->id,
-      ((const struct packet_web_ruleset_unit_addition *)packet)->utype_actions);
+  case PACKET_SYNC_SERIAL_REPLY:
+    handle_sync_serial_reply(
+      ((const struct packet_sync_serial_reply *)packet)->serial);
     return TRUE;
 
   default:
