@@ -76,6 +76,7 @@
 #include "chatline_common.h"
 #include "chatline_g.h"
 #include "client_main.h"
+#include "options.h"
 #include "servers.h"
 
 #include "gui_main_g.h"
@@ -119,6 +120,8 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
   int nservers, i, j;
   const char *latest_ver;
   const char *comment;
+  char *followtag;
+  char *q_followtag;
 
   /* Have the string outside Q_() so it won't get collected for translation here.
    * Actual collected string lives in translations/Strings.txt */
@@ -129,8 +132,16 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
     return NULL;
   }
 
-  latest_ver = secfile_lookup_str_default(file, NULL, "versions." FOLLOWTAG);
-  comment = secfile_lookup_str_default(file, NULL, "version_comments." FOLLOWTAG);
+  if (fc_strcasecmp(DEFAULT_FOLLOWTAG_OPTION, gui_options.followtag_override)) {
+    followtag = gui_options.followtag_override;
+    q_followtag = gui_options.followtag_override;
+  } else {
+    followtag = FOLLOWTAG;
+    q_followtag = QUALIFIED_FOLLOWTAG;
+  }
+
+  latest_ver = secfile_lookup_str_default(file, NULL, "versions.%s", followtag);
+  comment = secfile_lookup_str_default(file, NULL, "version_comments.%s", followtag);
 
   if (latest_ver == NULL && comment == NULL) {
     char vertext[2048];
@@ -139,7 +150,7 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
                 /* TRANS: Type is version tag name like "stable", "S3_2",
                  * "windows" (which can also be localised -- msgids start
                  * '?vertag:') */
-                _("There's no %s release yet."), Q_(QUALIFIED_FOLLOWTAG));
+                _("There's no %s release yet."), Q_(q_followtag));
     log_verbose("%s", vertext);
     version_message(vertext);
   } else {
@@ -147,8 +158,8 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
       const char *my_comparable = fc_comparable_version();
       char vertext[2048];
 
-      log_verbose("Metaserver says latest '" FOLLOWTAG "' version is '%s'; we have '%s'",
-                  latest_ver, my_comparable);
+      log_verbose("Metaserver says latest '%s' version is '%s'; we have '%s'",
+                  followtag, latest_ver, my_comparable);
       if (cvercmp_greater(latest_ver, my_comparable)) {
 
         fc_snprintf(vertext, sizeof(vertext),
@@ -156,20 +167,20 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
                      * "windows" (which can also be localised -- msgids start
                      * '?vertag:') */
                     _("Latest %s release of Freeciv is %s, this is %s."),
-                    Q_(QUALIFIED_FOLLOWTAG), latest_ver, my_comparable);
+                    Q_(q_followtag), latest_ver, my_comparable);
 
         version_message(vertext);
       } else if (comment == NULL) {
         fc_snprintf(vertext, sizeof(vertext),
                     _("There is no newer %s release of Freeciv available."),
-                    FOLLOWTAG);
+                    followtag);
 
         version_message(vertext);
       }
     }
 
     if (comment != NULL) {
-      log_verbose("Mesaserver comment about '" FOLLOWTAG "': %s", comment);
+      log_verbose("Mesaserver comment about '%s': %s", followtag, comment);
       version_message(comment);
     }
   }
@@ -258,11 +269,11 @@ static bool meta_read_response(struct server_scan *scan)
     return FALSE;
   }
 
-  /* parse message body */
-  fc_allocate_mutex(&scan->srvrs.mutex);
+  /* Parse message body */
+  fc_mutex_allocate(&scan->srvrs.mutex);
   srvrs = parse_metaserver_data(f);
   scan->srvrs.servers = srvrs;
-  fc_release_mutex(&scan->srvrs.mutex);
+  fc_mutex_release(&scan->srvrs.mutex);
 
   /* 'f' (hence 'meta.mem.mem') was closed in parse_metaserver_data(). */
   scan->meta.mem.mem = NULL;
@@ -288,21 +299,21 @@ static void metaserver_scan(void *arg)
   struct server_scan *scan = arg;
 
   if (!begin_metaserver_scan(scan)) {
-    fc_allocate_mutex(&scan->meta.mutex);
+    fc_mutex_allocate(&scan->meta.mutex);
     scan->meta.status = SCAN_STATUS_ERROR;
   } else {
     if (!meta_read_response(scan)) {
-      fc_allocate_mutex(&scan->meta.mutex);
+      fc_mutex_allocate(&scan->meta.mutex);
       scan->meta.status = SCAN_STATUS_ERROR;
     } else {
-      fc_allocate_mutex(&scan->meta.mutex);
+      fc_mutex_allocate(&scan->meta.mutex);
       if (scan->meta.status == SCAN_STATUS_WAITING) {
         scan->meta.status = SCAN_STATUS_DONE;
       }
     }
   }
 
-  fc_release_mutex(&scan->meta.mutex);
+  fc_mutex_release(&scan->meta.mutex);
 }
 
 /**********************************************************************//**
@@ -592,9 +603,9 @@ static bool begin_lanserver_scan(struct server_scan *scan)
 
   fc_closesocket(send_sock);
 
-  fc_allocate_mutex(&scan->srvrs.mutex);
+  fc_mutex_allocate(&scan->srvrs.mutex);
   scan->srvrs.servers = server_list_new();
-  fc_release_mutex(&scan->srvrs.mutex);
+  fc_mutex_release(&scan->srvrs.mutex);
 
   return TRUE;
 }
@@ -692,7 +703,7 @@ get_lan_server_list(struct server_scan *scan)
     }
 
     /* UDP can send duplicate or delayed packets. */
-    fc_allocate_mutex(&scan->srvrs.mutex);
+    fc_mutex_allocate(&scan->srvrs.mutex);
     server_list_iterate(scan->srvrs.servers, aserver) {
       if (0 == fc_strcasecmp(aserver->host, servername)
           && aserver->port == port) {
@@ -702,7 +713,7 @@ get_lan_server_list(struct server_scan *scan)
     } server_list_iterate_end;
 
     if (duplicate) {
-      fc_release_mutex(&scan->srvrs.mutex);
+      fc_mutex_release(&scan->srvrs.mutex);
       continue;
     }
 
@@ -720,7 +731,7 @@ get_lan_server_list(struct server_scan *scan)
     found_new = TRUE;
 
     server_list_prepend(scan->srvrs.servers, pserver);
-    fc_release_mutex(&scan->srvrs.mutex);
+    fc_mutex_release(&scan->srvrs.mutex);
   }
 
   if (found_new) {
@@ -757,7 +768,7 @@ struct server_scan *server_scan_begin(enum server_scan_type type,
   scan->type = type;
   scan->error_func = error_func;
   scan->sock = -1;
-  fc_init_mutex(&scan->srvrs.mutex);
+  fc_mutex_init(&scan->srvrs.mutex);
 
   switch (type) {
   case SERVER_SCAN_GLOBAL:
@@ -765,7 +776,7 @@ struct server_scan *server_scan_begin(enum server_scan_type type,
 #ifdef FREECIV_META_ENABLED
       int thr_ret;
 
-      fc_init_mutex(&scan->meta.mutex);
+      fc_mutex_init(&scan->meta.mutex);
       scan->meta.status = SCAN_STATUS_WAITING;
       thr_ret = fc_thread_start(&scan->meta.thr, metaserver_scan, scan);
       if (thr_ret) {
@@ -830,9 +841,9 @@ enum server_scan_status server_scan_poll(struct server_scan *scan)
     {
       enum server_scan_status status;
 
-      fc_allocate_mutex(&scan->meta.mutex);
+      fc_mutex_allocate(&scan->meta.mutex);
       status = scan->meta.status;
-      fc_release_mutex(&scan->meta.mutex);
+      fc_mutex_release(&scan->meta.mutex);
 
       return status;
     }
@@ -874,13 +885,13 @@ void server_scan_finish(struct server_scan *scan)
   if (scan->type == SERVER_SCAN_GLOBAL) {
 #ifdef FREECIV_META_ENABLED
     /* Signal metaserver scan thread to stop */
-    fc_allocate_mutex(&scan->meta.mutex);
+    fc_mutex_allocate(&scan->meta.mutex);
     scan->meta.status = SCAN_STATUS_ABORT;
-    fc_release_mutex(&scan->meta.mutex);
+    fc_mutex_release(&scan->meta.mutex);
 
     /* Wait thread to stop */
     fc_thread_wait(&scan->meta.thr);
-    fc_destroy_mutex(&scan->meta.mutex);
+    fc_mutex_destroy(&scan->meta.mutex);
 
     /* This mainly duplicates code from below "else" block.
      * That's intentional, since they will be completely different in future versions.
@@ -891,10 +902,10 @@ void server_scan_finish(struct server_scan *scan)
     }
 
     if (scan->srvrs.servers) {
-      fc_allocate_mutex(&scan->srvrs.mutex);
+      fc_mutex_allocate(&scan->srvrs.mutex);
       delete_server_list(scan->srvrs.servers);
       scan->srvrs.servers = NULL;
-      fc_release_mutex(&scan->srvrs.mutex);
+      fc_mutex_release(&scan->srvrs.mutex);
     }
 
     if (scan->meta.mem.mem) {
@@ -914,7 +925,7 @@ void server_scan_finish(struct server_scan *scan)
     }
   }
 
-  fc_destroy_mutex(&scan->srvrs.mutex);
+  fc_mutex_destroy(&scan->srvrs.mutex);
 
   free(scan);
 }
