@@ -21,10 +21,11 @@ extern "C" {
 /* common */
 #include "fc_types.h"
 
+struct civ_map;
 
 struct player *player_leading_spacerace(void);
 int player_distance_to_player(struct player *pplayer, struct player *target);
-int city_gold_worth(struct city *pcity);
+int city_gold_worth(const struct civ_map *nmap, struct city *pcity);
 
 #ifdef __cplusplus
 }
