@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#include "fc_types.h"
+struct tile;
 
 bool is_border_source(struct tile *ptile);
 int tile_border_source_radius_sq(struct tile *ptile);
@@ -28,4 +28,4 @@ int tile_border_strength(struct tile *ptile, struct tile *source);
 }
 #endif /* __cplusplus */
 
-#endif  /* FC__BORDERS_H */
+#endif /* FC__BORDERS_H */
