@@ -24,15 +24,15 @@ extern "C" {
 /* common */
 #include "fc_types.h"
 #include "name_translation.h"
-#include "improvement.h"
 #include "tile.h"
 #include "traderoutes.h"
-#include "unit.h"
-#include "unitlist.h"
-#include "vision.h"
 #include "workertask.h"
 #include "worklist.h"
 
+struct impr_type;
+struct unit;
+struct unit_list;
+struct vision;
 struct packet_city_rally_point;
 
 enum production_class_type {
@@ -42,8 +42,8 @@ enum production_class_type {
   PCT_LAST
 };
 
-/* Various city options.  These are stored by the server and can be
- * toggled by the user.  Each one defaults to off.  Adding new ones
+/* Various city options. These are stored by the server and can be
+ * toggled by the user. Each one defaults to off. Adding new ones
  * will break network compatibility. If you want to reorder or remove
  * an option remember to load the city option order from the savegame.
  * It is stored in savefile.city_options_vector
@@ -64,11 +64,19 @@ enum production_class_type {
 #define SPECENUM_BITVECTOR bv_city_options
 #include "specenum_gen.h"
 
-/* Changing the max radius requires updating network capabilities and results
- * in incompatible savefiles. */
-#define CITY_MAP_MIN_RADIUS       0
-#define CITY_MAP_DEFAULT_RADIUS   2
-#define CITY_MAP_MAX_RADIUS       5
+/* Used in savegames, and there's currently no order of the values
+ * stored in the savegame. Implement that before touching the values. */
+#define SPECENUM_NAME city_wl_cancel_behavior
+#define SPECENUM_VALUE0 WLCB_SMART
+  /* TRANS: Worklist Cancelling behavior
+   * (when something cannot be built right away) */
+#define SPECENUM_VALUE0NAME N_("?wlcb:Smart")
+#define SPECENUM_VALUE1 WLCB_ALWAYS_PURGE
+#define SPECENUM_VALUE1NAME N_("?wlcb:Always Purge")
+#define SPECENUM_VALUE2 WLCB_ALWAYS_POSTPONE
+#define SPECENUM_VALUE2NAME N_("?wlcb:Always Postpone")
+#define SPECENUM_COUNT WLCB_LAST
+#include "specenum_gen.h"
 
 /* The city includes all tiles dx^2 + dy^2 <= CITY_MAP_*_RADIUS_SQ */
 #define CITY_MAP_DEFAULT_RADIUS_SQ \
@@ -77,9 +85,9 @@ enum production_class_type {
   (CITY_MAP_MIN_RADIUS * CITY_MAP_MIN_RADIUS + 1)
 #define CITY_MAP_MAX_RADIUS_SQ \
   (CITY_MAP_MAX_RADIUS * CITY_MAP_MAX_RADIUS + 1)
-/* the id for the city center */
+/* The id for the city center */
 #define CITY_MAP_CENTER_RADIUS_SQ      -1
-/* the tile index of the city center */
+/* The tile index of the city center */
 #define CITY_MAP_CENTER_TILE_INDEX      0
 
 /* Maximum diameter of the workable city area. */
@@ -95,7 +103,7 @@ enum production_class_type {
  * The city size is saved as unsigned char. Therefore, MAX_CITY_SIZE should
  * be below 255!
  */
-#define MAX_CITY_SIZE		0xFF
+#define MAX_CITY_SIZE           0xFF
 
 /* Iterate a city map, from the center (the city) outwards */
 struct iter_index {
@@ -306,6 +314,9 @@ struct adv_city; /* defined in ./server/advisors/infracache.h */
 
 struct cm_parameter; /* defined in ./common/aicore/cm.h */
 
+#ifdef FREECIV_WEB
+#pragma pack(push, 1)
+#endif
 struct city {
   char *name;
   struct tile *tile; /* May be NULL, should check! */
@@ -315,8 +326,9 @@ struct city {
   int id;
   int style;
   enum capital_type capital;
+  enum city_acquire_type acquire_t;
 
-  /* the people */
+  /* The people */
   citizens size;
   citizens feel[CITIZEN_LAST][FEELING_LAST];
 
@@ -328,7 +340,7 @@ struct city {
 
   citizens *nationality;      /* Nationality of the citizens. */
 
-  /* trade routes */
+  /* Trade routes */
   struct trade_route_list *routes;
 
   /* Tile output, regardless of if the tile is actually worked. It is used
@@ -349,6 +361,7 @@ struct city {
 
   /* Cached values for CPU savings. */
   int bonus[O_LAST];
+  int abs_bonus[O_LAST];
 
   /* the physics */
   int food_stock;
@@ -366,6 +379,7 @@ struct city {
   bool did_buy;
   bool did_sell;
   bool was_happy;
+  bool had_famine;
 
   int anarchy;                  /* anarchy rounds count */ 
   int rapture;                  /* rapture rounds count */ 
@@ -387,14 +401,17 @@ struct city {
   struct worklist worklist;
 
   bv_city_options city_options;
+  enum city_wl_cancel_behavior wlcb;
 
   struct unit_list *units_supported;
 
+  int *counter_values;
+
   int history;                 /* Cumulative culture */
 
   struct worker_task_list *task_reqs;
 
-  int steal; /* diplomats steal once; for spies, gets harder */
+  int steal; /* Diplomats steal once; for spies, gets harder */
 
   struct {
     size_t length;
@@ -467,6 +484,9 @@ struct city {
     } client;
   };
 };
+#ifdef FREECIV_WEB
+#pragma pack(pop)
+#endif
 
 struct citystyle {
   struct name_translation name;
@@ -621,6 +641,8 @@ bool city_production_build_units(const struct city *pcity,
 int city_production_unit_veteran_level(struct city *pcity,
                                        const struct unit_type *punittype);
 
+bool city_production_is_genus(const struct city *pcity,
+                              enum impr_genus_id genus);
 bool city_production_has_flag(const struct city *pcity,
                               enum impr_flag_id flag);
 int city_production_turns_to_build(const struct city *pcity,
@@ -752,10 +774,12 @@ static inline bool is_non_allied_city_tile(const struct tile *ptile,
 }
 
 bool is_unit_near_a_friendly_city(const struct civ_map *nmap,
-                                  const struct unit *punit);
+                                  const struct unit *punit,
+                                  int distance);
 bool is_friendly_city_near(const struct civ_map *nmap,
                            const struct player *owner,
-                           const struct tile *ptile);
+                           const struct tile *ptile,
+                           int distance);
 bool city_exists_within_max_city_map(const struct civ_map *nmap,
                                      const struct tile *ptile,
                                      bool may_be_on_center);
