@@ -197,7 +197,7 @@ static int write_socket_data(struct connection *pc,
     }
 
     if (FD_ISSET(pc->sock, &writefs)) {
-      nblock=MIN(buf->ndata-start, MAX_LEN_PACKET);
+      nblock = MIN(buf->ndata-start, MAX_LEN_PACKET);
       log_debug("trying to write %d limit=%d", nblock, limit);
       if ((nput = fc_writesocket(pc->sock, 
                                  (const char *)buf->data+start, nblock)) == -1) {
@@ -216,7 +216,8 @@ static int write_socket_data(struct connection *pc,
   if (start > 0) {
     buf->ndata -= start;
     memmove(buf->data, buf->data+start, buf->ndata);
-    pc->last_write = timer_renew(pc->last_write, TIMER_USER, TIMER_ACTIVE);
+    pc->last_write = timer_renew(pc->last_write, TIMER_USER, TIMER_ACTIVE,
+                                 pc->last_write != NULL ? NULL : "socket write");
     timer_start(pc->last_write);
   }
 
@@ -619,6 +620,8 @@ void connection_common_init(struct connection *pconn)
   byte_vector_init(&pconn->compression.queue);
   pconn->compression.frozen_level = 0;
 #endif /* USE_COMPRESSION */
+
+  pconn->client_gui = GUI_STUB;
 }
 
 /**********************************************************************//**
