@@ -12,7 +12,7 @@
 ***********************************************************************/
 
 /*
- * The DataIO module provides a system independent (endianess and
+ * The DataIO module provides a system independent (endianness and
  * sizeof(int) independent) way to write and read data. It supports
  * multiple datas which are collected in a buffer. It provides
  * recognition of error cases like "not enough space" or "not enough
@@ -262,9 +262,10 @@ bool dio_input_skip(struct data_in *din, size_t size)
 /**********************************************************************//**
   Insert value using 8 bits. May overflow.
 **************************************************************************/
-void dio_put_uint8_raw(struct raw_data_out *dout, int value)
+int dio_put_uint8_raw(struct raw_data_out *dout, int value)
 {
   uint8_t x = value;
+
   FC_STATIC_ASSERT(sizeof(x) == 1, uint8_not_1_byte);
 
   FIELD_RANGE_TEST((int) x != value, ,
@@ -276,14 +277,17 @@ void dio_put_uint8_raw(struct raw_data_out *dout, int value)
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 1);
     dout->current++;
   }
+
+  return 0;
 }
 
 /**********************************************************************//**
   Insert value using 16 bits. May overflow.
 **************************************************************************/
-void dio_put_uint16_raw(struct raw_data_out *dout, int value)
+int dio_put_uint16_raw(struct raw_data_out *dout, int value)
 {
   uint16_t x = htons(value);
+
   FC_STATIC_ASSERT(sizeof(x) == 2, uint16_not_2_bytes);
 
   FIELD_RANGE_TEST((int) ntohs(x) != value, ,
@@ -295,14 +299,17 @@ void dio_put_uint16_raw(struct raw_data_out *dout, int value)
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 2);
     dout->current += 2;
   }
+
+  return 0;
 }
 
 /**********************************************************************//**
   Insert value using 32 bits. May overflow.
 **************************************************************************/
-void dio_put_uint32_raw(struct raw_data_out *dout, int value)
+int dio_put_uint32_raw(struct raw_data_out *dout, int value)
 {
   uint32_t x = htonl(value);
+
   FC_STATIC_ASSERT(sizeof(x) == 4, uint32_not_4_bytes);
 
   FIELD_RANGE_TEST((int) ntohl(x) != value, ,
@@ -314,97 +321,95 @@ void dio_put_uint32_raw(struct raw_data_out *dout, int value)
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 4);
     dout->current += 4;
   }
+
+  return 0;
 }
 
 /**********************************************************************//**
   Insert value using 'size' bits. May overflow.
 **************************************************************************/
-void dio_put_type_raw(struct raw_data_out *dout, enum data_type type, int value)
+int dio_put_type_raw(struct raw_data_out *dout, enum data_type type, int value)
 {
   switch (type) {
   case DIOT_UINT8:
-    dio_put_uint8_raw(dout, value);
-    return;
+    return dio_put_uint8_raw(dout, value);
   case DIOT_UINT16:
-    dio_put_uint16_raw(dout, value);
-    return;
+    return dio_put_uint16_raw(dout, value);
   case DIOT_UINT32:
-    dio_put_uint32_raw(dout, value);
-    return;
+    return dio_put_uint32_raw(dout, value);
   case DIOT_SINT8:
-    dio_put_sint8_raw(dout, value);
-    return;
+    return dio_put_sint8_raw(dout, value);
   case DIOT_SINT16:
-    dio_put_sint16_raw(dout, value);
-    return;
+    return dio_put_sint16_raw(dout, value);
   case DIOT_SINT32:
-    dio_put_sint32_raw(dout, value);
-    return;
+    return dio_put_sint32_raw(dout, value);
   case DIOT_LAST:
     break;
   }
 
   fc_assert_msg(FALSE, "data_type %d not handled.", type);
+
+  return -1;
 }
 
 /**********************************************************************//**
   Insert value using 8 bits. May overflow.
 **************************************************************************/
-void dio_put_sint8_raw(struct raw_data_out *dout, int value)
+int dio_put_sint8_raw(struct raw_data_out *dout, int value)
 {
-  dio_put_uint8_raw(dout, 0 <= value ? value : value + 0x100);
+  return dio_put_uint8_raw(dout, 0 <= value ? value : value + 0x100);
 }
 
 /**********************************************************************//**
   Insert value using 16 bits. May overflow.
 **************************************************************************/
-void dio_put_sint16_raw(struct raw_data_out *dout, int value)
+int dio_put_sint16_raw(struct raw_data_out *dout, int value)
 {
-  dio_put_uint16_raw(dout, 0 <= value ? value : value + 0x10000);
+  return dio_put_uint16_raw(dout, 0 <= value ? value : value + 0x10000);
 }
 
 /**********************************************************************//**
   Insert value using 32 bits. May overflow.
 **************************************************************************/
-void dio_put_sint32_raw(struct raw_data_out *dout, int value)
+int dio_put_sint32_raw(struct raw_data_out *dout, int value)
 {
 #if SIZEOF_INT == 4
-  dio_put_uint32_raw(dout, value);
+  return dio_put_uint32_raw(dout, value);
 #else
-  dio_put_uint32_raw(dout, (0 <= value ? value : value + 0x100000000));
+  return dio_put_uint32_raw(dout, (0 <= value ? value : value + 0x100000000));
 #endif
 }
 
 /**********************************************************************//**
   Insert value 0 or 1 using 8 bits.
 **************************************************************************/
-void dio_put_bool8_raw(struct raw_data_out *dout, bool value)
+int dio_put_bool8_raw(struct raw_data_out *dout, bool value)
 {
   FIELD_RANGE_TEST(value != TRUE && value != FALSE,
                    value = (value != FALSE);,
                    "Trying to put a non-boolean: %d", (int) value);
 
-  dio_put_uint8_raw(dout, value ? 1 : 0);
+  return dio_put_uint8_raw(dout, value ? 1 : 0);
 }
 
 /**********************************************************************//**
   Insert value 0 or 1 using 32 bits.
 **************************************************************************/
-void dio_put_bool32_raw(struct raw_data_out *dout, bool value)
+int dio_put_bool32_raw(struct raw_data_out *dout, bool value)
 {
   FIELD_RANGE_TEST(value != TRUE && value != FALSE,
                    value = (value != FALSE);,
                    "Trying to put a non-boolean: %d",
                    (int) value);
 
-  dio_put_uint32_raw(dout, value ? 1 : 0);
+  return dio_put_uint32_raw(dout, value ? 1 : 0);
 }
 
 /**********************************************************************//**
   Insert a float number, which is multiplied by 'float_factor' before
   being encoded into an uint32.
 **************************************************************************/
-void dio_put_ufloat_raw(struct raw_data_out *dout, float value, int float_factor)
+int dio_put_ufloat_raw(struct raw_data_out *dout, float value, int float_factor)
 {
   uint32_t v = value * float_factor;
 
@@ -414,14 +419,14 @@ void dio_put_ufloat_raw(struct raw_data_out *dout, float value, int float_factor
                    value, float_factor, (float) v / float_factor,
                    fabsf((float) v / float_factor - value) * float_factor);
 
-  dio_put_uint32_raw(dout, v);
+  return dio_put_uint32_raw(dout, v);
 }
 
 /**********************************************************************//**
   Insert a float number, which is multiplied by 'float_factor' before
   being encoded into a sint32.
 **************************************************************************/
-void dio_put_sfloat_raw(struct raw_data_out *dout, float value, int float_factor)
+int dio_put_sfloat_raw(struct raw_data_out *dout, float value, int float_factor)
 {
   int32_t v = value * float_factor;
 
@@ -431,7 +436,7 @@ void dio_put_sfloat_raw(struct raw_data_out *dout, float value, int float_factor
                    value, float_factor, (float) v / float_factor,
                    fabsf((float) v / float_factor - value) * float_factor);
 
-  dio_put_sint32_raw(dout, v);
+  return dio_put_sint32_raw(dout, v);
 }
 
 /**********************************************************************//**
@@ -439,9 +444,10 @@ void dio_put_sfloat_raw(struct raw_data_out *dout, float value, int float_factor
   insert values using 8 bits for each. stop_value is not required to
   fit in 8 bits. Actual values may overflow.
 **************************************************************************/
-void dio_put_uint8_vec8_raw(struct raw_data_out *dout, int *values, int stop_value)
+int dio_put_uint8_vec8_raw(struct raw_data_out *dout, int *values, int stop_value)
 {
   size_t count;
+  int e = 0;
 
   for (count = 0; values[count] != stop_value; count++) {
     /* nothing */
@@ -450,12 +456,14 @@ void dio_put_uint8_vec8_raw(struct raw_data_out *dout, int *values, int stop_val
   if (enough_space(dout, 1 + count)) {
     size_t i;
 
-    dio_put_uint8_raw(dout, count);
+    e |= dio_put_uint8_raw(dout, count);
 
     for (i = 0; i < count; i++) {
-      dio_put_uint8_raw(dout, values[i]);
+      e |= dio_put_uint8_raw(dout, values[i]);
     }
   }
+
+  return e;
 }
 
 /**********************************************************************//**
@@ -463,9 +471,10 @@ void dio_put_uint8_vec8_raw(struct raw_data_out *dout, int *values, int stop_val
   insert values using 16 bits for each. stop_value is not required to
   fit in 16 bits. Actual values may overflow.
 **************************************************************************/
-void dio_put_uint16_vec8_raw(struct raw_data_out *dout, int *values, int stop_value)
+int dio_put_uint16_vec8_raw(struct raw_data_out *dout, int *values, int stop_value)
 {
   size_t count;
+  int e = 0;
 
   for (count = 0; values[count] != stop_value; count++) {
     /* nothing */
@@ -474,96 +483,113 @@ void dio_put_uint16_vec8_raw(struct raw_data_out *dout, int *values, int stop_va
   if (enough_space(dout, 1 + 2 * count)) {
     size_t i;
 
-    dio_put_uint8_raw(dout, count);
+    e |= dio_put_uint8_raw(dout, count);
 
     for (i = 0; i < count; i++) {
-      dio_put_uint16_raw(dout, values[i]);
+      e |= dio_put_uint16_raw(dout, values[i]);
     }
   }
+
+  return e;
 }
 
 /**********************************************************************//**
   Insert block directly from memory.
 **************************************************************************/
-void dio_put_memory_raw(struct raw_data_out *dout, const void *value, size_t size)
+int dio_put_memory_raw(struct raw_data_out *dout, const void *value, size_t size)
 {
   if (enough_space(dout, size)) {
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), value, size);
     dout->current += size;
   }
+
+  return 0;
 }
 
 /**********************************************************************//**
   Insert NULL-terminated string. Conversion callback is used if set.
 **************************************************************************/
-void dio_put_string_raw(struct raw_data_out *dout, const char *value)
+int dio_put_string_raw(struct raw_data_out *dout, const char *value)
 {
   if (put_conv_callback) {
     size_t length;
     char *buffer;
+    int e = 0;
 
     if ((buffer = (*put_conv_callback) (value, &length))) {
-      dio_put_memory_raw(dout, buffer, length + 1);
+      e = dio_put_memory_raw(dout, buffer, length + 1);
       free(buffer);
     }
+
+    return e;
   } else {
-    dio_put_memory_raw(dout, value, strlen(value) + 1);
+    return dio_put_memory_raw(dout, value, strlen(value) + 1);
   }
 }
 
 /**********************************************************************//**
   Insert cm_parameter struct.
 **************************************************************************/
-void dio_put_cm_parameter_raw(struct raw_data_out *dout,
-                              const struct cm_parameter *param)
+int dio_put_cm_parameter_raw(struct raw_data_out *dout,
+                             const struct cm_parameter *param)
 {
   int i;
+  int e = 0;
 
   for (i = 0; i < O_LAST; i++) {
-    dio_put_sint16_raw(dout, param->minimal_surplus[i]);
+    e |= dio_put_sint16_raw(dout, param->minimal_surplus[i]);
   }
 
-  dio_put_bool8_raw(dout, param->max_growth);
-  dio_put_bool8_raw(dout, param->require_happy);
-  dio_put_bool8_raw(dout, param->allow_disorder);
-  dio_put_bool8_raw(dout, param->allow_specialists);
+  e |= dio_put_bool8_raw(dout, param->max_growth);
+  e |= dio_put_bool8_raw(dout, param->require_happy);
+  e |= dio_put_bool8_raw(dout, param->allow_disorder);
+  e |= dio_put_bool8_raw(dout, param->allow_specialists);
 
   for (i = 0; i < O_LAST; i++) {
-    dio_put_uint16_raw(dout, param->factor[i]);
+    e |= dio_put_uint16_raw(dout, param->factor[i]);
   }
 
-  dio_put_uint16_raw(dout, param->happy_factor);
+  e |= dio_put_uint16_raw(dout, param->happy_factor);
+
+  return e;
 }
 
 /**********************************************************************//**
   Insert the given unit_order struct/
 **************************************************************************/
-void dio_put_unit_order_raw(struct raw_data_out *dout,
-                            const struct unit_order *order)
+int dio_put_unit_order_raw(struct raw_data_out *dout,
+                           const struct unit_order *order)
 {
-  dio_put_uint8_raw(dout, order->order);
-  dio_put_uint8_raw(dout, order->activity);
-  dio_put_sint32_raw(dout, order->target);
-  dio_put_sint16_raw(dout, order->sub_target);
-  dio_put_uint8_raw(dout, order->action);
-  dio_put_sint8_raw(dout, order->dir);
+  int e = 0;
+
+  e |= dio_put_uint8_raw(dout, order->order);
+  e |= dio_put_uint8_raw(dout, order->activity);
+  e |= dio_put_sint32_raw(dout, order->target);
+  e |= dio_put_sint16_raw(dout, order->sub_target);
+  e |= dio_put_uint8_raw(dout, order->action);
+  e |= dio_put_sint8_raw(dout, order->dir);
+
+  return e;
 }
 
 /**********************************************************************//**
   Insert number of worklist items as 8 bit value and then insert
   8 bit kind and 8 bit number for each worklist item.
 **************************************************************************/
-void dio_put_worklist_raw(struct raw_data_out *dout, const struct worklist *pwl)
+int dio_put_worklist_raw(struct raw_data_out *dout, const struct worklist *pwl)
 {
   int i, length = worklist_length(pwl);
+  int e = 0;
 
-  dio_put_uint8_raw(dout, length);
+  e |= dio_put_uint8_raw(dout, length);
   for (i = 0; i < length; i++) {
     const struct universal *pcp = &(pwl->entries[i]);
 
-    dio_put_uint8_raw(dout, pcp->kind);
-    dio_put_uint8_raw(dout, universal_number(pcp));
+    e |= dio_put_uint8_raw(dout, pcp->kind);
+    e |= dio_put_uint8_raw(dout, universal_number(pcp));
   }
+
+  return e;
 }
 
 /**********************************************************************//**
@@ -1009,11 +1035,15 @@ bool dio_get_action_probability_raw(struct data_in *din,
 /**********************************************************************//**
   Serialize an action probability.
 **************************************************************************/
-void dio_put_action_probability_raw(struct raw_data_out *dout,
-                                    const struct act_prob *aprob)
+int dio_put_action_probability_raw(struct raw_data_out *dout,
+                                   const struct act_prob *aprob)
 {
-  dio_put_uint8_raw(dout, aprob->min);
-  dio_put_uint8_raw(dout, aprob->max);
+  int e = 0;
+
+  e |= dio_put_uint8_raw(dout, aprob->min);
+  e |= dio_put_uint8_raw(dout, aprob->max);
+
+  return e;
 }
 
 /**********************************************************************//**
@@ -1045,24 +1075,27 @@ bool dio_get_requirement_raw(struct data_in *din, struct requirement *preq)
 /**********************************************************************//**
   Serialize a requirement.
 **************************************************************************/
-void dio_put_requirement_raw(struct raw_data_out *dout,
-                             const struct requirement *preq)
+int dio_put_requirement_raw(struct raw_data_out *dout,
+                            const struct requirement *preq)
 {
   int type, range, value;
   bool survives, present, quiet;
+  int e = 0;
 
   req_get_values(preq, &type, &range, &survives, &present, &quiet, &value);
 
-  dio_put_uint8_raw(dout, type);
-  dio_put_sint32_raw(dout, value);
-  dio_put_uint8_raw(dout, range);
-  dio_put_bool8_raw(dout, survives);
-  dio_put_bool8_raw(dout, present);
-  dio_put_bool8_raw(dout, quiet);
+  e |= dio_put_uint8_raw(dout, type);
+  e |= dio_put_sint32_raw(dout, value);
+  e |= dio_put_uint8_raw(dout, range);
+  e |= dio_put_bool8_raw(dout, survives);
+  e |= dio_put_bool8_raw(dout, present);
+  e |= dio_put_bool8_raw(dout, quiet);
+
+  return e;
 }
 
 /**********************************************************************//**
- Create a new address of the location of a field inside a packet.
+  Create a new address of the location of a field inside a packet.
 **************************************************************************/
 struct plocation *plocation_field_new(char *name)
 {
@@ -1076,7 +1109,7 @@ struct plocation *plocation_field_new(char *name)
 }
 
 /**********************************************************************//**
- Create a new address of the location of an array element inside a packet.
+  Create a new address of the location of an array element inside a packet.
 **************************************************************************/
 struct plocation *plocation_elem_new(int number)
 {
@@ -1106,7 +1139,7 @@ const char *plocation_name(const struct plocation *loc)
   case PADR_FIELD:
     return loc->name;
   case PADR_ELEMENT:
-    fc_snprintf(locname, sizeof(locname), "%d", loc->number);
+    fc_snprintf(locname, sizeof(locname), SIZE_T_PRINTF, loc->number);
     return locname;
   }
 
