@@ -44,12 +44,18 @@ void terrains_init(void)
   int i;
 
   for (i = 0; i < ARRAY_SIZE(civ_terrains); i++) {
+    int j;
+
     /* Can't use terrain_by_number here because it does a bounds check. */
     civ_terrains[i].item_number = i;
     civ_terrains[i].ruledit_disabled = FALSE;
     civ_terrains[i].ruledit_dlg = NULL;
     civ_terrains[i].rgb = NULL;
     civ_terrains[i].animal = NULL;
+
+    for (j = 0; j < MAX_EXTRA_TYPES; j++) {
+      civ_terrains[i].extra_removal_times[j] = 0;
+    }
   }
 }
 
@@ -69,6 +75,12 @@ void terrains_free(void)
       free(pterrain->resources);
       pterrain->resources = NULL;
     }
+    if (pterrain->resource_freq != NULL) {
+      /* Server allocates this on ruleset loading, client when
+       * ruleset packet is received. */
+      free(pterrain->resource_freq);
+      pterrain->resource_freq = NULL;
+    }
     if (pterrain->rgb != NULL) {
       /* Server allocates this on ruleset loading, client when
        * ruleset packet is received. */
@@ -668,11 +680,16 @@ bool terrain_can_support_alteration(const struct terrain *pterrain,
      return (pterrain->mining_time > 0);
    case TA_CAN_ROAD:
      return (pterrain->road_time > 0);
+   case TA_CAN_BASE:
+     return (pterrain->base_time > 0);
+   case TA_CAN_PLACE:
+     return (pterrain->placing_time > 0);
    default:
      break;
   }
 
   fc_assert(FALSE);
+
   return FALSE;
 }
 
@@ -713,7 +730,7 @@ int terrain_extra_build_time(const struct terrain *pterrain,
 }
 
 /**********************************************************************//**
-   Time to complete the extra removal activity on the given terrain.
+  Time to complete the extra removal activity on the given terrain.
 **************************************************************************/
 int terrain_extra_removal_time(const struct terrain *pterrain,
                                enum unit_activity activity,
@@ -721,27 +738,22 @@ int terrain_extra_removal_time(const struct terrain *pterrain,
 {
   int factor;
 
-  if (tgt != NULL && tgt->removal_time != 0) {
+  if (tgt->removal_time != 0) {
     /* Extra specific removal time */
     return tgt->removal_time;
   }
 
-  if (tgt == NULL) {
-    factor = 1;
-  } else {
-    factor = tgt->removal_time_factor;
-  }
+  factor = tgt->removal_time_factor;
 
   /* Terrain and activity specific removal time */
   switch (activity) {
-  case ACTIVITY_POLLUTION:
-    return pterrain->clean_pollution_time * factor;
-  case ACTIVITY_FALLOUT:
-    return pterrain->clean_fallout_time * factor;
+  case ACTIVITY_CLEAN:
+    return pterrain->extra_removal_times[extra_index(tgt)] * factor;
   case ACTIVITY_PILLAGE:
     return pterrain->pillage_time * factor;
   default:
     fc_assert(FALSE);
+
     return 0;
   }
 }
