@@ -88,8 +88,8 @@ bool is_sea_barbarian(struct player *pplayer)
 }
 
 /**********************************************************************//**
-  Creates the land/sea barbarian player and inits some stuff. If 
-  barbarian player already exists, return player pointer. If barbarians 
+  Creates the land/sea barbarian player and inits some stuff. If
+  barbarian player already exists, return player pointer. If barbarians
   are dead, revive them with a new leader :-)
 
   Dead barbarians forget the map and lose the money.
@@ -117,9 +117,9 @@ struct player *create_barbarian_player(enum barbarian_type type)
         sz_strlcpy(old_barbs->username, _(ANON_USER_NAME));
         old_barbs->unassigned_user = TRUE;
         /* I need to make them to forget the map, I think */
-	whole_map_iterate(&(wld.map), ptile) {
-	  map_clear_known(ptile, old_barbs);
-	} whole_map_iterate_end;
+        whole_map_iterate(&(wld.map), ptile) {
+          map_clear_known(ptile, old_barbs);
+        } whole_map_iterate_end;
       }
       old_barbs->economic.gold += 100;  /* New leader, new money */
 
@@ -127,11 +127,13 @@ struct player *create_barbarian_player(enum barbarian_type type)
     }
   } players_iterate_end;
 
-  /* make a new player, or not */
+  /* Make a new player, or not */
   barbarians = server_create_player(-1, default_ai_type_name(), NULL, FALSE);
-  if (!barbarians) {
+  if (barbarians == NULL) {
     return NULL;
   }
+  /* Freeciv-web depends on AI-status being set already before server_player_init() */
+  set_as_ai(barbarians);
   server_player_init(barbarians, TRUE, TRUE);
 
   if (type == LAND_BARBARIAN || type == SEA_BARBARIAN) {
@@ -165,13 +167,12 @@ struct player *create_barbarian_player(enum barbarian_type type)
   barbarians->is_connected = FALSE;
   barbarians->government = init_government_of_nation(nation);
   fc_assert(barbarians->revolution_finishes < 0);
-  barbarians->server.got_first_city = FALSE;
+  BV_CLR(barbarians->flags, PLRF_FIRST_CITY);
   barbarians->economic.gold = 100;
 
   barbarians->phase_done = TRUE;
 
-  /* Do the ai */
-  set_as_ai(barbarians);
+  /* Do the AI */
   barbarians->ai_common.barbarian_type = type;
   set_ai_level_directer(barbarians, game.info.skill_level);
 
@@ -259,13 +260,13 @@ static void unit_move_pay(struct unit *punit, struct tile *pdesttile)
 }
 
 /**********************************************************************//**
-  Unleash barbarians means give barbarian player some units and move them 
+  Unleash barbarians means give barbarian player some units and move them
   out of the hut, unless there's no place to go.
 
   Barbarian unit deployment algorithm: If enough free land around, deploy
-  on land, if not enough land but some sea free, load some of them on 
-  boats, otherwise (not much land and no sea) kill enemy unit and stay in 
-  a village. The return value indicates if the explorer survived entering 
+  on land, if not enough land but some sea free, load some of them on
+  boats, otherwise (not much land and no sea) kill enemy unit and stay in
+  a village. The return value indicates if the explorer survived entering
   the vilage.
 **************************************************************************/
 bool unleash_barbarians(struct tile *ptile)
@@ -388,7 +389,7 @@ bool unleash_barbarians(struct tile *ptile)
         struct unit_type *candidate;
         int rdir = random_unchecked_direction(ocean_tiles - checked_count, checked);
 
-        candidate = find_a_unit_type(L_BARBARIAN_BOAT, -1);
+        candidate = find_a_unit_type(L_BARBARIAN_BOAT, L_BARBARIAN_BOAT_TECH);
         if (is_native_tile(candidate, dir_tiles[rdir])
             && !utype_player_already_has_this_unique(barbarians, candidate)) {
           boat = create_unit(barbarians, dir_tiles[rdir], candidate,
@@ -417,6 +418,11 @@ bool unleash_barbarians(struct tile *ptile)
               /* Load */
               unit_do_action(unit_owner(punit2), punit2->id, boat->id,
                              0, "", ACTION_TRANSPORT_EMBARK3);
+            } else if (is_action_enabled_unit_on_unit(nmap, ACTION_TRANSPORT_EMBARK4,
+                                                      punit2, boat)) {
+              /* Load */
+              unit_do_action(unit_owner(punit2), punit2->id, boat->id,
+                             0, "", ACTION_TRANSPORT_EMBARK4);
             }
           }
         } unit_list_iterate_safe_end;
@@ -508,20 +514,20 @@ static struct tile *find_empty_tile_nearby(struct tile *ptile)
 
 /**********************************************************************//**
   The barbarians are summoned at a randomly chosen place if:
-  1. It's not closer than MIN_UNREST_DIST and not further than 
-     MAX_UNREST_DIST from the nearest city. City owner is called 'victim' 
+  1. It's not closer than MIN_UNREST_DIST and not further than
+     MAX_UNREST_DIST from the nearest city. City owner is called 'victim'
      here.
   2. The place or a neighboring tile must be empty to deploy the units.
   3. If it's the sea it shouldn't be far from the land. (questionable)
   4. Place must be known to the victim
   5. The uprising chance depends also on the victim empire size, its
      government (civil_war_chance) and barbarian difficulty level.
-  6. The number of land units also depends slightly on victim's empire 
+  6. The number of land units also depends slightly on victim's empire
      size and barbarian difficulty level.
-  Q: The empire size is used so there are no uprisings in the beginning 
-     of the game (year is not good as it can be customized), but it seems 
-     a bit unjust if someone is always small. So maybe it should rather 
-     be an average number of cities (all cities/player num)? Depending 
+  Q: The empire size is used so there are no uprisings in the beginning
+     of the game (year is not good as it can be customized), but it seems
+     a bit unjust if someone is always small. So maybe it should rather
+     be an average number of cities (all cities/player num)? Depending
      on the victim government type is also questionable.
 **************************************************************************/
 static void try_summon_barbarians(void)
@@ -657,7 +663,7 @@ static void try_summon_barbarians(void)
       CALL_PLR_AI_FUNC(phase_begin, barbarians, barbarians, TRUE);
     }
 
-    boat = find_a_unit_type(L_BARBARIAN_BOAT,-1);
+    boat = find_a_unit_type(L_BARBARIAN_BOAT, L_BARBARIAN_BOAT_TECH);
 
     if (is_native_tile(boat, utile)
         && !utype_player_already_has_this_unique(barbarians, boat)
