@@ -22,6 +22,7 @@
 #include "fcintl.h"
 #include "log.h"
 #include "mem.h"
+#include "rand.h"
 #include "support.h"
 
 /* common */
@@ -50,6 +51,9 @@
 #include "stdinhand.h"
 #include "voting.h"
 
+/* server/scripting */
+#include "script_fcdb.h"
+
 #include "connecthand.h"
 
 
@@ -75,7 +79,10 @@ void conn_set_access(struct connection *pconn, enum cmdlevel new_level,
     pconn->server.granted_access_level = new_level;
   }
 
-  if (old_level != new_level) {
+  /* Send updated settings only if settings control already sent.
+   * Otherwise client is not ready to receive them, AND we will send
+   * them later anyway. */
+  if (old_level != new_level && pconn->server.settings_sent) {
     send_server_access_level_settings(pconn->self, old_level, new_level);
   }
 }
@@ -104,7 +111,7 @@ static void restore_access_level(struct connection *pconn)
 
 /**********************************************************************//**
   This is used when a new player joins a server, before the game
-  has started.  If pconn is NULL, is an AI, else a client.
+  has started. If pconn is NULL, is an AI, else a client.
 
   N.B. this only attaches a connection to a player if
        pconn->username == player->username
@@ -130,10 +137,10 @@ void establish_new_connection(struct connection *pconn)
   bool delegation_error = FALSE;
   struct packet_set_topology topo_packet;
 
-  /* zero out the password */
+  /* Zero out the password */
   memset(pconn->server.password, 0, sizeof(pconn->server.password));
 
-  /* send join_reply packet */
+  /* Send join_reply packet */
   packet.you_can_join = TRUE;
   sz_strlcpy(packet.capability, our_capability);
   fc_snprintf(packet.message, sizeof(packet.message), _("%s Welcome"),
@@ -149,6 +156,7 @@ void establish_new_connection(struct connection *pconn)
   pconn->server.delegation.status = FALSE;
   pconn->server.delegation.playing = NULL;
   pconn->server.delegation.observer = FALSE;
+  pconn->server.settings_sent = FALSE;
 
   conn_list_append(game.est_connections, pconn);
   if (conn_list_size(game.est_connections) == 1) {
@@ -158,7 +166,7 @@ void establish_new_connection(struct connection *pconn)
     (void) send_server_info_to_metaserver(META_INFO);
   }
 
-  /* introduce the server to the connection */
+  /* Introduce the server to the connection */
   if (fc_gethostname(hostname, sizeof(hostname)) == 0) {
     notify_conn(dest, NULL, E_CONNECTION, ftc_any,
                 _("Welcome to the %s Server running at %s port %d."),
@@ -175,6 +183,10 @@ void establish_new_connection(struct connection *pconn)
   /* Notify the console that you're here. */
   log_normal(_("%s has connected from %s."), pconn->username, pconn->addr);
 
+  if (srvarg.fcdb_enabled) {
+    script_fcdb_call("conn_established", pconn);
+  }
+
   conn_compression_freeze(pconn);
   send_rulesets(dest);
   send_server_setting_control(pconn);
@@ -183,12 +195,14 @@ void establish_new_connection(struct connection *pconn)
   send_scenario_description(dest);
   send_game_info(dest);
   topo_packet.topology_id = wld.map.topology_id;
+  topo_packet.wrap_id = wld.map.wrap_id;
   send_packet_set_topology(pconn, &topo_packet);
 
   /* Do we have a player that a delegate is currently controlling? */
   if ((pplayer = player_by_user_delegated(pconn->username))) {
     /* Reassert our control over the player. */
     struct connection *pdelegate;
+
     fc_assert_ret(player_delegation_get(pplayer) != NULL);
     pdelegate = conn_by_user(player_delegation_get(pplayer));
 
@@ -219,13 +233,43 @@ void establish_new_connection(struct connection *pconn)
   if (!delegation_error) {
     if ((pplayer = player_by_user(pconn->username))
         && connection_attach_real(pconn, pplayer, FALSE, TRUE)) {
-      /* a player has already been created for this user, reconnect */
+      /* A player has already been created for this user, reconnect */
 
       if (S_S_INITIAL == server_state()) {
         send_player_info_c(NULL, dest);
       }
     } else {
-      if (!game_was_started()) {
+      int total_free_weight = 0;
+
+      players_iterate(wplayer) {
+        if (wplayer->autoselect_weight > 0
+            && !wplayer->is_connected
+            && !player_has_flag(wplayer, PLRF_SCENARIO_RESERVED)) {
+          total_free_weight += wplayer->autoselect_weight;
+        }
+      } players_iterate_end;
+
+      if (total_free_weight > 0) {
+        int weight_rand = fc_rand(total_free_weight);
+
+        players_iterate(wplayer) {
+          if (wplayer->autoselect_weight > 0
+              && !wplayer->is_connected
+              && !player_has_flag(wplayer, PLRF_SCENARIO_RESERVED)) {
+            weight_rand -= wplayer->autoselect_weight;
+            if (weight_rand < 0) {
+              log_normal("Trying to attach %s to %s",
+                         pconn->username, wplayer->name);
+              if (!connection_attach_real(pconn, wplayer, FALSE, TRUE)) {
+                notify_conn(dest, NULL, E_CONNECTION, ftc_server,
+                            _("Couldn't attach your connection to a scenario player."));
+                log_verbose("%s is not attached to a player", pconn->username);
+              }
+              break;
+            }
+          }
+        } players_iterate_end;
+      } else if (!game_was_started()) {
         if (connection_attach_real(pconn, NULL, FALSE, TRUE)) {
           pplayer = conn_get_player(pconn);
           fc_assert(pplayer != NULL);
@@ -679,7 +723,7 @@ static bool connection_attach_real(struct connection *pconn,
   /* We don't want the connection's username on another player. */
   players_iterate(aplayer) {
     if (aplayer != pplayer
-        && 0 == strncmp(aplayer->username, pconn->username, MAX_LEN_NAME)) {
+        && !fc_strncmp(aplayer->username, pconn->username, MAX_LEN_NAME)) {
       sz_strlcpy(aplayer->username, _(ANON_USER_NAME));
       aplayer->unassigned_user = TRUE;
       send_player_info_c(aplayer, NULL);
@@ -965,3 +1009,11 @@ void connection_close_server(struct connection *pconn, const char *reason)
   connection_delegate_restore(pconn);
   connection_close(pconn, reason);
 }
+
+/**********************************************************************//**
+  Handle client's request to sync via packet serial number.
+**************************************************************************/
+void handle_sync_serial(struct connection *conn, int serial)
+{
+  dsend_packet_sync_serial_reply(conn, serial);
+}
