@@ -19,7 +19,6 @@
 
 /* utility */
 #include "bitvector.h"
-#include "capability.h"
 #include "fcintl.h"
 #include "log.h"
 #include "rand.h"
@@ -334,6 +333,7 @@ bool diplomat_investigate(struct player *pplayer, struct unit *pdiplomat,
   struct packet_web_city_info_addition web_packet;
   struct trade_route_packet_list *routes;
   const struct unit_type *act_utype;
+  struct packet_web_city_info_addition *webp_ptr;
 
   /* Fetch target city's player.  Sanity checks. */
   fc_assert_ret_val(pcity, FALSE);
@@ -354,12 +354,7 @@ bool diplomat_investigate(struct player *pplayer, struct unit *pdiplomat,
 
   log_debug("investigate: unit: %d", pdiplomat->id);
 
-  conn_list_iterate(pplayer->connections, pconn) {
-    if (has_capability("obsinv", pconn->capability)) {
-      dsend_packet_investigate_started(pconn, pdiplomat->id, pdiplomat->id,
-                                       pcity->id, pcity->id);
-    }
-  } conn_list_iterate_end;
+  dlsend_packet_investigate_started(pplayer->connections, pcity->id);
 
   /* Do It... */
   update_dumb_city(pplayer, pcity);
@@ -367,7 +362,7 @@ bool diplomat_investigate(struct player *pplayer, struct unit *pdiplomat,
      The investigator needs to know the supported and present
      units of a city, whether or not they are fogged. So, we
      send a list of them all before sending the city info.
-     As this is a special case we bypass send_unit_info(). */
+     As this is a special case we bypass send_unit_info. */
   unit_list_iterate(pcity->units_supported, punit) {
     package_short_unit(punit, &unit_packet,
                        UNIT_INFO_CITY_SUPPORTED, pcity->id);
@@ -383,17 +378,24 @@ bool diplomat_investigate(struct player *pplayer, struct unit *pdiplomat,
     lsend_packet_unit_short_info(pplayer->connections, &unit_packet, TRUE);
   } unit_list_iterate_end;
   /* Send city info to investigator's player.
-     As this is a special case we bypass send_city_info. */
+     As this is a special case we bypass send_city_info(). */
+
+  if (any_web_conns()) {
+    webp_ptr = &web_packet;
+  } else {
+    webp_ptr = NULL;
+  }
+
   routes = trade_route_packet_list_new();
   package_city(pcity, &city_packet, &nat_packet, &rally_packet,
-               &web_packet, routes, TRUE);
+               webp_ptr, routes, TRUE);
   /* We need to force to send the packet to ensure the client will receive
    * something and popup the city dialog. */
   city_packet.original = city_original_owner(pcity, pplayer);
   lsend_packet_city_info(pplayer->connections, &city_packet, TRUE);
   lsend_packet_city_nationalities(pplayer->connections, &nat_packet, TRUE);
   lsend_packet_city_rally_point(pplayer->connections, &rally_packet, TRUE);
-  web_lsend_packet(city_info_addition, pplayer->connections, &web_packet, TRUE);
+  web_lsend_packet(city_info_addition, pplayer->connections, webp_ptr, TRUE);
   trade_route_packet_list_iterate(routes, route_packet) {
     lsend_packet_trade_route_info(pplayer->connections, route_packet);
     FC_FREE(route_packet);
@@ -412,12 +414,7 @@ bool diplomat_investigate(struct player *pplayer, struct unit *pdiplomat,
     send_unit_info(NULL, pdiplomat);
   }
 
-  conn_list_iterate(pplayer->connections, pconn) {
-    if (has_capability("obsinv", pconn->capability)) {
-      dsend_packet_investigate_finished(pconn, pdiplomat->id, pdiplomat->id,
-                                        pcity->id, pcity->id);
-    }
-  } conn_list_iterate_end;
+  dlsend_packet_investigate_finished(pplayer->connections, pcity->id);
 
   return TRUE;
 }
@@ -464,10 +461,8 @@ void spy_send_sabotage_list(struct connection *pc, struct unit *pdiplomat,
     } improvement_iterate_end;
   }
 
-  packet.actor_id32 = pdiplomat->id;
-  packet.actor_id16 = packet.actor_id32;
-  packet.city_id32 = pcity->id;
-  packet.city_id16 = packet.city_id32;
+  packet.actor_id = pdiplomat->id;
+  packet.city_id = pcity->id;
   packet.act_id = paction->id;
   packet.request_kind = request_kind;
   send_packet_city_sabotage_list(pc, &packet);
@@ -1922,13 +1917,9 @@ bool spy_nuke_city(struct player *act_player, struct unit *act_unit,
     wipe_unit(act_unit, ULR_USED, NULL);
   }
 
-  /* TODO: In real life a suitcase nuke is way less powerful than an ICBM.
-   * Maybe the size of the suitcase nuke explosion should be ruleset
-   * configurable? */
-
   /* Detonate the nuke. */
   dlsend_packet_nuke_tile_info(game.est_connections, tile_index(tgt_tile));
-  do_nuclear_explosion(act_player, tgt_tile);
+  do_nuclear_explosion(paction, act_utype, act_player, tgt_tile);
 
   /* This may cause a diplomatic incident. */
   action_consequence_success(paction, act_player, act_utype,
@@ -2062,7 +2053,8 @@ static bool diplomat_infiltrate_tile(struct player *pplayer,
     sz_strlcpy(link_city, city_link(pcity));
   }
 
-  if ((punit = get_diplomatic_defender(pdiplomat, pvictim, ptile))) {
+  if ((punit = get_diplomatic_defender(pdiplomat, pvictim, ptile,
+                                       paction))) {
     struct player *uplayer = unit_owner(punit);
 
     if (defender_owner != NULL) {
@@ -2240,9 +2232,9 @@ static bool diplomat_infiltrate_tile(struct player *pplayer,
     - Escapes to home city.
     - Escapee may become a veteran.
 ****************************************************************************/
-static void diplomat_escape(struct player *pplayer, struct unit *pdiplomat,
-                            const struct city *pcity,
-                            const struct action *paction)
+void diplomat_escape(struct player *pplayer, struct unit *pdiplomat,
+                     const struct city *pcity,
+                     const struct action *paction)
 {
   struct tile *ptile;
   const char *vlink;
@@ -2343,6 +2335,42 @@ static void diplomat_escape_full(struct player *pplayer,
   }
 }
 
+/************************************************************************//**
+  Attempt to escape without doing anything else first.
+
+  May be captured and executed, or escape to the nearest domestic city.
+
+  Returns TRUE iff action could be done, FALSE if it couldn't. Even if
+  this returns TRUE, unit may have died during the action.
+****************************************************************************/
+bool spy_escape(struct player *pplayer,
+                struct unit *actor_unit,
+                struct city *target_city,
+                struct tile *target_tile,
+                const struct action *paction)
+{
+  const char *vlink;
+  const struct unit_type *act_utype = unit_type_get(actor_unit);
+
+  if (target_city != NULL) {
+    fc_assert(city_tile(target_city) == target_tile);
+    vlink = city_link(target_city);
+  } else {
+    vlink = tile_link(target_tile);
+  }
+
+  /* this may cause a diplomatic incident */
+  action_consequence_success(paction, pplayer, act_utype,
+                             tile_owner(target_tile),
+                             target_tile, vlink);
+
+  /* Try to escape. */
+  diplomat_escape_full(pplayer, actor_unit, target_city != NULL,
+                       target_tile, vlink, paction);
+
+  return TRUE;
+}
+
 /************************************************************************//**
   Return number of diplomats on this square.  AJS 20000130
 ****************************************************************************/
