@@ -25,6 +25,7 @@
 #include "government.h"
 #include "map.h"
 #include "movement.h"
+#include "nation.h"
 #include "player.h"
 #include "research.h"
 #include "specialist.h"
@@ -35,6 +36,7 @@
 /* server */
 #include "citytools.h"
 #include "cityturn.h"           /* city_repair_size() */
+#include "diplhand.h"           /* valid_dst_closest() */
 #include "maphand.h"
 #include "plrhand.h"
 #include "srv_main.h"
@@ -522,8 +524,8 @@ static void check_players(const char *file, const char *function, int line)
     SANITY_CHECK(!pplayer->nation || pplayer->nation->player == pplayer);
     SANITY_CHECK(player_list_search(team_members(pplayer->team), pplayer));
 
-    SANITY_CHECK(!(city_list_size(pplayer->cities) > 0
-                   && !pplayer->server.got_first_city));
+    SANITY_CHECK(player_has_flag(pplayer, PLRF_FIRST_CITY)
+                 || city_list_size(pplayer->cities) == 0);
 
     city_list_iterate(pplayer->cities, pcity) {
       if (pcity->capital == CAPITAL_PRIMARY) {
@@ -543,6 +545,7 @@ static void check_players(const char *file, const char *function, int line)
       state2 = player_diplstate_get(pplayer2, pplayer);
       SANITY_CHECK(state1->type == state2->type);
       SANITY_CHECK(state1->max_state == state2->max_state);
+      SANITY_CHECK(valid_dst_closest(state1) == state1->max_state);
       if (state1->type == DS_CEASEFIRE
           || state1->type == DS_ARMISTICE) {
         SANITY_CHECK(state1->turns_left == state2->turns_left);
@@ -649,9 +652,11 @@ check_researches(const char *file, const char *function, int line)
 static void check_connections(const char *file, const char *function,
                               int line)
 {
-  /* est_connections is a subset of all_connections */
-  SANITY_CHECK(conn_list_size(game.all_connections)
-	       >= conn_list_size(game.est_connections));
+  int all = conn_list_size(game.all_connections);
+
+  /* Other lists are subsets of all_connections */
+  SANITY_CHECK(all >= conn_list_size(game.est_connections));
+  SANITY_CHECK(all >= conn_list_size(game.web_client_connections));
 }
 
 /**********************************************************************//**
