@@ -25,6 +25,8 @@
 
 /* server */
 #include "aiiface.h"
+#include "setcompat.h"
+#include "settings.h"
 #include "unittools.h"
 
 #include "savecompat.h"
@@ -65,8 +67,9 @@ static char *special_names[] =
           | * "known" info format change                   |            |
   2.5.0   | 2.5.0 release                                  | 201./../.. | 20
   2.6.0   | 2.6.0 release                                  | 201./../.. | 30
-  3.0.0   | 3.0.0 release                                  | 202./../.. | 40
-  3.1.0   | 3.1.0 release                                  | 202./../.. | 50
+  3.0.0   | 3.0.0 release                                  | 201./../.. | 40
+  3.1.0   | 3.1.0 release                                  | 201./../.. | 50
+  3.2.0   | 3.2.0 release (development)                    | 202./../.. | 60
           |                                                |            |
 */
 
@@ -75,6 +78,7 @@ static void compat_load_020500(struct loaddata *loading, enum sgf_version format
 static void compat_load_020600(struct loaddata *loading, enum sgf_version format_class);
 static void compat_load_030000(struct loaddata *loading, enum sgf_version format_class);
 static void compat_load_030100(struct loaddata *loading, enum sgf_version format_class);
+static void compat_load_030200(struct loaddata *loading, enum sgf_version format_class);
 static void compat_post_load_030100(struct loaddata *loading,
                                     enum sgf_version format_class);
 
@@ -96,8 +100,8 @@ struct compatibility {
  * add the needed code to load the old version below. Thus, old
  * savegames can still be loaded while the main definition
  * represents the current state of the art. */
-/* While developing freeciv 3.1.0, add the compatibility functions to
- * - compat_load_030100 to load old savegame. */
+/* While developing freeciv 3.2.0, add the compatibility functions to
+ * - compat_load_030200 to load old savegame. */
 static struct compatibility compat[] = {
   /* dummy; equal to the current version (last element) */
   { 0, NULL, NULL },
@@ -115,6 +119,8 @@ static struct compatibility compat[] = {
   { 40, compat_load_030000, NULL },
   /* version 41 to 49 are reserved for possible changes in 3.0.x */
   { 50, compat_load_030100, compat_post_load_030100 },
+  /* version 51 to 59 are reserved for possible changes in 3.1.x */
+  { 60, compat_load_030200, NULL },
   /* Current savefile version is listed above this line; it corresponds to
      the definitions in this file. */
 };
@@ -366,15 +372,18 @@ static void compat_load_020400(struct loaddata *loading,
       /* This savefile contains known information in a sane format.
        * Just move any entries to where 2.4.x+ expect to find them. */
       struct section *map = secfile_section_by_name(loading->file, "map");
-      if (map) {
+
+      if (map != NULL) {
         entry_list_iterate(section_entries(map), pentry) {
           const char *name = entry_name(pentry);
-          if (strncmp(name, "kvb", 3) == 0) {
+
+          if (!fc_strncmp(name, "kvb", 3)) {
             /* Rename the "kvb..." entry to "k..." */
             char *name2 = fc_strdup(name), *newname = name2 + 2;
+
             *newname = 'k';
             /* Savefile probably contains existing "k" entries, which are bogus
-             * so we trash them */
+             * so we trash them. */
             secfile_entry_delete(loading->file, "map.%s", newname);
             entry_set_name(pentry, newname);
             FC_FREE(name2);
@@ -427,7 +436,7 @@ static void compat_load_020400(struct loaddata *loading,
           for (p = 0; p < maxslots; p++) {
             l = p / 32;
             for (x = 0; x < xsize; x++) {
-              /* This test causes bit-shifts of >=32 (undefined behaviour), but
+              /* This test causes bit-shifts of >=32 (undefined behavior), but
                * on common platforms, information happens not to be lost, just
                * oddly arranged. */
               if (known_row_old[l * xsize + x] & (1u << (p - l * 8))) {
@@ -458,14 +467,17 @@ static void compat_load_020400(struct loaddata *loading,
   /* Server setting migration. */
   {
     int set_count;
+
     if (secfile_lookup_int(loading->file, &set_count, "settings.set_count")) {
       int i, new_opt = set_count;
       bool gamestart_valid
         = secfile_lookup_bool_default(loading->file, FALSE,
                                       "settings.gamestart_valid");
+
       for (i = 0; i < set_count; i++) {
         const char *name
           = secfile_lookup_str(loading->file, "settings.set%d.name", i);
+
         if (!name) {
           continue;
         }
@@ -473,9 +485,9 @@ static void compat_load_020400(struct loaddata *loading,
         /* In 2.3.x and prior, saveturns=0 meant no turn-based saves.
          * This is now controlled by the "autosaves" setting. */
         if (!fc_strcasecmp("saveturns", name)) {
-          /* XXX: hardcodes details from GAME_AUTOSAVES_DEFAULT
+          /* XXX: Hardcodes details from GAME_AUTOSAVES_DEFAULT
            * and settings.c:autosaves_name() (but these defaults reflect
-           * 2.3's behaviour). */
+           * 2.3's behavior). */
           const char *const nosave = "GAMEOVER|QUITIDLE|INTERRUPT";
           const char *const save = "TURN|GAMEOVER|QUITIDLE|INTERRUPT";
           int nturns;
@@ -1168,6 +1180,9 @@ static void compat_load_020600(struct loaddata *loading,
         case ENTRY_FILEREFERENCE:
           fc_assert(entries[j].type != ENTRY_FILEREFERENCE);
           break;
+        case ENTRY_LONG_COMMENT:
+          fc_assert(entries[j].type != ENTRY_LONG_COMMENT);
+          break;
         case ENTRY_ILLEGAL:
           fc_assert(entries[j].type != ENTRY_ILLEGAL);
           break;
@@ -1623,8 +1638,7 @@ static void unit_order_activity_to_action(struct unit *act_unit)
     }
 
     switch (order->activity) {
-    case ACTIVITY_FALLOUT:
-    case ACTIVITY_POLLUTION:
+    case ACTIVITY_CLEAN:
     case ACTIVITY_MINE:
     case ACTIVITY_IRRIGATE:
     case ACTIVITY_PLANT:
@@ -1638,7 +1652,7 @@ static void unit_order_activity_to_action(struct unit *act_unit)
       action_iterate(act_id) {
         struct action *paction = action_by_number(act_id);
 
-        if (actres_get_activity(paction->result) == order->activity) {
+        if (action_get_activity(paction) == order->activity) {
           order->order = ORDER_PERFORM_ACTION;
           order->action = action_number(paction);
           order->activity = ACTIVITY_LAST;
@@ -1653,13 +1667,7 @@ static void unit_order_activity_to_action(struct unit *act_unit)
     case ACTIVITY_IDLE:
     case ACTIVITY_GOTO:
     case ACTIVITY_FORTIFIED:
-    case ACTIVITY_OLD_ROAD:
-    case ACTIVITY_OLD_RAILROAD:
-    case ACTIVITY_FORTRESS:
-    case ACTIVITY_AIRBASE:
-    case ACTIVITY_PATROL_UNUSED:
     case ACTIVITY_LAST:
-    case ACTIVITY_UNKNOWN:
       log_error("Activity %d is not supposed to appear in unit orders",
                 order->activity);
       break;
@@ -1877,6 +1885,521 @@ static void compat_post_load_030100(struct loaddata *loading,
   } players_iterate_alive_end;
 }
 
+/************************************************************************//**
+  Translate savegame secfile data from 3.1.x to 3.2.0 format.
+  Note that even after 2.6 savegame has gone through all the compatibility
+  functions, it's still 2.6 savegame in the sense that savegame2.c, and not
+  savegame3.c, handles it.
+****************************************************************************/
+static void compat_load_030200(struct loaddata *loading,
+                               enum sgf_version format_class)
+{
+  int i;
+  int count;
+  int set_count;
+  bool gamestart_valid = FALSE;
+
+  /* Check status and return if not OK (sg_success FALSE). */
+  sg_check_ret();
+
+  log_debug("Upgrading data from savegame to version 3.2.0");
+
+  {
+    const char *str = secfile_lookup_str_default(loading->file, NULL,
+                                                 "savefile.orig_version");
+
+    if (str == NULL) {
+      /* Make sure CURRENTLY running version does not
+       * end as orig_version when we resave. */
+      if (format_class == SAVEGAME_3) {
+        secfile_insert_str(loading->file, "old savegame3, or older",
+                           "savefile.orig_version");
+      } else {
+        fc_assert(format_class == SAVEGAME_2);
+
+        secfile_insert_str(loading->file, "savegame2, or older",
+                           "savefile.orig_version");
+      }
+    }
+  }
+
+  {
+    int action_count;
+
+    action_count = secfile_lookup_int_default(loading->file, 0,
+                                              "savefile.action_size");
+
+    if (action_count > 0) {
+      const char **modname;
+      const char **savemod;
+      int j;
+      const char *dur_name = "Transport Deboard";
+      const char *clean_name = "Clean";
+
+      modname = secfile_lookup_str_vec(loading->file, &loading->action.size,
+                                       "savefile.action_vector");
+
+      savemod = fc_calloc(action_count, sizeof(*savemod));
+
+      for (j = 0; j < action_count; j++) {
+        if (!fc_strcasecmp("Transport Alight", modname[j])) {
+          savemod[j] = dur_name;
+        } else if (!fc_strcasecmp("Clean Pollution", modname[j])
+                   || !fc_strcasecmp("Clean Fallout", modname[j])) {
+          savemod[j] = clean_name;
+        } else {
+          savemod[j] = modname[j];
+        }
+      }
+
+      secfile_replace_str_vec(loading->file, savemod, action_count,
+                              "savefile.action_vector");
+
+      free(savemod);
+    }
+  }
+
+  {
+    int activities_count;
+
+    activities_count = secfile_lookup_int_default(loading->file, 0,
+                                                  "savefile.activities_size");
+
+    if (activities_count > 0) {
+      const char **modname;
+      const char **savemod;
+      int j;
+      const char *clean_name = "Clean";
+
+      modname = secfile_lookup_str_vec(loading->file, &loading->activities.size,
+                                       "savefile.activities_vector");
+
+      savemod = fc_calloc(activities_count, sizeof(*savemod));
+
+      for (j = 0; j < activities_count; j++) {
+        if (!fc_strcasecmp("Pollution", modname[j])
+            || !fc_strcasecmp("Fallout", modname[j])) {
+          savemod[j] = clean_name;
+        } else {
+          savemod[j] = modname[j];
+        }
+      }
+
+      secfile_replace_str_vec(loading->file, savemod, activities_count,
+                              "savefile.activities_vector");
+
+      free(savemod);
+    }
+  }
+
+  /* Server setting migration. */
+  {
+    if (secfile_lookup_int(loading->file, &set_count, "settings.set_count")) {
+      int alltemperate_idx = -1, singlepole_idx = -1;
+      bool count_changed = FALSE;
+
+      gamestart_valid
+        = secfile_lookup_bool_default(loading->file, FALSE,
+                                      "settings.gamestart_valid");
+
+      for (i = 0; i < set_count; i++) {
+        const char *old_name
+          = secfile_lookup_str(loading->file, "settings.set%d.name", i);
+        const char *name;
+
+        if (!old_name) {
+          continue;
+        }
+
+        name = setcompat_S3_2_name_from_S3_1(old_name);
+
+        if (fc_strcasecmp(old_name, name)) {
+          /* Setting's name changed */
+          secfile_replace_str(loading->file, name, "settings.set%d.name", i);
+        }
+
+        if (!gamestart_valid) {
+          /* Older savegames saved these values even when they were not valid.
+           * Silence warnings caused by them. */
+          (void) secfile_entry_lookup(loading->file, "settings.set%d.gamestart", i);
+          (void) secfile_entry_lookup(loading->file, "settings.set%d.gamesetdef", i);
+        }
+
+        if (!fc_strcasecmp("compresstype", name)) {
+          const char *val = secfile_lookup_str(loading->file,
+                                               "settings.set%d.value", i);
+          if (!fc_strcasecmp(val, "BZIP2")) {
+#ifdef FREECIV_HAVE_LIBZSTD
+            secfile_replace_str(loading->file, "ZSTD",
+                                "settings.set%d.value", i);
+#elif FREECIV_HAVE_LIBLZMA
+            secfile_replace_str(loading->file, "XZ",
+                                "settings.set%d.value", i);
+#elif FREECIV_HAVE_LIBZ
+            secfile_replace_str(loading->file, "LIBZ",
+                                "settings.set%d.value", i);
+#else
+            secfile_replace_str(loading->file, "PLAIN",
+                                "settings.set%d.value", i);
+#endif
+          }
+
+          if (gamestart_valid) {
+            val = secfile_lookup_str(loading->file,
+                                     "settings.set%d.gamestart", i);
+            if (!fc_strcasecmp(val, "BZIP2")) {
+#ifdef FREECIV_HAVE_LIBZSTD
+              secfile_replace_str(loading->file, "ZSTD",
+                                  "settings.set%d.gamestart", i);
+#elif FREECIV_HAVE_LIBLZMA
+              secfile_replace_str(loading->file, "XZ",
+                                  "settings.set%d.gamestart", i);
+#elif FREECIV_HAVE_LIBZ
+              secfile_replace_str(loading->file, "LIBZ",
+                                  "settings.set%d.gamestart", i);
+#else
+              secfile_replace_str(loading->file, "PLAIN",
+                                  "settings.set%d.gamestart", i);
+#endif
+            }
+          }
+        } else if (!fc_strcasecmp("topology", name)) {
+          struct setting *pset = setting_by_name(name);
+          struct sf_cb_data info = { pset, TRUE };
+          int val;
+
+          if (secfile_lookup_enum_data(loading->file, &val, TRUE,
+                                       setting_bitwise_secfile_str, &info,
+                                       "settings.set%d.value", i)) {
+            char wrap[100];
+            char buf[100];
+
+            if (val & TF_OLD_WRAPX) {
+              if (val & TF_OLD_WRAPY) {
+                fc_strlcpy(wrap, "WrapX|WrapY", sizeof(wrap));
+              } else {
+                fc_strlcpy(wrap, "WrapX", sizeof(wrap));
+              }
+            } else if (val & TF_OLD_WRAPY) {
+              fc_strlcpy(wrap, "WrapY", sizeof(wrap));
+            } else {
+              fc_strlcpy(wrap, "", sizeof(wrap));
+            }
+
+            if (val & TF_ISO) {
+              if (val & TF_HEX) {
+                setting_bitwise_set(pset, "ISO|HEX", NULL, NULL, 0);
+              } else {
+                setting_bitwise_set(pset, "ISO", NULL, NULL, 0);
+              }
+            } else if (val & TF_HEX) {
+              setting_bitwise_set(pset, "HEX", NULL, NULL, 0);
+            } else {
+              setting_bitwise_set(pset, "", NULL, NULL, 0);
+            }
+
+            setting_value_name(pset, FALSE, buf, sizeof(buf));
+            secfile_replace_str(loading->file, buf,
+                                "settings.set%d.value", i);
+
+            secfile_insert_str(loading->file,
+                               "wrap", "settings.set%d.name", set_count);
+            secfile_insert_str(loading->file,
+                               wrap, "settings.set%d.value", set_count);
+
+            if (gamestart_valid) {
+              if (secfile_lookup_enum_data(loading->file, &val, TRUE,
+                                           setting_bitwise_secfile_str, &info,
+                                           "settings.set%d.gamestart", i)) {
+                if (val & TF_OLD_WRAPX) {
+                  if (val & TF_OLD_WRAPY) {
+                    fc_strlcpy(wrap, "WrapX|WrapY", sizeof(wrap));
+                  } else {
+                    fc_strlcpy(wrap, "WrapX", sizeof(wrap));
+                  }
+                } else if (val & TF_OLD_WRAPY) {
+                  fc_strlcpy(wrap, "WrapY", sizeof(wrap));
+                } else {
+                  fc_strlcpy(wrap, "", sizeof(wrap));
+                }
+
+                if (val & TF_ISO) {
+                  if (val & TF_HEX) {
+                    setting_bitwise_set(pset, "ISO|HEX", NULL, NULL, 0);
+                  } else {
+                    setting_bitwise_set(pset, "ISO", NULL, NULL, 0);
+                  }
+                } else if (val & TF_HEX) {
+                  setting_bitwise_set(pset, "HEX", NULL, NULL, 0);
+                } else {
+                  setting_bitwise_set(pset, "", NULL, NULL, 0);
+                }
+
+                setting_value_name(pset, FALSE, buf, sizeof(buf));
+                secfile_replace_str(loading->file, buf,
+                                    "settings.set%d.gamestart", i);
+
+                secfile_insert_str(loading->file,
+                                   wrap, "settings.set%d.gamestart", set_count);
+              }
+            }
+
+            set_count++;
+            count_changed = TRUE;
+          }
+        } else if (!fc_strcasecmp("alltemperate", name)) {
+          alltemperate_idx = i;
+        } else if (!fc_strcasecmp("singlepole", name)) {
+          singlepole_idx = i;
+        }
+      }
+
+      if (alltemperate_idx >= 0 || singlepole_idx >= 0) {
+        int north_latitude, south_latitude;
+        int north_idx, south_idx;
+        bool alltemperate, singlepole;
+
+        if (alltemperate_idx < 0
+            || !secfile_lookup_bool(loading->file, &alltemperate,
+                                    "settings.set%d.value",
+                                    alltemperate_idx)) {
+          /* Infer what would've been the ruleset default */
+          alltemperate = (wld.map.north_latitude == wld.map.south_latitude);
+        }
+
+        if (singlepole_idx < 0
+            || !secfile_lookup_bool(loading->file, &singlepole,
+                                    "settings.set%d.value",
+                                    singlepole_idx)) {
+          /* Infer what would've been the ruleset default */
+          singlepole = (wld.map.south_latitude >= 0);
+        }
+
+        /* Note: hard-coding 1000-based latitudes here; if MAX_LATITUDE ever
+         * changes, that'll have to be handled in later migrations anyway */
+        north_latitude = alltemperate ? 500 : 1000;
+        south_latitude = alltemperate ? 500 : (singlepole ? 0 : -1000);
+
+        /* Replace alltemperate with northlatitude, and singlepole with
+         * southlatitude. If only one of the two was given, add the other
+         * at the end. */
+        north_idx = (alltemperate_idx < 0) ? set_count : alltemperate_idx;
+        south_idx = (singlepole_idx < 0) ? set_count : singlepole_idx;
+
+        secfile_replace_str(loading->file, "northlatitude",
+                            "settings.set%d.name", north_idx);
+        secfile_replace_int(loading->file, north_latitude,
+                            "settings.set%d.value", north_idx);
+
+        secfile_replace_str(loading->file, "southlatitude",
+                            "settings.set%d.name", south_idx);
+        secfile_replace_int(loading->file, south_latitude,
+                            "settings.set%d.value", south_idx);
+
+        if (gamestart_valid) {
+          if (alltemperate_idx < 0
+              || !secfile_lookup_bool(loading->file, &alltemperate,
+                                      "settings.set%d.gamestart",
+                                      alltemperate_idx)) {
+            alltemperate =
+                (wld.map.north_latitude == wld.map.south_latitude);
+          }
+
+          if (singlepole_idx < 0
+              || !secfile_lookup_bool(loading->file, &singlepole,
+                                      "settings.set%d.gamestart",
+                                      singlepole_idx)) {
+            singlepole = (wld.map.south_latitude >= 0);
+          }
+
+          north_latitude = alltemperate ? 500 : 1000;
+          south_latitude = alltemperate ? 500 : (singlepole ? 0 : -1000);
+
+          secfile_replace_int(loading->file, north_latitude,
+                              "settings.set%d.gamestart", north_idx);
+          secfile_replace_int(loading->file, south_latitude,
+                              "settings.set%d.gamestart", south_idx);
+        }
+
+        if (alltemperate_idx < 0 || singlepole_idx < 0) {
+          /* only one was given and replaced ~> we added one new entry */
+          set_count++;
+          count_changed = TRUE;
+        }
+      }
+
+      if (count_changed) {
+        secfile_replace_int(loading->file, set_count,
+                            "settings.set_count");
+      }
+    }
+  }
+
+  {
+    /* Turn old AI level field to a setting. */
+    const char *level;
+    enum ai_level lvl;
+
+    level = secfile_lookup_str_default(loading->file, NULL, "game.level");
+    if (level != NULL && !fc_strcasecmp("Handicapped", level)) {
+      /* Up to freeciv-3.1 Restricted AI level was known as Handicapped */
+      lvl = AI_LEVEL_RESTRICTED;
+    } else {
+      lvl = ai_level_by_name(level, fc_strcasecmp);
+    }
+
+    if (!ai_level_is_valid(lvl)) {
+      log_sg("Invalid AI level \"%s\". "
+             "Changed to \"%s\".", level,
+             ai_level_name(GAME_HARDCODED_DEFAULT_SKILL_LEVEL));
+      lvl = GAME_HARDCODED_DEFAULT_SKILL_LEVEL;
+    }
+
+    secfile_insert_str(loading->file, "ailevel", "settings.set%d.name", set_count);
+    secfile_insert_enum(loading->file, lvl, ai_level, "settings.set%d.value", set_count);
+
+    if (gamestart_valid) {
+      secfile_insert_enum(loading->file, lvl, ai_level, "settings.set%d.gamestart",
+                          set_count);
+    }
+
+    set_count++;
+    secfile_replace_int(loading->file, set_count, "settings.set_count");
+  }
+
+  if (format_class != SAVEGAME_2) {
+    /* Replace got_tech[_multi] bools on free_bulbs integers. */
+    /* Older savegames had a bug that got_tech_multi was not saved. */
+    count = secfile_lookup_int_default(loading->file, 0, "research.count");
+    for (i = 0; i < count; i++) {
+      bool got_tech = FALSE;
+      int bulbs = 0;
+      bool got_tech_multi
+        = secfile_lookup_bool_default(loading->file, FALSE,
+                                      "research.r%d.got_tech_multi", i);
+
+      if (secfile_lookup_bool(loading->file, &got_tech,
+                              "research.r%d.got_tech", i)
+          && secfile_lookup_int(loading->file, &bulbs,
+                                "research.r%d.bulbs", i)) {
+        secfile_insert_int(loading->file,
+                           got_tech || got_tech_multi ? bulbs : 0,
+                           "research.r%d.free_bulbs", i);
+      }
+    }
+  }
+
+  /* Older savegames unnecessarily saved diplstate type order.
+   * Silence "unused entry" warnings about those. */
+  {
+    int dscount = secfile_lookup_int_default(loading->file, 0,
+                                             "savefile.diplstate_type_size");
+
+    for (i = 0; i < dscount; i++) {
+      (void) secfile_entry_lookup(loading->file,
+                                  "savefile.diplstate_type_vector,%d", i);
+    }
+  }
+
+  /* Add wl_max_length entries for players */
+  {
+    player_slots_iterate(pslot) {
+      int plrno = player_slot_index(pslot);
+      int ncities;
+      int cnro;
+      size_t wlist_max_length = 0;
+      bool first_city;
+
+      if (secfile_section_lookup(loading->file, "player%d", plrno) == NULL) {
+        continue;
+      }
+
+      first_city = secfile_lookup_bool_default(loading->file, FALSE,
+                                               "player%d.got_first_city",
+                                               plrno);
+      if (first_city) {
+        const char **flag_names = fc_calloc(PLRF_COUNT, sizeof(char *));
+        int flagcount = 0;
+        const char **flags_sg;
+        size_t nval;
+
+        flag_names[flagcount++] = plr_flag_id_name(PLRF_FIRST_CITY);
+
+        flags_sg = secfile_lookup_str_vec(loading->file, &nval,
+                                          "player%d.flags", plrno);
+
+        for (i = 0; i < nval; i++) {
+          enum plr_flag_id fid = plr_flag_id_by_name(flags_sg[i],
+                                                     fc_strcasecmp);
+
+          flag_names[flagcount++] = plr_flag_id_name(fid);
+        }
+
+        secfile_replace_str_vec(loading->file, flag_names, flagcount,
+                                "player%d.flags", plrno);
+
+        free(flag_names);
+      }
+
+      ncities = secfile_lookup_int_default(loading->file, 0,
+                                           "player%d.ncities", plrno);
+
+      for (cnro = 0; cnro < ncities; cnro++) {
+        int wl_length = secfile_lookup_int_default(loading->file, 0,
+                                                   "player%d.c%d.wl_length",
+                                                   plrno, cnro);
+
+        wlist_max_length = MAX(wlist_max_length, wl_length);
+
+        if (format_class == SAVEGAME_3) {
+          if (secfile_lookup_int_default(loading->file, plrno,
+                                         "player%d.c%d.original",
+                                         plrno, cnro) != plrno) {
+            secfile_insert_int(loading->file, CACQ_CONQUEST,
+                               "player%d.c%d.acquire_t",
+                               plrno, cnro);
+          } else {
+            secfile_insert_int(loading->file, CACQ_FOUNDED,
+                               "player%d.c%d.acquire_t",
+                               plrno, cnro);
+          }
+
+          secfile_insert_int(loading->file, WLCB_SMART,
+                             "player%d.c%d.wlcb",
+                             plrno, cnro);
+        }
+      }
+
+      secfile_insert_int(loading->file, wlist_max_length,
+                         "player%d.wl_max_length", plrno);
+
+      if (format_class == SAVEGAME_3) {
+        int nunits;
+        int unro;
+        size_t olist_max_length = 0;
+
+        nunits = secfile_lookup_int_default(loading->file, 0,
+                                            "player%d.nunits", plrno);
+
+        for (unro = 0; unro < nunits; unro++) {
+          int ol_length = secfile_lookup_int_default(loading->file, 0,
+                                                     "player%d.u%d.orders_length",
+                                                     plrno, unro);
+
+          olist_max_length = MAX(olist_max_length, ol_length);
+        }
+
+        secfile_insert_int(loading->file, olist_max_length,
+                           "player%d.orders_max_length", plrno);
+
+        secfile_insert_int(loading->file, MAX_TRADE_ROUTES_OLD,
+                           "player%d.routes_max_length", plrno);
+      }
+
+    } player_slots_iterate_end;
+  }
+}
+
 /************************************************************************//**
   Convert old ai level value to ai_level
 ****************************************************************************/
@@ -1922,23 +2445,3 @@ enum barbarian_type barb_type_convert(int old_type)
 
   return barbarian_type_invalid();
 }
-
-/************************************************************************//**
-  Assign a new base building task to unit
-****************************************************************************/
-void set_unit_activity_base(struct unit *punit,
-                            Base_type_id base)
-{
-  set_unit_activity_targeted(punit, ACTIVITY_BASE,
-                             base_extra_get(base_by_number(base)));
-}
-
-/************************************************************************//**
-  Assign a new road building task to unit
-****************************************************************************/
-void set_unit_activity_road(struct unit *punit,
-                            Road_type_id road)
-{
-  set_unit_activity_targeted(punit, ACTIVITY_GEN_ROAD,
-                             road_extra_get(road_by_number(road)));
-}
