@@ -47,8 +47,10 @@ class edit_impr : public values_dlg
     QToolButton *genus_button;
     QLineEdit *gfx_tag;
     QLineEdit *gfx_tag_alt;
+    QLineEdit *gfx_tag_alt2;
     QLineEdit *sound_tag;
     QLineEdit *sound_tag_alt;
+    QLineEdit *sound_tag_alt2;
 
     QGridLayout *flag_layout;
 
@@ -61,8 +63,10 @@ class edit_impr : public values_dlg
     void genus_menu(QAction *action);
     void gfx_tag_given();
     void gfx_tag_alt_given();
+    void gfx_tag_alt2_given();
     void sound_tag_given();
     void sound_tag_alt_given();
+    void sound_tag_alt2_given();
     void helptext();
 };
 
