@@ -96,6 +96,15 @@ edit_terrain::edit_terrain(ruledit_gui *ui_in, struct terrain *ter_in) : values_
   ter_layout->addWidget(label, row, 0);
   ter_layout->addWidget(gfx_tag_alt, row++, 1);
 
+  label = new QLabel(QString::fromUtf8(R__("Second alt graphics tag")));
+  label->setParent(this);
+
+  gfx_tag_alt2 = new QLineEdit(this);
+  connect(gfx_tag_alt2, SIGNAL(returnPressed()), this, SLOT(gfx_tag_alt2_given()));
+
+  ter_layout->addWidget(label, row, 0);
+  ter_layout->addWidget(gfx_tag_alt2, row++, 1);
+
   button = new QPushButton(QString::fromUtf8(R__("Helptext")), this);
   connect(button, SIGNAL(pressed()), this, SLOT(helptext()));
   ter_layout->addWidget(button, row++, 1);
@@ -152,6 +161,7 @@ void edit_terrain::closeEvent(QCloseEvent *cevent)
   // Save values from text fields.
   gfx_tag_given();
   gfx_tag_alt_given();
+  gfx_tag_alt2_given();
 
   BV_CLR_ALL(ter->native_to);
   for (int i = 0; i < game.control.num_unit_classes; i++) {
@@ -190,6 +200,7 @@ void edit_terrain::refresh()
   defense->setValue(ter->defense_bonus);
   gfx_tag->setText(ter->graphic_str);
   gfx_tag_alt->setText(ter->graphic_alt);
+  gfx_tag_alt2->setText(ter->graphic_alt2);
 }
 
 /**********************************************************************//**
@@ -232,6 +243,16 @@ void edit_terrain::gfx_tag_alt_given()
   sz_strlcpy(ter->graphic_alt, tag_bytes);
 }
 
+/**********************************************************************//**
+  User entered new second alternative graphics tag.
+**************************************************************************/
+void edit_terrain::gfx_tag_alt2_given()
+{
+  QByteArray tag_bytes = gfx_tag_alt2->text().toUtf8();
+
+  sz_strlcpy(ter->graphic_alt2, tag_bytes);
+}
+
 /**********************************************************************//**
   User pressed helptext button
 **************************************************************************/
