@@ -23,8 +23,8 @@
 
   When the user tries to read a token, we return a (const char*)
   pointing to some data if the token was found, or NULL otherwise.
-  The data pointed to should not be modified.  The retuned pointer
-  is valid _only_ until another inputfile is performed.  (So should
+  The data pointed to should not be modified. The returned pointer
+  is valid _only_ until another inputfile is performed. (So should
   be used immediately, or fc_strdup-ed etc.)
   
   The tokens recognised are as follows:
@@ -57,8 +57,8 @@
 	  raw embedded newlines, and escaped doublequotes, or \.
 	  eg:  '123', '-999', '"foo"', '_("foo")'
   returned token: string containing number, for numeric, or string
-          starting at first doublequote for strings, but ommiting
-	  trailing double-quote.  Note this does _not_ translate
+          starting at first doublequote for strings, but omitting
+	  trailing double-quote. Note this does _not_ translate
 	  escaped doublequotes etc back to normal.
 
 ***********************************************************************/
@@ -284,7 +284,7 @@ static void inf_close_partial(struct inputfile *inf)
   astr_free(&inf->token);
   astr_free(&inf->partial);
 
-  /* Assign zeros for safety if accidently reuse etc: */
+  /* Assign zeros for safety if accidentally reuse etc: */
   init_zeros(inf);
   inf->magic = ~INF_MAGIC;
 
@@ -382,14 +382,14 @@ static bool check_include(struct inputfile *inf)
     return FALSE;
   }
 
-  if (strncmp(astr_str(&inf->cur_line), include_prefix, len) != 0) {
+  if (fc_strncmp(astr_str(&inf->cur_line), include_prefix, len)) {
     return FALSE;
   }
 
-  /* from here, the include-line must be well formed */
-  /* keep inf->cur_line_pos accurate just so error messages are useful */
+  /* From here, the include-line must be well formed.
+   * Keep inf->cur_line_pos accurate just so error messages are useful */
 
-  /* skip any whitespace: */
+  /* Skip any whitespace: */
   inf->cur_line_pos = len;
   c = astr_str(&inf->cur_line) + len;
   while (*c != '\0' && fc_isspace(*c)) {
