@@ -16,7 +16,7 @@
   available on all platforms. Where the functions are available
   natively, these are (mostly) just wrappers.
 
-  Notice the function names here are prefixed by, eg, "fc".
+  Notice the function names here are prefixed by, eg, "fc_".
   An alternative would be to use the "standard" function name, and
   provide the implementation only if required. However the method
   here has some advantages:
@@ -32,8 +32,8 @@
 
    - We can add some extra stuff to these functions if we want.
 
-  The main disadvantage is remembering to use these "fc" functions on
-  systems which have the functions natively.
+  The main disadvantage is need to remember to use these
+  "fc_" functions on systems which have the functions natively.
 
 ***********************************************************************/
 
@@ -53,7 +53,7 @@
 #include <sys/stat.h>
 
 #ifdef GENERATING_MAC
-#include <events.h>		/* for WaitNextEvent() */
+#include <events.h>             /* for WaitNextEvent() */
 #endif
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
@@ -71,7 +71,7 @@
 #include <sys/types.h>
 #endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>		/* usleep, fcntl, gethostname */
+#include <unistd.h>             /* usleep, fcntl, gethostname */
 #endif
 #ifdef HAVE_TIME_H
 #include <time.h>               /* nanosleep */
@@ -163,7 +163,7 @@ static void icu_buffers_increase(void)
 static void fc_strAPI_init(void)
 {
   if (icu_buffer_uchars == 0) {
-    fc_init_mutex(&icu_buffer_mutex);
+    fc_mutex_init(&icu_buffer_mutex);
     icu_buffers_initial();
   }
 }
@@ -180,11 +180,11 @@ static void fc_strAPI_free(void)
     icu_buffer2 = NULL;
     icu_buffer_uchars = 0;
   }
-  fc_destroy_mutex(&icu_buffer_mutex);
+  fc_mutex_destroy(&icu_buffer_mutex);
 }
 
 /************************************************************************//**
-  Compare strings like strcmp(), but ignoring case.
+  Compare strings like strcmp(), but ignoring case. UTF8 aware.
 ****************************************************************************/
 int fc_strcasecmp(const char *str0, const char *str1)
 {
@@ -205,7 +205,7 @@ int fc_strcasecmp(const char *str0, const char *str1)
     fc_strAPI_init();
   }
 
-  fc_allocate_mutex(&icu_buffer_mutex);
+  fc_mutex_allocate(&icu_buffer_mutex);
 
   while (!enough_mem) {
     UErrorCode err_code0 = U_ZERO_ERROR;
@@ -226,14 +226,14 @@ int fc_strcasecmp(const char *str0, const char *str1)
   ret = u_strCaseCompare(icu_buffer1, -1, icu_buffer2, -1,
                          0, &err_code);
 
-  fc_release_mutex(&icu_buffer_mutex);
+  fc_mutex_release(&icu_buffer_mutex);
 
   return ret;
 }
 
 /************************************************************************//**
   Compare strings like strncmp(), but ignoring case.
-  ie, only compares first n chars.
+  i.e. only compares first n chars. UTF8 aware.
 ****************************************************************************/
 int fc_strncasecmp(const char *str0, const char *str1, size_t n)
 {
@@ -254,7 +254,7 @@ int fc_strncasecmp(const char *str0, const char *str1, size_t n)
     fc_strAPI_init();
   }
 
-  fc_allocate_mutex(&icu_buffer_mutex);
+  fc_mutex_allocate(&icu_buffer_mutex);
 
   while (!enough_mem) {
     UErrorCode err_code0 = U_ZERO_ERROR;
@@ -282,7 +282,7 @@ int fc_strncasecmp(const char *str0, const char *str1, size_t n)
   ret = u_strCaseCompare(icu_buffer1, len0, icu_buffer2, len1,
                          0, &err_code);
 
-  fc_release_mutex(&icu_buffer_mutex);
+  fc_mutex_release(&icu_buffer_mutex);
 
   return ret;
 }
@@ -359,6 +359,7 @@ void remove_escapes(const char *str, bool full_escapes,
 size_t effectivestrlenquote(const char *str)
 {
   int len;
+
   if (!str) {
     return 0;
   }
@@ -613,9 +614,9 @@ const char *fc_strerror(fc_errno err)
   static char buf[256];
 
   if (!FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-		     NULL, err, 0, buf, sizeof(buf), NULL)) {
+                     NULL, err, 0, buf, sizeof(buf), NULL)) {
     fc_snprintf(buf, sizeof(buf),
-		_("error %ld (failed FormatMessage)"), err);
+                _("error %ld (failed FormatMessage)"), err);
   }
   return buf;
 #else  /* FREECIV_MSWINDOWS */
@@ -628,7 +629,7 @@ const char *fc_strerror(fc_errno err)
   static char buf[64];
 
   fc_snprintf(buf, sizeof(buf),
-	      _("error %d (compiled without strerror)"), err);
+              _("error %d (compiled without strerror)"), err);
   return buf;
 #endif /* HAVE_STRERROR */
 #endif /* FREECIV_MSWINDOWS */
@@ -655,17 +656,18 @@ void fc_usleep(unsigned long usec)
 #ifdef HAVE_USLEEP
   usleep(usec);
 #else  /* HAVE_USLEEP */
-#ifdef HAVE_SNOOZE		/* BeOS */
+#ifdef HAVE_SNOOZE              /* BeOS */
   snooze(usec);
 #else  /* HAVE_SNOOZE */
 #ifdef GENERATING_MAC
-  EventRecord the_event;	/* dummy - always be a null event */
+  EventRecord the_event;        /* dummy - always be a null event */
 
-  usec /= 16666;		/* microseconds to 1/60th seconds */
+  usec /= 16666;                /* microseconds to 1/60th seconds */
   if (usec < 1) {
     usec = 1;
   }
-  /* supposed to give other application processor time for the mac */
+
+  /* Supposed to give other application processor time for the mac */
   WaitNextEvent(0, &the_event, usec, 0L);
 #else  /* GENERATING_MAC */
 #ifdef FREECIV_MSWINDOWS
@@ -675,7 +677,7 @@ void fc_usleep(unsigned long usec)
 
   tv.tv_sec = 0;
   tv.tv_usec = usec;
-  /* FIXME: an interrupt can cause an EINTR return here.  In that case we
+  /* FIXME: an interrupt can cause an EINTR return here. In that case we
    * need to have another select call. */
   fc_select(0, NULL, NULL, NULL, &tv);
 #endif /* FREECIV_MSWINDOWS */
@@ -697,13 +699,14 @@ char *fc_strrep_resize(char *str, size_t *len, const char *search,
 
   fc_assert_ret_val(str != NULL, NULL);
   fc_assert_ret_val(len != NULL, NULL);
+
   if (search == NULL || replace == NULL) {
     return str;
   }
 
   len_max = ceil((double)strlen(str) * strlen(replace) / strlen(search)) + 1;
   if ((*len) < len_max) {
-    /* replace string is longer than search string; allocate enough memory
+    /* Replace string is longer than search string; allocate enough memory
      * for the worst case */
     (*len) = len_max;
     str = fc_realloc(str, len_max);
@@ -735,6 +738,7 @@ bool fc_strrep(char *str, size_t len, const char *search,
   char *s, *p;
 
   fc_assert_ret_val(str != NULL, FALSE);
+
   if (search == NULL || replace == NULL) {
     return TRUE;
   }
@@ -746,7 +750,7 @@ bool fc_strrep(char *str, size_t len, const char *search,
   while (s != NULL) {
     p = strstr(s, search);
     if (p == NULL) {
-      /* nothing found */
+      /* Nothing found */
       break;
     }
 
@@ -780,7 +784,7 @@ bool fc_strrep(char *str, size_t len, const char *search,
   truncation occurred.
 
   Not sure about the asserts below, but they are easier than
-  trying to ensure correct behaviour on strange inputs.
+  trying to ensure correct behavior on strange inputs.
   In particular note that n == 0 is prohibited (e.g., since there
   must at least be room for a nul); could consider other options.
 ****************************************************************************/
@@ -799,7 +803,7 @@ size_t fc_strlcpy(char *dest, const char *src, size_t n)
     fc_strAPI_init();
   }
 
-  fc_allocate_mutex(&icu_buffer_mutex);
+  fc_mutex_allocate(&icu_buffer_mutex);
 
   while (!enough_mem) {
     u_strFromUTF8(icu_buffer1, icu_buffer_uchars, &slen, src, -1, &err_code);
@@ -816,7 +820,7 @@ size_t fc_strlcpy(char *dest, const char *src, size_t n)
 
   u_strToUTF8(dest, n - 1, &dlen, icu_buffer1, slen, &err_code);
 
-  fc_release_mutex(&icu_buffer_mutex);
+  fc_mutex_release(&icu_buffer_mutex);
 
   dest[n - 1] = '\0';
 
@@ -921,7 +925,7 @@ int fc_vsnprintf(char *str, size_t n, const char *format, va_list ap)
       exit(EXIT_FAILURE);
     }
 
-    fc_allocate_mutex(&vsnprintf_mutex);
+    fc_mutex_allocate(&vsnprintf_mutex);
 
     if (vsnprintf_buf == NULL) {
       vsnprintf_buf = malloc(VSNP_BUF_SIZE);
@@ -929,7 +933,8 @@ int fc_vsnprintf(char *str, size_t n, const char *format, va_list ap)
       if (vsnprintf_buf == NULL) {
         fprintf(stderr, "Could not allocate %i bytes for vsnprintf() "
                 "replacement.", VSNP_BUF_SIZE);
-        fc_release_mutex(&vsnprintf_mutex);
+        fc_mutex_release(&vsnprintf_mutex);
+
         exit(EXIT_FAILURE);
       }
     }
@@ -956,7 +961,7 @@ int fc_vsnprintf(char *str, size_t n, const char *format, va_list ap)
       str[n - 1] = '\0';
     }
 
-    fc_release_mutex(&vsnprintf_mutex);
+    fc_mutex_release(&vsnprintf_mutex);
 
     return len;
   }
@@ -983,10 +988,10 @@ int fc_snprintf(char *str, size_t n, const char *format, ...)
   it does snprintf() to the end of an existing string.
 
   Like fc_strlcat(), n is the total length available for str, including
-  existing contents and trailing nul. If there is no extra room
+  existing contents and trailing NULL. If there is no extra room
   available in str, does not change the string.
 
-  Also like fc_strlcat(), returns the final length that str would have
+  Also like fc_strlcat, returns the final length that str would have
   had without truncation, or -1 if the end of the buffer is reached.
   I.e., if return is >= n, truncation occurred.
 
@@ -1106,9 +1111,9 @@ char *fc_read_console(void)
         *bufptr = '\0';
       }
       if (*bufptr == '\0') {
-	bufptr = console_buf;
+        bufptr = console_buf;
 
-	return console_buf;
+        return console_buf;
       }
       if ((bufptr - console_buf) <= CONSOLE_BUF_SIZE) {
         bufptr++; /* prevent overrun */
@@ -1154,7 +1159,7 @@ int fc_break_lines(char *str, size_t desired_len)
 
     num_lines++;
 
-    /* check if there is already a newline: */
+    /* Check if there is already a newline: */
     for (c = str; c < str + desired_len; c++) {
       if (*c == '\n') {
         slen -= c + 1 - str;
@@ -1163,7 +1168,7 @@ int fc_break_lines(char *str, size_t desired_len)
       }
     }
 
-    /* find space and break: */
+    /* Find space and break: */
     for (c = str + desired_len; c > str; c--) {
       if (fc_isspace(*c)) {
         *c = '\n';
@@ -1173,7 +1178,7 @@ int fc_break_lines(char *str, size_t desired_len)
       }
     }
 
-    /* couldn't find a good break; settle for a bad one... */
+    /* Couldn't find a good break; settle for a bad one... */
     for (c = str + desired_len + 1; *c != '\0'; c++) {
       if (fc_isspace(*c)) {
         *c = '\n';
@@ -1312,9 +1317,9 @@ struct tm *fc_localtime(const time_t *timep, struct tm *result)
 #ifdef HAVE_LOCALTIME_R
   return localtime_r(timep, result);
 #else  /* HAVE_LOCALTIME_R */
-  fc_allocate_mutex(&localtime_mutex);
+  fc_mutex_allocate(&localtime_mutex);
   memcpy(result, localtime(timep), sizeof(struct tm));
-  fc_release_mutex(&localtime_mutex);
+  fc_mutex_release(&localtime_mutex);
 
   return result;
 #endif /* HAVE_LOCALTIME_R */
@@ -1340,11 +1345,11 @@ void fc_support_init(void)
   fc_strAPI_init();
 
 #ifndef HAVE_WORKING_VSNPRINTF
-  fc_init_mutex(&vsnprintf_mutex);
+  fc_mutex_init(&vsnprintf_mutex);
 #endif /* HAVE_WORKING_VSNPRINTF */
 
 #ifndef HAVE_LOCALTIME_R
-  fc_init_mutex(&localtime_mutex);
+  fc_mutex_init(&localtime_mutex);
 #endif /* HAVE_LOCALTIME_R */
 
   support_initialized = TRUE;
@@ -1362,11 +1367,11 @@ void fc_support_free(void)
     free(vsnprintf_buf);
     vsnprintf_buf = NULL;
   }
-  fc_destroy_mutex(&vsnprintf_mutex);
+  fc_mutex_destroy(&vsnprintf_mutex);
 #endif /* HAVE_WORKING_VSNPRINTF */
 
 #ifndef HAVE_LOCALTIME_R
-  fc_destroy_mutex(&localtime_mutex);
+  fc_mutex_destroy(&localtime_mutex);
 #endif /* HAVE_LOCALTIME_R */
 
   fc_strAPI_free();
