@@ -7,18 +7,18 @@
 # This script is licensed under Gnu General Public License version 2 or later.
 # See COPYING available from the same location you got this script.
 
-# Version 2.4.2 (16-Dec-22)
+# Version 2.4.3 (28-Jan-23)
 
-WINBUILD_VERSION="2.4.2"
+WINBUILD_VERSION="2.4.3"
 MIN_WINVER=0x0603 # Windows 8.1, Qt6-client and Qt6-ruledit builds override this
-CROSSER_FEATURE_LEVEL=2.9
+CROSSER_FEATURE_LEVEL=2.10
 
-if test "x$1" = x || test "x$1" = "x-h" || test "x$1" = "x--help" ; then
+if test "$1" = "" || test "$1" = "-h" || test "$1" = "--help" ; then
   echo "Usage: $0 <crosser dir> [gui]"
   exit 1
 fi
 
-if test "x$1" = "x-v" || test "x$1" = "x--version" ; then
+if test "$1" = "-v" || test "$1" = "--version" ; then
   echo "winbuild.sh version $WINBUILD_VERSION"
   exit
 fi
@@ -35,10 +35,12 @@ if ! test -f "$DLLSPATH/crosser.txt" ; then
   exit 1
 fi
 
-VERREV="$(../../fc_version)"
-if test "x$INST_CROSS_MODE" != "xrelease" ; then
-  if test -d ../../.git || test -f ../../.git ; then
-    VERREV="$VERREV-$(cd ../.. && git rev-parse --short HEAD)"
+SRC_ROOT="$(cd ../.. || exit 1 ; pwd)"
+
+VERREV="$(${SRC_ROOT}/fc_version)"
+if test "$INST_CROSS_MODE" != "release" ; then
+  if test -d ${SRC_ROOT}/.git || test -f ${SRC_ROOT}/.git ; then
+    VERREV="$VERREV-$(cd ${SRC_ROOT} && git rev-parse --short HEAD)"
   fi
 fi
 
@@ -58,11 +60,12 @@ fi
 
 SETUP=$(grep "CrosserSetup=" $DLLSPATH/crosser.txt | sed -e 's/CrosserSetup="//' -e 's/"//')
 
-# Make this Qt-client/Ruledit specific as upstream updates
-# to Qt headers allow. Currently needed in all cases.
-CXXFLAGS="-Wno-error=attributes"
+# Make -Wno-error=attributes Qt-client/Ruledit specific as
+# upstream updates to Qt headers allow. Currently needed
+# in all cases.
+CXXFLAGS="-Wno-error=attributes -Wl,-allow-multiple-definition"
 
-if test "x$2" = "xruledit" ; then
+if test "$2" = "ruledit" ; then
   SINGLE_GUI=true
   GUIP="-ruledit"
   RULEDIT="yes"
@@ -70,11 +73,11 @@ if test "x$2" = "xruledit" ; then
   FCMP="no"
   SERVER="no"
   AIS="--enable-ai-static=stub"
-elif test "x$2" != "x" ; then
+elif test "$2" != "" ; then
   SINGLE_GUI=true
-  GUIP="-$2"
+  GUIP="-client-$2"
   SERVER="yes"
-  if test "x$2" = "xqt6" ; then
+  if test "$2" = "qt6" ; then
     RULEDIT="yes"
     CLIENTS="qt"
   else
@@ -82,7 +85,6 @@ elif test "x$2" != "x" ; then
     CLIENTS="$2"
   fi
   case $2 in
-    gtk3) FCMP="gtk3" ;;
     sdl2) FCMP="gtk4" ;;
     gtk3.22) FCMP="gtk3" ;;
     gtk4) FCMP="gtk4" ;;
@@ -98,15 +100,15 @@ else
   RULEDIT="yes"
 fi
 
-if test "x$NAMEP" = "x" ; then
+if test "$NAMEP" = "" ; then
   NAMEP="$GUIP"
 fi
 
-if test "x$MAKE_PARAMS" = "x" ; then
+if test "$MAKE_PARAMS" = "" ; then
   MAKE_PARAMS="-j$(nproc)"
 fi
 
-BUILD_DIR="build-${SETUP}${NAMEP}"
+BUILD_DIR="autotools/build/${SETUP}${NAMEP}"
 
 if ! rm -Rf "${BUILD_DIR}" ; then
   echo "Failed to clear out old build directory!" >&2
@@ -120,15 +122,15 @@ fi
 
 if test "$SETUP" = "win64" ; then
   TARGET=x86_64-w64-mingw32
-  if test "x$SINGLE_GUI" != "xtrue" ; then
-    CLIENTS="gtk3,sdl2,gtk3.22"
+  if test "$SINGLE_GUI" != "true" ; then
+    CLIENTS="sdl2,gtk3.22"
     FCMP="gtk3,cli"
   fi
   VERREV="win64-$VERREV"
 elif test "$SETUP" = "win32" ; then
   TARGET=i686-w64-mingw32
-  if test "x$SINGLE_GUI" != "xtrue" ; then
-    CLIENTS="gtk3,sdl2,gtk3.22"
+  if test "$SINGLE_GUI" != "true" ; then
+    CLIENTS="sdl2,gtk3.22"
     FCMP="gtk3,cli"
   fi
   VERREV="win32-$VERREV"
@@ -157,7 +159,7 @@ if test "${SINGLE_GUI}" != "true" ; then
   fi
 fi
 
-if test "x$QTVER" = "xQt6"; then
+if test "${QTVER}" = "Qt6"; then
   QTPARAMS="--with-qtver=Qt6 --with-qt6-includes=${DLLSPATH}/qt6/include --with-qt6-libs=${DLLSPATH}/lib"
   MOC_CROSSER="${DLLSPATH}/linux/libexec/moc-qt6"
 fi
@@ -171,30 +173,30 @@ echo "----------------------------------"
 export CC="$TARGET-gcc -static-libgcc -static-libstdc++"
 export CXX="$TARGET-g++ -static-libgcc -static-libstdc++"
 
-if ! ../../autogen.sh --no-configure-run ; then
+if ! ${SRC_ROOT}/autogen.sh --no-configure-run ; then
   echo "Autogen failed" >&2
   exit 1
 fi
 
-INSTALL_DIR="$(pwd)/freeciv-${VERREV}${NAMEP}"
+INSTALL_DIR="$(pwd)/autotools/install/freeciv-${VERREV}${NAMEP}"
 
 if ! (
 cd "${BUILD_DIR}"
 
-if test "x$INST_CROSS_MODE" = "xsnapshot" ; then
+if test "$INST_CROSS_MODE" = "snapshot" ; then
   GITREVP="--enable-gitrev"
 else
   GITREVP=""
 fi
 
-if test "x$MOCCMD" = "x" && test "x$MOC_CROSSER" != "x" ; then
+if test "$MOCCMD" = "" && test "$MOC_CROSSER" != "" ; then
   MOCPARAM="MOCCMD=${MOC_CROSSER}"
 fi
 
 PATH="${DLLSPATH}/linux/bin:${PATH}"
 hash -r
 
-if ! ../../../configure \
+if ! ${SRC_ROOT}/configure \
      ac_cv_working_gettimeofday=yes \
      $MOCPARAM \
      FREECIV_LABEL_FORCE="<base>-crs" \
@@ -210,7 +212,7 @@ if ! ../../../configure \
      --enable-fcmp=$FCMP \
      --enable-debug \
      --host=$TARGET \
-     --build=$(../../../bootstrap/config.guess) \
+     --build=$(${SRC_ROOT}/bootstrap/config.guess) \
      --with-libiconv-prefix=${DLLSPATH} \
      --with-sqlite3-prefix=${DLLSPATH} \
      --with-followtag="crosser" \
@@ -269,12 +271,13 @@ fi
   exit 1
 fi
 
-if ! mkdir -p Output ; then
-  echo "Creating Output directory failed" >&2
+if ! mkdir -p autotools/output ; then
+  echo "Creating autotools/output directory failed" >&2
   exit 1
 fi
 
-if ! 7z a -r Output/freeciv-${VERREV}${NAMEP}.7z freeciv-${VERREV}${NAMEP}
+if ! 7z a -r autotools/output/freeciv-${VERREV}${NAMEP}.7z \
+             freeciv-${VERREV}${NAMEP}
 then
   echo "7z failed" >&2
   exit 1
